Bump

Struct Bump 

pub struct Bump<const N: usize, M = MatterRawMutex> { /* private fields */ }
A bump allocator that uses a provided memory chunk

Implementations

Source

impl<const N: usize, M: RawMutex> Bump<N, M>

pub const fn new() -> Self

Create a new bump allocator

pub fn init() -> impl Init<Self>

Return an initializer for a new bump allocator

pub unsafe fn reset(&self)

Reset the allocator, making all previously allocated memory available again.

Safety

This is unsafe because any previously allocated objects that are still in use will get their memory corrupted and overwritten with new objects.

Make sure that NO previously allocated objects are still in use when calling this method.

pub fn pin_alloc<T>(&self, object: T, location: &str) -> Pin<BumpBox<'_, T>>
where T: Sized,

Allocate an object and return it pinned in a Pin<BumpBox<T>>

Arguments
  • object: The object to allocate
  • location: A string describing the location of the allocation, for logging purposes
Panics

This function will panic if there is not enough memory left in the bump allocator

pub fn alloc<T>(&self, object: T, location: &str) -> BumpBox<'_, T>
where T: Sized,

Allocate an object and return it in a BumpBox<T>

Arguments
  • object: The object to allocate
  • location: A string describing the location of the allocation, for logging purposes
Panics

This function will panic if there is not enough memory left in the bump allocator