Module eth
rs_
matter_
stack
0.2.0
Module eth
Module Items
Structs
Traits
Type Aliases
In crate rs_
matter_
stack
rs_matter_stack
Module
eth
Structs

Eth
An implementation of the
Network
trait for Ethernet.
Preexisting
Ethernet
A utility type for running an ethernet task with a pre-existing ethernet interface rather than bringing up / tearing down the ethernet interface for the task.
Traits

Ethernet
A trait for running a task within a context where the ethernet interface is initialized and operable
Ethernet
Task
A trait representing a task that needs access to the operational Ethernet interface (Network stack and Netif) to perform its work.
Type Aliases

EthMatter
Stack