Ethernet

Trait Ethernet 

pub trait Ethernet {
    // Required method
    async fn run<T>(&mut self, task: T) -> Result<(), Error>
       where T: EthernetTask;
}
A trait for running a task within a context where the ethernet interface is initialized and operable

Required Methods

async fn run<T>(&mut self, task: T) -> Result<(), Error>
where T: EthernetTask,

Setup Ethernet and run the given task

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> Ethernet for &mut T
where T: Ethernet,

Source

fn run<A>(&mut self, task: A) -> impl Future<Output = Result<(), Error>>
where A: EthernetTask,

Implementors

Source

impl<S, N, M> Ethernet for PreexistingEthernet<S, N, M>