EthernetTask

Trait EthernetTask 

pub trait EthernetTask {
    // Required method
    async fn run<S, N, M>(
        &mut self,
        net_stack: S,
        netif: N,
        mdns: M,
    ) -> Result<(), Error>
       where S: NetStack,
             N: NetifDiag + NetChangeNotif,
             M: Mdns;
}
A trait representing a task that needs access to the operational Ethernet interface (Network stack and Netif) to perform its work.

Required Methods

async fn run<S, N, M>( &mut self, net_stack: S, netif: N, mdns: M, ) -> Result<(), Error>

Run the task with the given network stack, network interface and mDNS

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> EthernetTask for &mut T
where T: EthernetTask,

Source

fn run<S, N, M>( &mut self, net_stack: S, netif: N, mdns: M, ) -> impl Future<Output = Result<(), Error>>

Implementors