Module matter

Module matter 

Modules

acl
Re-export the rs-matter crate This module contains the implementation of the rs-matter Access Control List (ACL)
attest
Re-export the rs-matter crate Credential verification for Matter device attestation.
bdx
Re-export the rs-matter crate Bulk Data Exchange (BDX) protocol.
cert
Re-export the rs-matter crate
crypto
Re-export the rs-matter crate Cryptographic abstractions and backend.
dm
Re-export the rs-matter crate The Data Model as defined by the Matter Core spec: the structure and schema of a node - its endpoints, clusters, attributes, commands and events - and the handlers that give them behaviour.
error
Re-export the rs-matter crate
fabric
Re-export the rs-matter crate
failsafe
Re-export the rs-matter crate
group_keys
Re-export the rs-matter crate
im
Re-export the rs-matter crate The Interaction Model as defined by the Matter Core spec: the interactions (Read, Subscribe/Report, Write, Invoke, Timed) and their TLV-serde encoding types, plus the engine - InteractionModel - that drives those interactions against a crate::dm data model.
onboard
Re-export the rs-matter crate Matter Commissioner support.
pairing
Re-export the rs-matter crate This module contains the logic for generating the pairing code and the QR code for easy pairing.
persist
Re-export the rs-matter crate This module provides the key-value BLOB store traits used throughout rs-matter for persistence, as well as some implementations for those.
reexport
Re-export the rs-matter crate Re-export several crates
respond
Re-export the rs-matter crate
sc
Re-export the rs-matter crate
tlv
Re-export the rs-matter crate
transport
Re-export the rs-matter crate
utils
Re-export the rs-matter crate

Macros

alloc
Re-export the rs-matter crate
attribute_enum
Re-export the rs-matter crate A macro to generate a TryFrom implementation for an attribute enum.
attributes
Re-export the rs-matter crate A macro to generate the attributes for a cluster.
bitflags_tlv
Re-export the rs-matter crate Implements to/from TLV for the given enumeration that was created using bitflags!
clusters
Re-export the rs-matter crate A macro to generate the clusters’ meta-data for an endpoint.
command_enum
Re-export the rs-matter crate A macro to generate a TryFrom implementation for a command enum.
commands
Re-export the rs-matter crate A macro to generate the commands for a cluster.
devices
Re-export the rs-matter crate A macro to generate the devices for an endpoint.
event_enum
Re-export the rs-matter crate A macro to generate a TryFrom implementation for an event enum.
events
Re-export the rs-matter crate A macro to generate the events for a cluster.
except
Re-export the rs-matter crate A macro that generates an “except” fn for matching attributes and commands
handler_chain_type
Re-export the rs-matter crate A helper macro that makes it easier to specify the full type of a ChainedHandler instantiation, which can be quite annoying in the case of long chains of handlers.
root_endpoint
Re-export the rs-matter crate A macro to generate the meta-data for the root endpoint (Endpoint 0).
with
Re-export the rs-matter crate A macro that generates a “with” fn for matching attributes and commands

Structs

BasicCommData
Re-export the rs-matter crate Device basic commissioning data
Matter
Re-export the rs-matter crate The primary Matter Object
MatterState
Re-export the rs-matter crate The internal state of the Matter Object

Constants

MATTER_PORT
Re-export the rs-matter crate The Matter UDP port