AccessReq

Struct AccessReq 

pub struct AccessReq<'a> { /* private fields */ }
Access Request Object

Implementations

Source

impl<'a> AccessReq<'a>

pub const fn new( accessor: &'a Accessor<'a>, path: GenericPath, operation: Access, device_types: &'a [DeviceType], ) -> AccessReq<'a>

Create an access request object.

An access request specifies the accessor attempting to access path with operation. device_types lists the device types declared by the endpoint that hosts path; pass an empty slice when this is not applicable (e.g. for unit tests that don’t exercise DeviceType ACL targets).

pub fn accessor(&self) -> &Accessor<'_>

Return the accessor of the request

pub fn operation(&self) -> Access

Return the operation of the request

pub fn set_target_perms(&mut self, perms: Access)

Add target’s permissions to the request

The permissions that are associated with the target (identified by the path in the AccessReq) are added to the request

pub fn allow(&self) -> bool

Check if access is allowed

This checks all the ACL list to identify if any of the ACLs provides the accessor the necessary privileges to access the target as per its permissions