Accessor

Struct Accessor 

pub struct Accessor<'a> { /* private fields */ }
The Accessor Object

Implementations

Source

impl<'a> Accessor<'a>

pub fn for_session( session: &Session, matter: &'a Matter<'a>, aux_acl_enabled: bool, ) -> Accessor<'a>

Create a new Accessor object for the given session

pub const fn new( fab_idx: u8, aux_acl_enabled: bool, subjects: AccessorSubjects, auth_mode: Option<AuthMode>, matter: &'a Matter<'a>, ) -> Accessor<'a>

Create a new Accessor object

Arguments
  • fab_idx: The fabric index of the accessor (0 means no fabric index)
  • aux_acl_enabled: Whether AUX ACL was enabled at the time this accessor was instantiated
  • subjects: The subjects of the accessor
  • auth_mode: The auth mode of the accessor
  • matter: The Matter instance
pub fn fab_idx(&self) -> Result<NonZero<u8>, Error>

pub const fn aux_acl_enabled(&self) -> bool

Return whether AUX ACL was enabled at the time this accessor was instantiated

pub const fn subjects(&self) -> &AccessorSubjects

Return the subjects of the accessor

pub const fn auth_mode(&self) -> Option<AuthMode>

Return the auth mode of the accessor

pub fn is_endpoint_accessible(&self, endpoint_id: u16) -> bool

Return whether the given endpoint is accessible for this accessor.

For group sessions, only endpoints that are members of the group are accessible. For all other session types, all endpoints are accessible.

pub fn node_id(&self) -> Option<u64>

Return the Operational Node ID of the accessor, if any

pub fn peer_node_id(&self) -> Option<u64>

Return the peer node ID (admin node ID) for CASE sessions, or None for PASE/other sessions.