AclEntry

Struct AclEntry 

pub struct AclEntry {
    pub fab_idx: Option<NonZero<u8>>,
    /* private fields */
}
The ACL entry object

Fields

fab_idx: Option<NonZero<u8>>

Implementations

Source

impl AclEntry

pub const fn new( fab_idx: Option<NonZero<u8>>, privilege: Privilege, auth_mode: AuthMode, ) -> AclEntry

Create a new ACL entry object

pub fn init( fab_idx: Option<NonZero<u8>>, privilege: Privilege, auth_mode: AuthMode, ) -> impl Init<AclEntry>

Return an initializer for an ACL entry object using the given fabric index, privilege and auth mode as input

pub fn init_with<'a>( fab_idx: NonZero<u8>, entry: &'a AccessControlEntryStruct<'a>, ) -> impl Init<AclEntry, Error> + 'a

Return an initializer for an ACL entry object using the given fabric index and TLV entry struct as input

pub fn read_into<P>( &self, accessing_fab_idx: u8, fab_idx: Option<u8>, builder: AccessControlEntryStructBuilder<P>, ) -> Result<P, Error>

Return the data of the ACL entry object into the provided TLV builder

pub fn normalize(&mut self)

Normalize the ACL entry by converting non-null but empty subjects/targets to null, as the spec and YAML tests expect

pub fn auth_mode(&self) -> AuthMode

Return the auth mode of the ACL entry

pub fn subjects(&self) -> Maybe<&[u64], AsNullable>

Return the subjects of the ACL entry

pub fn targets(&self) -> Maybe<&[Target], AsNullable>

Return the targets of the ACL entry

pub fn auxiliary_type(&self) -> Option<AccessControlAuxiliaryTypeEnum>

pub fn allow(&self, req: &AccessReq<'_>, aux_acl_enabled: bool) -> bool

Check if the ACL entry allows access to the given accessor and object

aux_acl_enabled conveys whether the node advertises the Access Control cluster’s AUXILIARY feature, which changes how wildcard-target Group-auth entries are evaluated - see Self::match_access_desc.

pub fn add_subject(&mut self, subject: u64) -> Result<(), Error>

Add a subject to the ACL entry

pub fn add_subject_catid(&mut self, cat_id: u32) -> Result<(), Error>

Add a CAT id to the ACL entry

pub fn add_target(&mut self, target: Target) -> Result<(), Error>

Add a target to the ACL entry