pub struct BdxDownloadResponder<'a> { /* private fields */ }Expand description
Implementations
Sourceimpl<'a> BdxDownloadResponder<'a>
impl<'a> BdxDownloadResponder<'a>
Sourcepub fn fd(&self) -> &[u8] ⓘ
pub fn fd(&self) -> &[u8] ⓘ
The file designator the initiator requested (borrowed from the held init).
Sourcepub fn start_offset(&self) -> u64
pub fn start_offset(&self) -> u64
The byte offset of the file from which the initiator asked the transfer to
begin (0 for a transfer from the start): the sender should start sending
from here, and advertise the remaining length in reply.
Reject with StartOffsetNotSupported
if the offset cannot be honored.
Sourcepub async fn reply<'b>(
self,
buf: &'b mut [u8],
length: Option<u64>,
) -> Result<BdxWriter<'a, 'b>, Error>
pub async fn reply<'b>( self, buf: &'b mut [u8], length: Option<u64>, ) -> Result<BdxWriter<'a, 'b>, Error>
Accept the transfer and start sending, staging blocks in the (non-empty)
caller-provided buffer buf (its length bounds the block size). length
advertises a definite transfer length (enabling the receiver’s progress
reporting) when known.