Module cert

Module cert 

Re-export the rs-matter crate

Modules

der_utils
DER encoding utilities for ECDSA signatures and certificate operations.
gen
Matter TLV-encoded certificate generator (RCAC / ICAC / NOC).
x509
X.509 DER certificate parsing utilities for extracting Matter-specific data.

Structs

ASN1Writer
CertRef
CertVerifier

Enums

CertTag
EcCurveIdValue
PubKeyAlgoValue
SignAlgoValue

Constants

MAX_CERT_ASN1_LEN
As per “Certificate Sizes” of the Matter spec, DER formatted DAC and NOC chains must not be longer than this size
MAX_CERT_TLV_AND_ASN1_LEN
Must be large enough to hold both TLV encoding and intermediate ASN.1 encoding during building in order to sign over the ASN1-encoded TBS certificate
MAX_CERT_TLV_LEN
As per “Certificate Sizes” of the Matter spec

Traits

CertConsumer

Functions

get_ec_curve_id
get_pubkey_algo
get_sign_algo