CryptoSensitive

Struct CryptoSensitive 

pub struct CryptoSensitive<const N: usize> { /* private fields */ }
A cryptographic material represented in a cross-platform way, as a fixed-length array in a well-defined format.

Thus, it can be imported into any Crypto provider and exported from it without worrying about endianness or other platform-specific representation issues.

The reason for wrapping the array with a newtype is so that the following protection measures are taken:

  • The material is not accidentally printed in logs or debug output.
  • The material has a single access / access_mut method and deliberately does not implement Deref or AsRef traits to avoid accidental leakage.
  • The material is zeroed out when dropped; note however that this has a limited use case, in Rust, because of the Rust move semantics.

Regarding sensitivity, rs-matter takes a radical approach and assumes that all cryptographic material is sensitive. Including, but not limited to:

  • Secret keys (obviously)
  • Signatures (because they can leak information about the secret key)
  • Hashes (because they can be pre-images of sensitive data)
  • Public keys (just in case)

Implementations

Source

impl<const N: usize> CryptoSensitive<N>

pub const fn new() -> CryptoSensitive<N>

Create a new zeroed CryptoSensitive instance.

pub const fn new_from_ref( other: CryptoSensitiveRef<'_, N>, ) -> CryptoSensitive<N>

Create a new CryptoSensitive instance by loading data from the provided reference.

pub fn init() -> impl Init<CryptoSensitive<N>>

Return an in-place initializer for a zeroed CryptoSensitive instance.

pub fn zeroize(&mut self)

Zeroizes the cryptographic material held by this instance.

pub const fn reference(&self) -> CryptoSensitiveRef<'_, N>

Get a reference to this cryptographic material.

pub const fn load(&mut self, other: CryptoSensitiveRef<'_, N>)

Load data from another cryptographic material reference.

pub const fn load_from_array(&mut self, data: &[u8; N])

Load data from a byte array.

pub fn try_load_from_slice(&mut self, data: &[u8]) -> Result<(), Error>

Try to load data from a byte slice.

Returns an error if the slice length does not match the expected length.

pub const fn access(&self) -> &[u8; N]

Access the underlying data as a byte array reference.

NOTE: care should be taken when using this method, as it exposes the sensitive data.

pub const fn access_mut(&mut self) -> &mut [u8; N]

Access the underlying data as a mutable byte array reference.

NOTE: care should be taken when using this method, as it exposes the sensitive data.