CryptoSensitiveRef

Struct CryptoSensitiveRef 

pub struct CryptoSensitiveRef<'a, const N: usize> { /* private fields */ }
A reference to cryptographic material. The non-owned equivalent of CryptoSensitive<N>.

Implementations

Source

impl<'a, const N: usize> CryptoSensitiveRef<'a, N>

pub const fn new(material: &'a [u8; N]) -> CryptoSensitiveRef<'a, N>

Create a new CryptoSensitiveRef instance from a byte array reference.

pub fn new_from_slice(material: &'a [u8]) -> CryptoSensitiveRef<'a, N>

Create a new CryptoSensitiveRef instance from a byte slice.

Panics if the slice length does not match the expected length.

pub fn try_new(material: &'a [u8]) -> Result<CryptoSensitiveRef<'a, N>, Error>

Try to create a new CryptoSensitiveRef instance from a byte slice.

Returns an error if the slice length does not match the expected length.

pub fn split<const M1: usize, const M2: usize>( &self, ) -> (CryptoSensitiveRef<'a, M1>, CryptoSensitiveRef<'a, M2>)

Split this reference into two references of the specified lengths.

Panics if the sum of the specified lengths does not match the length of this reference.

pub const fn access(&self) -> &'a [u8; N]

Access the underlying data as a byte array reference.

NOTE: care should be taken when using this method, as it exposes the sensitive data.