pub enum OutOfBandMessage {
Update(u8),
MoveToLevel {
with_on_off: bool,
level: u8,
transition_time: Option<u16>,
options_mask: OptionsBitmap,
options_override: OptionsBitmap,
},
Move {
with_on_off: bool,
move_mode: MoveModeEnum,
rate: Option<u8>,
options_mask: OptionsBitmap,
options_override: OptionsBitmap,
},
Step {
with_on_off: bool,
step_mode: StepModeEnum,
step_size: u8,
transition_time: Option<u16>,
options_mask: OptionsBitmap,
options_override: OptionsBitmap,
},
Stop,
}Expand description
Messages passed to the notify closure in LevelControlHooks::run() method.
Variants
Update(u8)
Indicates to the handler that the value of the current level has change and it should update the Matter state accordingly. Takes the new value of the CurrentLevel.
MoveToLevel
Initiates a MoveToLevel command. This will change the state of the device if and when appropriate according to Matter logic. See Matter Application Clusters specification.
Move
Initiates a Move command. This will change the state of the device if and when appropriate according to Matter logic. See Matter Application Clusters specification.
Step
Initiates a Step command. This will change the state of the device if and when appropriate according to Matter logic. See Matter Application Clusters specification.
Stop
Stop any running LevelControl transitions.