pub struct NoLevelControl;Expand description
This is a phantom type for when the OnOff cluster is not coupled with a LevelControl cluster. This type should only be used for annotations and not for actual LevelControl functionality. All methods will panic.