BasicInfoConfig

Struct BasicInfoConfig 

pub struct BasicInfoConfig<'a> {
Show 28 fields pub vendor_name: &'a str, pub vid: u16, pub product_name: &'a str, pub pid: u16, pub hw_ver: u16, pub hw_ver_str: &'a str, pub sw_ver: u32, pub sw_ver_str: &'a str, pub manufacturing_date: &'a str, pub part_number: &'a str, pub product_url: &'a str, pub product_label: &'a str, pub serial_no: &'a str, pub unique_id: &'a str, pub location: Option<&'a str>, pub device_location: Option<DeviceLocationConfig<'a>>, pub capability_minima: CapabilityMinima, pub product_appearance: ProductAppearance, pub specification_version: u32, pub data_model_revision: u16, pub max_paths_per_invoke: u16, pub device_name: &'a str, pub device_type: Option<u16>, pub pairing_hint: PairingHintFlags, pub pairing_instruction: &'a str, pub sai: Option<u32>, pub sii: Option<u32>, pub tcp_supported: bool,
}
Basic information which is immutable (i.e. valid for the lifetime of the device firmware)

Note that some of the fields will be reported only if their corresponding optional attributes are enabled.

By default, BasicInfoHandler::CLUSTER enables ALL optional attributes except reachable which is only valid for bridged devices.

Fields

vendor_name: &'a str

Vendor name (up to 32 characters)

vid: u16

Vendor ID

product_name: &'a str

Product name (up to 32 characters)

pid: u16

Product ID

hw_ver: u16

Hardware version

hw_ver_str: &'a str

Hardware version string (up to 64 characters)

sw_ver: u32

Software version

sw_ver_str: &'a str

Software version string (up to 64 characters)

manufacturing_date: &'a str

Manufacturing date (up to 16 characters)

part_number: &'a str

Part number (up to 32 characters)

product_url: &'a str

Product URL (up to 256 characters)

product_label: &'a str

Product label (up to 64 characters)

serial_no: &'a str

Serial number (up to 32 characters)

unique_id: &'a str

Unique ID (up to 64 characters)

location: Option<&'a str>

Factory default for the runtime-mutable, persisted BasicInformation::Location attribute

device_location: Option<DeviceLocationConfig<'a>>

Factory default for the runtime-mutable, persisted BasicInformation::DeviceLocation attribute

capability_minima: CapabilityMinima

Capability Minima

product_appearance: ProductAppearance

Product Appearance

specification_version: u32

Specification Version

data_model_revision: u16

Data Model Revision

max_paths_per_invoke: u16

Max Paths Per Invoke

device_name: &'a str

Device Name

Not a real attribute; used in the mDNS commissioning advertisement

device_type: Option<u16>

Device Type

Not a real attribute; used in the mDNS commissioning advertisement

pairing_hint: PairingHintFlags

Pairing Hint

Not a real attribute; used in the mDNS commissioning advertisement

pairing_instruction: &'a str

Pairing Instruction

Not a real attribute; used in the mDNS commissioning advertisement

sai: Option<u32>

Session Active Interval in ms If not specified, defaults to 300

Per the Matter Core Spec, the value is a 32-bit unsigned integer and SHALL NOT exceed 3,600,000 (1 hour in milliseconds).

Not a real attribute, just used to configure the session timeouts

sii: Option<u32>

Session Idle Interval in ms If not specified, defaults to 5000

Per the Matter Core Spec, the value is a 32-bit unsigned integer and SHALL NOT exceed 3,600,000 (1 hour in milliseconds).

Not a real attribute, just used to configure the session timeouts

tcp_supported: bool

Whether the device supports TCP transport.

Not a real attribute; advertised via the T TXT record key in mDNS. Per the Matter Core Spec, T is a bitmap: bit 2 (value 4) indicates TCP server support. Required for large payloads such as WebRTC SDP exchanges and camera snapshots.

Implementations

Source

impl BasicInfoConfig<'_>

pub const fn new() -> BasicInfoConfig<'_>