pub struct CapabilityMinima {
pub case_sessions_per_fabric: u16,
pub subscriptions_per_fabric: u16,
pub simultaneous_invocations_supported: u16,
pub simultaneous_writes_supported: u16,
pub read_paths_supported: u16,
pub subscribe_paths_supported: u16,
}Expand description
Capability Minima as reported in the Basic Information cluster
Fields
case_sessions_per_fabric: u16Maximum CASE sessions per fabric
subscriptions_per_fabric: u16Maximum subscriptions per fabric
simultaneous_invocations_supported: u16Maximum concurrent Invoke interactions processed before the node may
start answering with BUSY
simultaneous_writes_supported: u16Minimum concurrent Write interactions the node can process
read_paths_supported: u16Maximum number of read paths (AttributePathIB + EventPathIB) the
node guarantees to process in a single Read Request
subscribe_paths_supported: u16Maximum number of subscribe paths (AttributePathIB + EventPathIB)
the node guarantees to process in a single Subscribe Request
Implementations
Sourceimpl CapabilityMinima
impl CapabilityMinima
Sourcepub const fn new() -> CapabilityMinima
pub const fn new() -> CapabilityMinima
Create a default instance of CapabilityMinima, with CASE sessions per
fabric derived from the session table and the spec-minimum subscriptions
per fabric.