pub struct HandlerAsyncAdaptor<T>(pub T);Expand description
The handler adaptor for the cluster-specific handler. This adaptor implements the generic rs-matter handler trait.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> AsyncHandler for HandlerAsyncAdaptor<T>where
T: ClusterAsyncHandler,
impl<T> AsyncHandler for HandlerAsyncAdaptor<T>where
T: ClusterAsyncHandler,
Sourceasync fn read(
&self,
ctx: impl ReadContext,
reply: impl ReadReply,
) -> Result<(), Error>
async fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> Result<(), Error>
Read from the requested attribute and encode the result using the provided reply type.
Sourceasync fn write(&self, ctx: impl WriteContext) -> Result<(), Error>
async fn write(&self, ctx: impl WriteContext) -> Result<(), Error>
Write into the requested attribute using the provided data. Read more
Sourceasync fn invoke(
&self,
ctx: impl InvokeContext,
reply: impl InvokeReply,
) -> Result<(), Error>
async fn invoke( &self, ctx: impl InvokeContext, reply: impl InvokeReply, ) -> Result<(), Error>
Invoke the requested command with the provided data and encode the result using the provided reply type. Read more
Sourcefn bump_dataver(&self, ctx: impl MatchContext)
fn bump_dataver(&self, ctx: impl MatchContext)
Bump the per-cluster
Dataver for the cluster handler matching
the supplied context endpoint_id / cluster_id.Sourcefn lifecycle(
&self,
ctx: impl HandlerContext,
op: LifecycleOp,
) -> Result<(), Error>
fn lifecycle( &self, ctx: impl HandlerContext, op: LifecycleOp, ) -> Result<(), Error>
Process a lifecycle operation (
LifecycleOp). Read moreSourcefn run(
&self,
ctx: impl HandlerContext,
) -> impl Future<Output = Result<(), Error>>
fn run( &self, ctx: impl HandlerContext, ) -> impl Future<Output = Result<(), Error>>
A hook (a scheduling facility) for placing handler-impl-specific code that needs to run
asynchronously - forever and in the “background”.
Sourcefn read_awaits(&self, _ctx: impl ReadContext) -> bool
fn read_awaits(&self, _ctx: impl ReadContext) -> bool
Provide information whether the handler will internally await while reading
the current value of the provided attribute. Read more
Sourcefn write_awaits(&self, _ctx: impl WriteContext) -> bool
fn write_awaits(&self, _ctx: impl WriteContext) -> bool
Provide information whether the handler will internally await while updating
the value of the provided attribute. Read more
Sourcefn invoke_awaits(&self, _ctx: impl InvokeContext) -> bool
fn invoke_awaits(&self, _ctx: impl InvokeContext) -> bool
Provide information whether the handler will internally await while invoking
the provided command. Read more
Sourceimpl<T> Clone for HandlerAsyncAdaptor<T>where
T: Clone,
impl<T> Clone for HandlerAsyncAdaptor<T>where
T: Clone,
Sourcefn clone(&self) -> HandlerAsyncAdaptor<T>
fn clone(&self) -> HandlerAsyncAdaptor<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl<T> Copy for HandlerAsyncAdaptor<T>where
T: Copy,
Sourceimpl<T> Debug for HandlerAsyncAdaptor<T>where
T: Debug,
impl<T> Debug for HandlerAsyncAdaptor<T>where
T: Debug,
impl<T> Eq for HandlerAsyncAdaptor<T>where
T: Eq,
Sourceimpl<T> Hash for HandlerAsyncAdaptor<T>where
T: Hash,
impl<T> Hash for HandlerAsyncAdaptor<T>where
T: Hash,
Sourceimpl<T> PartialEq for HandlerAsyncAdaptor<T>where
T: PartialEq,
impl<T> PartialEq for HandlerAsyncAdaptor<T>where
T: PartialEq,
impl<T> StructuralPartialEq for HandlerAsyncAdaptor<T>where
T: PartialEq,