pub struct PairingHintFlags(/* private fields */);Implementations
Sourceimpl PairingHintFlags
impl PairingHintFlags
Sourcepub const POWER_CYCLE: PairingHintFlags
pub const POWER_CYCLE: PairingHintFlags
Power Cycle False The Device will automatically enter Commissioning Mode upon power cycle (unplug/replug, remove/re-insert batteries). This bit SHALL be set to 1 for devices using Standard Commissioning Flow, and set to 0 otherwise.
Sourcepub const DEV_MANUFACTURER_URL: PairingHintFlags
pub const DEV_MANUFACTURER_URL: PairingHintFlags
This SHALL be set to 1 for devices requiring Custom Commissioning Flow before they can be available for Commissioning by any Commissioner. For such a flow, the user SHOULD be sent to the URL specified in the CommissioningCustomFlowUrl of the DeviceModel schema entry indexed by the Vendor ID and Product ID (e.g., as found in the announcement) in the Distributed Compliance Ledger.
Sourcepub const ADMINISTRATOR: PairingHintFlags
pub const ADMINISTRATOR: PairingHintFlags
The Device has been commissioned. Any Administrator that commissioned the device provides a user interface that may be used to put the device into Commissioning Mode.
Sourcepub const SETTINGS_MENU: PairingHintFlags
pub const SETTINGS_MENU: PairingHintFlags
The settings menu on the Device provides instructions to put it into Commissioning Mode.
Sourcepub const CUSTOM_INSTRUCTION: PairingHintFlags
pub const CUSTOM_INSTRUCTION: PairingHintFlags
The PI key/value pair describes a custom way to put the Device into Commissioning Mode. This Custom Instruction option is NOT recommended for use by a Device that does not have knowledge of the user’s language preference.
Sourcepub const DEVICE_MANUAL: PairingHintFlags
pub const DEVICE_MANUAL: PairingHintFlags
The Device Manual provides special instructions to put the Device into Commissioning Mode (see “UserManualUrl” in the Core Spec). This is a catchall option to capture user interactions that are not codified by other options in this flags type.
Sourcepub const PRESS_RESET_BUTTON: PairingHintFlags
pub const PRESS_RESET_BUTTON: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed.
Sourcepub const PRESS_RESET_BUTTON_WITH_POWER: PairingHintFlags
pub const PRESS_RESET_BUTTON_WITH_POWER: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed when applying power to it.
Sourcepub const PRESS_RESET_BUTTON_FOR_N_SECONDS: PairingHintFlags
pub const PRESS_RESET_BUTTON_FOR_N_SECONDS: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed for N seconds. The exact value of N SHALL be made available via PI key.
Sourcepub const PRESS_RESET_BUTTON_UNTIL_LIGHT_BLINKS: PairingHintFlags
pub const PRESS_RESET_BUTTON_UNTIL_LIGHT_BLINKS: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed until associated light blinks. Information on color of light MAY be made available via PI key.
Sourcepub const PRESS_RESET_BUTTON_FOR_N_SECONDS_WITH_POWER: PairingHintFlags
pub const PRESS_RESET_BUTTON_FOR_N_SECONDS_WITH_POWER: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed for N seconds when applying power to it. The exact value of N SHALL be made available via PI key.
Sourcepub const PRESS_RESET_BUTTON_UNTIL_LIGHT_BLINKS_WITH_POWER: PairingHintFlags
pub const PRESS_RESET_BUTTON_UNTIL_LIGHT_BLINKS_WITH_POWER: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed until associated light blinks when applying power to the Device. Information on color of light MAY be made available via PI key.
Sourcepub const PRESS_RESET_BUTTON_N_TIMES: PairingHintFlags
pub const PRESS_RESET_BUTTON_N_TIMES: PairingHintFlags
The Device will enter Commissioning Mode when reset button is pressed N times with maximum 1 second between each press. The exact value of N SHALL be made available via PI key.
Sourcepub const PRESS_SETUP_BUTTON: PairingHintFlags
pub const PRESS_SETUP_BUTTON: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed.
Sourcepub const PRESS_SETUP_BUTTON_WITH_POWER: PairingHintFlags
pub const PRESS_SETUP_BUTTON_WITH_POWER: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed when applying power to it.
Sourcepub const PRESS_SETUP_BUTTON_FOR_N_SECONDS: PairingHintFlags
pub const PRESS_SETUP_BUTTON_FOR_N_SECONDS: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed for N seconds. The exact value of N SHALL be made available via PI key.
Sourcepub const PRESS_SETUP_BUTTON_UNTIL_LIGHT_BLINKS: PairingHintFlags
pub const PRESS_SETUP_BUTTON_UNTIL_LIGHT_BLINKS: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed until associated light blinks. Information on color of light MAY be made available via PI key.
Sourcepub const PRESS_SETUP_BUTTON_FOR_N_SECONDS_WITH_POWER: PairingHintFlags
pub const PRESS_SETUP_BUTTON_FOR_N_SECONDS_WITH_POWER: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed for N seconds when applying power to it. The exact value of N SHALL be made available via PI key.
Sourcepub const PRESS_SETUP_BUTTON_UNTIL_LIGHT_BLINKS_WITH_POWER: PairingHintFlags
pub const PRESS_SETUP_BUTTON_UNTIL_LIGHT_BLINKS_WITH_POWER: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed until associated light blinks when applying power to the Device. Information on color of light MAY be made available via PI key.
Sourcepub const PRESS_SETUP_BUTTON_N_TIMES: PairingHintFlags
pub const PRESS_SETUP_BUTTON_N_TIMES: PairingHintFlags
The Device will enter Commissioning Mode when setup button is pressed N times with maximum 1 second between each press. The exact value of N SHALL be made available via PI key.
Sourceimpl PairingHintFlags
impl PairingHintFlags
Sourcepub const fn empty() -> PairingHintFlags
pub const fn empty() -> PairingHintFlags
Get a flags value with all bits unset.
Sourcepub const fn all() -> PairingHintFlags
pub const fn all() -> PairingHintFlags
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<PairingHintFlags>
pub const fn from_bits(bits: u32) -> Option<PairingHintFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> PairingHintFlags
pub const fn from_bits_truncate(bits: u32) -> PairingHintFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> PairingHintFlags
pub const fn from_bits_retain(bits: u32) -> PairingHintFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<PairingHintFlags>
pub fn from_name(name: &str) -> Option<PairingHintFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: PairingHintFlags) -> bool
pub const fn intersects(&self, other: PairingHintFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: PairingHintFlags) -> bool
pub const fn contains(&self, other: PairingHintFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: PairingHintFlags)
pub fn insert(&mut self, other: PairingHintFlags)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: PairingHintFlags)
pub fn remove(&mut self, other: PairingHintFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: PairingHintFlags)
pub fn toggle(&mut self, other: PairingHintFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: PairingHintFlags, value: bool)
pub fn set(&mut self, other: PairingHintFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: PairingHintFlags) -> PairingHintFlags
pub const fn intersection(self, other: PairingHintFlags) -> PairingHintFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: PairingHintFlags) -> PairingHintFlags
pub const fn union(self, other: PairingHintFlags) -> PairingHintFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: PairingHintFlags) -> PairingHintFlags
pub const fn difference(self, other: PairingHintFlags) -> PairingHintFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: PairingHintFlags,
) -> PairingHintFlags
pub const fn symmetric_difference( self, other: PairingHintFlags, ) -> PairingHintFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> PairingHintFlags
pub const fn complement(self) -> PairingHintFlags
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PairingHintFlags
impl PairingHintFlags
Sourcepub const fn iter(&self) -> Iter<PairingHintFlags> ⓘ
pub const fn iter(&self) -> Iter<PairingHintFlags> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PairingHintFlags> ⓘ
pub const fn iter_names(&self) -> IterNames<PairingHintFlags> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.