pub struct CommandBits(/* private fields */);Implementations
Sourceimpl CommandBits
impl CommandBits
pub const INSTANT_ACTION: CommandBits
pub const INSTANT_ACTION_WITH_TRANSITION: CommandBits
pub const START_ACTION: CommandBits
pub const START_ACTION_WITH_DURATION: CommandBits
pub const STOP_ACTION: CommandBits
pub const PAUSE_ACTION: CommandBits
pub const PAUSE_ACTION_WITH_DURATION: CommandBits
pub const RESUME_ACTION: CommandBits
pub const ENABLE_ACTION: CommandBits
pub const ENABLE_ACTION_WITH_DURATION: CommandBits
pub const DISABLE_ACTION: CommandBits
pub const DISABLE_ACTION_WITH_DURATION: CommandBits
pub const _INTERNAL_ALL_BITS: CommandBits
Sourceimpl CommandBits
impl CommandBits
Sourcepub const fn empty() -> CommandBits
pub const fn empty() -> CommandBits
Get a flags value with all bits unset.
Sourcepub const fn all() -> CommandBits
pub const fn all() -> CommandBits
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<CommandBits>
pub const fn from_bits(bits: u16) -> Option<CommandBits>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> CommandBits
pub const fn from_bits_truncate(bits: u16) -> CommandBits
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> CommandBits
pub const fn from_bits_retain(bits: u16) -> CommandBits
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<CommandBits>
pub fn from_name(name: &str) -> Option<CommandBits>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: CommandBits) -> bool
pub const fn intersects(&self, other: CommandBits) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: CommandBits) -> bool
pub const fn contains(&self, other: CommandBits) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: CommandBits)
pub fn insert(&mut self, other: CommandBits)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: CommandBits)
pub fn remove(&mut self, other: CommandBits)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: CommandBits)
pub fn toggle(&mut self, other: CommandBits)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: CommandBits, value: bool)
pub fn set(&mut self, other: CommandBits, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: CommandBits) -> CommandBits
pub const fn intersection(self, other: CommandBits) -> CommandBits
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: CommandBits) -> CommandBits
pub const fn union(self, other: CommandBits) -> CommandBits
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: CommandBits) -> CommandBits
pub const fn difference(self, other: CommandBits) -> CommandBits
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: CommandBits) -> CommandBits
pub const fn symmetric_difference(self, other: CommandBits) -> CommandBits
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> CommandBits
pub const fn complement(self) -> CommandBits
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl CommandBits
impl CommandBits
Sourcepub const fn iter(&self) -> Iter<CommandBits> ⓘ
pub const fn iter(&self) -> Iter<CommandBits> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<CommandBits> ⓘ
pub const fn iter_names(&self) -> IterNames<CommandBits> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.