pub struct AdministratorCommissioningClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the AdministratorCommissioning cluster’s client operations. Returned by AdministratorCommissioningClient::administrator_commissioning. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> AdministratorCommissioningClientView<'a>
impl<'a> AdministratorCommissioningClientView<'a>
pub async fn open_commissioning_window<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(OpenCommissioningWindowRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn open_basic_commissioning_window<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(OpenBasicCommissioningWindowRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn revoke_commissioning(self, endpoint: u16) -> Result<(), Error>
pub async fn window_status_read( self, endpoint: u16, ) -> Result<CommissioningWindowStatusEnum, Error>
pub async fn admin_fabric_index_read( self, endpoint: u16, ) -> Result<Maybe<u8, AsNullable>, Error>
pub async fn admin_vendor_id_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>