pub struct BallastStatusBitmap(/* private fields */);Implementations
Sourceimpl BallastStatusBitmap
impl BallastStatusBitmap
pub const BALLAST_NON_OPERATIONAL: BallastStatusBitmap
pub const LAMP_FAILURE: BallastStatusBitmap
pub const _INTERNAL_ALL_BITS: BallastStatusBitmap
Sourceimpl BallastStatusBitmap
impl BallastStatusBitmap
Sourcepub const fn empty() -> BallastStatusBitmap
pub const fn empty() -> BallastStatusBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> BallastStatusBitmap
pub const fn all() -> BallastStatusBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<BallastStatusBitmap>
pub const fn from_bits(bits: u8) -> Option<BallastStatusBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> BallastStatusBitmap
pub const fn from_bits_truncate(bits: u8) -> BallastStatusBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> BallastStatusBitmap
pub const fn from_bits_retain(bits: u8) -> BallastStatusBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<BallastStatusBitmap>
pub fn from_name(name: &str) -> Option<BallastStatusBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: BallastStatusBitmap) -> bool
pub const fn intersects(&self, other: BallastStatusBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: BallastStatusBitmap) -> bool
pub const fn contains(&self, other: BallastStatusBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: BallastStatusBitmap)
pub fn insert(&mut self, other: BallastStatusBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: BallastStatusBitmap)
pub fn remove(&mut self, other: BallastStatusBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: BallastStatusBitmap)
pub fn toggle(&mut self, other: BallastStatusBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: BallastStatusBitmap, value: bool)
pub fn set(&mut self, other: BallastStatusBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: BallastStatusBitmap,
) -> BallastStatusBitmap
pub const fn intersection( self, other: BallastStatusBitmap, ) -> BallastStatusBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: BallastStatusBitmap) -> BallastStatusBitmap
pub const fn union(self, other: BallastStatusBitmap) -> BallastStatusBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: BallastStatusBitmap) -> BallastStatusBitmap
pub const fn difference(self, other: BallastStatusBitmap) -> BallastStatusBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: BallastStatusBitmap,
) -> BallastStatusBitmap
pub const fn symmetric_difference( self, other: BallastStatusBitmap, ) -> BallastStatusBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> BallastStatusBitmap
pub const fn complement(self) -> BallastStatusBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl BallastStatusBitmap
impl BallastStatusBitmap
Sourcepub const fn iter(&self) -> Iter<BallastStatusBitmap> ⓘ
pub const fn iter(&self) -> Iter<BallastStatusBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<BallastStatusBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<BallastStatusBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.