pub struct AlarmModeBitmap(/* private fields */);Implementations
Sourceimpl AlarmModeBitmap
impl AlarmModeBitmap
pub const VISUAL: AlarmModeBitmap
pub const AUDIBLE: AlarmModeBitmap
pub const _INTERNAL_ALL_BITS: AlarmModeBitmap
Sourceimpl AlarmModeBitmap
impl AlarmModeBitmap
Sourcepub const fn empty() -> AlarmModeBitmap
pub const fn empty() -> AlarmModeBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> AlarmModeBitmap
pub const fn all() -> AlarmModeBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<AlarmModeBitmap>
pub const fn from_bits(bits: u8) -> Option<AlarmModeBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> AlarmModeBitmap
pub const fn from_bits_truncate(bits: u8) -> AlarmModeBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> AlarmModeBitmap
pub const fn from_bits_retain(bits: u8) -> AlarmModeBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AlarmModeBitmap>
pub fn from_name(name: &str) -> Option<AlarmModeBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AlarmModeBitmap) -> bool
pub const fn intersects(&self, other: AlarmModeBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: AlarmModeBitmap) -> bool
pub const fn contains(&self, other: AlarmModeBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: AlarmModeBitmap)
pub fn insert(&mut self, other: AlarmModeBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: AlarmModeBitmap)
pub fn remove(&mut self, other: AlarmModeBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AlarmModeBitmap)
pub fn toggle(&mut self, other: AlarmModeBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: AlarmModeBitmap, value: bool)
pub fn set(&mut self, other: AlarmModeBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AlarmModeBitmap) -> AlarmModeBitmap
pub const fn intersection(self, other: AlarmModeBitmap) -> AlarmModeBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: AlarmModeBitmap) -> AlarmModeBitmap
pub const fn union(self, other: AlarmModeBitmap) -> AlarmModeBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: AlarmModeBitmap) -> AlarmModeBitmap
pub const fn difference(self, other: AlarmModeBitmap) -> AlarmModeBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: AlarmModeBitmap,
) -> AlarmModeBitmap
pub const fn symmetric_difference( self, other: AlarmModeBitmap, ) -> AlarmModeBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> AlarmModeBitmap
pub const fn complement(self) -> AlarmModeBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AlarmModeBitmap
impl AlarmModeBitmap
Sourcepub const fn iter(&self) -> Iter<AlarmModeBitmap> ⓘ
pub const fn iter(&self) -> Iter<AlarmModeBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AlarmModeBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<AlarmModeBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.