pub struct SensorFaultBitmap(/* private fields */);Implementations
Sourceimpl SensorFaultBitmap
impl SensorFaultBitmap
pub const GENERAL_FAULT: SensorFaultBitmap
pub const _INTERNAL_ALL_BITS: SensorFaultBitmap
Sourceimpl SensorFaultBitmap
impl SensorFaultBitmap
Sourcepub const fn empty() -> SensorFaultBitmap
pub const fn empty() -> SensorFaultBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> SensorFaultBitmap
pub const fn all() -> SensorFaultBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<SensorFaultBitmap>
pub const fn from_bits(bits: u16) -> Option<SensorFaultBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> SensorFaultBitmap
pub const fn from_bits_truncate(bits: u16) -> SensorFaultBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> SensorFaultBitmap
pub const fn from_bits_retain(bits: u16) -> SensorFaultBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SensorFaultBitmap>
pub fn from_name(name: &str) -> Option<SensorFaultBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SensorFaultBitmap) -> bool
pub const fn intersects(&self, other: SensorFaultBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SensorFaultBitmap) -> bool
pub const fn contains(&self, other: SensorFaultBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SensorFaultBitmap)
pub fn insert(&mut self, other: SensorFaultBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SensorFaultBitmap)
pub fn remove(&mut self, other: SensorFaultBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SensorFaultBitmap)
pub fn toggle(&mut self, other: SensorFaultBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SensorFaultBitmap, value: bool)
pub fn set(&mut self, other: SensorFaultBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SensorFaultBitmap) -> SensorFaultBitmap
pub const fn intersection(self, other: SensorFaultBitmap) -> SensorFaultBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SensorFaultBitmap) -> SensorFaultBitmap
pub const fn union(self, other: SensorFaultBitmap) -> SensorFaultBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SensorFaultBitmap) -> SensorFaultBitmap
pub const fn difference(self, other: SensorFaultBitmap) -> SensorFaultBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: SensorFaultBitmap,
) -> SensorFaultBitmap
pub const fn symmetric_difference( self, other: SensorFaultBitmap, ) -> SensorFaultBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SensorFaultBitmap
pub const fn complement(self) -> SensorFaultBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SensorFaultBitmap
impl SensorFaultBitmap
Sourcepub const fn iter(&self) -> Iter<SensorFaultBitmap> ⓘ
pub const fn iter(&self) -> Iter<SensorFaultBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SensorFaultBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<SensorFaultBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.