pub struct RecordingFlagBitmap(/* private fields */);Implementations
Sourceimpl RecordingFlagBitmap
impl RecordingFlagBitmap
pub const SCHEDULED: RecordingFlagBitmap
pub const RECORD_SERIES: RecordingFlagBitmap
pub const RECORDED: RecordingFlagBitmap
pub const _INTERNAL_ALL_BITS: RecordingFlagBitmap
Sourceimpl RecordingFlagBitmap
impl RecordingFlagBitmap
Sourcepub const fn empty() -> RecordingFlagBitmap
pub const fn empty() -> RecordingFlagBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> RecordingFlagBitmap
pub const fn all() -> RecordingFlagBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<RecordingFlagBitmap>
pub const fn from_bits(bits: u32) -> Option<RecordingFlagBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> RecordingFlagBitmap
pub const fn from_bits_truncate(bits: u32) -> RecordingFlagBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> RecordingFlagBitmap
pub const fn from_bits_retain(bits: u32) -> RecordingFlagBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RecordingFlagBitmap>
pub fn from_name(name: &str) -> Option<RecordingFlagBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RecordingFlagBitmap) -> bool
pub const fn intersects(&self, other: RecordingFlagBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RecordingFlagBitmap) -> bool
pub const fn contains(&self, other: RecordingFlagBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RecordingFlagBitmap)
pub fn insert(&mut self, other: RecordingFlagBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RecordingFlagBitmap)
pub fn remove(&mut self, other: RecordingFlagBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RecordingFlagBitmap)
pub fn toggle(&mut self, other: RecordingFlagBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RecordingFlagBitmap, value: bool)
pub fn set(&mut self, other: RecordingFlagBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: RecordingFlagBitmap,
) -> RecordingFlagBitmap
pub const fn intersection( self, other: RecordingFlagBitmap, ) -> RecordingFlagBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: RecordingFlagBitmap) -> RecordingFlagBitmap
pub const fn union(self, other: RecordingFlagBitmap) -> RecordingFlagBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: RecordingFlagBitmap) -> RecordingFlagBitmap
pub const fn difference(self, other: RecordingFlagBitmap) -> RecordingFlagBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: RecordingFlagBitmap,
) -> RecordingFlagBitmap
pub const fn symmetric_difference( self, other: RecordingFlagBitmap, ) -> RecordingFlagBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RecordingFlagBitmap
pub const fn complement(self) -> RecordingFlagBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RecordingFlagBitmap
impl RecordingFlagBitmap
Sourcepub const fn iter(&self) -> Iter<RecordingFlagBitmap> ⓘ
pub const fn iter(&self) -> Iter<RecordingFlagBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RecordingFlagBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<RecordingFlagBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.