pub struct LatchControlModesBitmap(/* private fields */);Implementations
Sourceimpl LatchControlModesBitmap
impl LatchControlModesBitmap
pub const REMOTE_LATCHING: LatchControlModesBitmap
pub const REMOTE_UNLATCHING: LatchControlModesBitmap
pub const _INTERNAL_ALL_BITS: LatchControlModesBitmap
Sourceimpl LatchControlModesBitmap
impl LatchControlModesBitmap
Sourcepub const fn empty() -> LatchControlModesBitmap
pub const fn empty() -> LatchControlModesBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> LatchControlModesBitmap
pub const fn all() -> LatchControlModesBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<LatchControlModesBitmap>
pub const fn from_bits(bits: u8) -> Option<LatchControlModesBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> LatchControlModesBitmap
pub const fn from_bits_truncate(bits: u8) -> LatchControlModesBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> LatchControlModesBitmap
pub const fn from_bits_retain(bits: u8) -> LatchControlModesBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<LatchControlModesBitmap>
pub fn from_name(name: &str) -> Option<LatchControlModesBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: LatchControlModesBitmap) -> bool
pub const fn intersects(&self, other: LatchControlModesBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: LatchControlModesBitmap) -> bool
pub const fn contains(&self, other: LatchControlModesBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: LatchControlModesBitmap)
pub fn insert(&mut self, other: LatchControlModesBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: LatchControlModesBitmap)
pub fn remove(&mut self, other: LatchControlModesBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: LatchControlModesBitmap)
pub fn toggle(&mut self, other: LatchControlModesBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: LatchControlModesBitmap, value: bool)
pub fn set(&mut self, other: LatchControlModesBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: LatchControlModesBitmap,
) -> LatchControlModesBitmap
pub const fn intersection( self, other: LatchControlModesBitmap, ) -> LatchControlModesBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: LatchControlModesBitmap,
) -> LatchControlModesBitmap
pub const fn union( self, other: LatchControlModesBitmap, ) -> LatchControlModesBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: LatchControlModesBitmap,
) -> LatchControlModesBitmap
pub const fn difference( self, other: LatchControlModesBitmap, ) -> LatchControlModesBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: LatchControlModesBitmap,
) -> LatchControlModesBitmap
pub const fn symmetric_difference( self, other: LatchControlModesBitmap, ) -> LatchControlModesBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> LatchControlModesBitmap
pub const fn complement(self) -> LatchControlModesBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl LatchControlModesBitmap
impl LatchControlModesBitmap
Sourcepub const fn iter(&self) -> Iter<LatchControlModesBitmap> ⓘ
pub const fn iter(&self) -> Iter<LatchControlModesBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<LatchControlModesBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<LatchControlModesBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.