pub struct DayPatternDayOfWeekBitmap(/* private fields */);Implementations
Sourceimpl DayPatternDayOfWeekBitmap
impl DayPatternDayOfWeekBitmap
pub const SUNDAY: DayPatternDayOfWeekBitmap
pub const MONDAY: DayPatternDayOfWeekBitmap
pub const TUESDAY: DayPatternDayOfWeekBitmap
pub const WEDNESDAY: DayPatternDayOfWeekBitmap
pub const THURSDAY: DayPatternDayOfWeekBitmap
pub const FRIDAY: DayPatternDayOfWeekBitmap
pub const SATURDAY: DayPatternDayOfWeekBitmap
pub const _INTERNAL_ALL_BITS: DayPatternDayOfWeekBitmap
Sourceimpl DayPatternDayOfWeekBitmap
impl DayPatternDayOfWeekBitmap
Sourcepub const fn empty() -> DayPatternDayOfWeekBitmap
pub const fn empty() -> DayPatternDayOfWeekBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> DayPatternDayOfWeekBitmap
pub const fn all() -> DayPatternDayOfWeekBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<DayPatternDayOfWeekBitmap>
pub const fn from_bits(bits: u8) -> Option<DayPatternDayOfWeekBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> DayPatternDayOfWeekBitmap
pub const fn from_bits_truncate(bits: u8) -> DayPatternDayOfWeekBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> DayPatternDayOfWeekBitmap
pub const fn from_bits_retain(bits: u8) -> DayPatternDayOfWeekBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DayPatternDayOfWeekBitmap>
pub fn from_name(name: &str) -> Option<DayPatternDayOfWeekBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DayPatternDayOfWeekBitmap) -> bool
pub const fn intersects(&self, other: DayPatternDayOfWeekBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DayPatternDayOfWeekBitmap) -> bool
pub const fn contains(&self, other: DayPatternDayOfWeekBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DayPatternDayOfWeekBitmap)
pub fn insert(&mut self, other: DayPatternDayOfWeekBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DayPatternDayOfWeekBitmap)
pub fn remove(&mut self, other: DayPatternDayOfWeekBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DayPatternDayOfWeekBitmap)
pub fn toggle(&mut self, other: DayPatternDayOfWeekBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DayPatternDayOfWeekBitmap, value: bool)
pub fn set(&mut self, other: DayPatternDayOfWeekBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DayPatternDayOfWeekBitmap,
) -> DayPatternDayOfWeekBitmap
pub const fn intersection( self, other: DayPatternDayOfWeekBitmap, ) -> DayPatternDayOfWeekBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DayPatternDayOfWeekBitmap,
) -> DayPatternDayOfWeekBitmap
pub const fn union( self, other: DayPatternDayOfWeekBitmap, ) -> DayPatternDayOfWeekBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DayPatternDayOfWeekBitmap,
) -> DayPatternDayOfWeekBitmap
pub const fn difference( self, other: DayPatternDayOfWeekBitmap, ) -> DayPatternDayOfWeekBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DayPatternDayOfWeekBitmap,
) -> DayPatternDayOfWeekBitmap
pub const fn symmetric_difference( self, other: DayPatternDayOfWeekBitmap, ) -> DayPatternDayOfWeekBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DayPatternDayOfWeekBitmap
pub const fn complement(self) -> DayPatternDayOfWeekBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DayPatternDayOfWeekBitmap
impl DayPatternDayOfWeekBitmap
Sourcepub const fn iter(&self) -> Iter<DayPatternDayOfWeekBitmap> ⓘ
pub const fn iter(&self) -> Iter<DayPatternDayOfWeekBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DayPatternDayOfWeekBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<DayPatternDayOfWeekBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.