pub struct ContentControlClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the ContentControl cluster’s client operations. Returned by ContentControlClient::content_control. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> ContentControlClientView<'a>
impl<'a> ContentControlClientView<'a>
pub async fn update_pin<F>(self, endpoint: u16, request: F) -> Result<(), Error>where
F: FnMut(UpdatePINRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn reset_pin( self, endpoint: u16, ) -> Result<ResetPINResponseHandle<'a>, Error>
pub async fn enable(self, endpoint: u16) -> Result<(), Error>
pub async fn disable(self, endpoint: u16) -> Result<(), Error>
pub async fn add_bonus_time<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(AddBonusTimeRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_screen_daily_time<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetScreenDailyTimeRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn block_unrated_content(self, endpoint: u16) -> Result<(), Error>
pub async fn unblock_unrated_content(self, endpoint: u16) -> Result<(), Error>
pub async fn set_on_demand_rating_threshold<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetOnDemandRatingThresholdRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_scheduled_content_rating_threshold<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetScheduledContentRatingThresholdRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn add_block_channels<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(AddBlockChannelsRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn remove_block_channels<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(RemoveBlockChannelsRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn add_block_applications<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(AddBlockApplicationsRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn remove_block_applications<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(RemoveBlockApplicationsRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_block_content_time_window<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetBlockContentTimeWindowRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn remove_block_content_time_window<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(RemoveBlockContentTimeWindowRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn enabled_read(self, endpoint: u16) -> Result<bool, Error>
Sourcepub async fn on_demand_ratings_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, RatingNameStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn on_demand_ratings_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, RatingNameStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn on_demand_rating_threshold_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<&str, Error>) -> R,
) -> Result<R, Error>
pub async fn on_demand_rating_threshold_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<&str, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn scheduled_content_ratings_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, RatingNameStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn scheduled_content_ratings_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, RatingNameStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn scheduled_content_rating_threshold_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<&str, Error>) -> R,
) -> Result<R, Error>
pub async fn scheduled_content_rating_threshold_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<&str, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn screen_daily_time_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn remaining_screen_time_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn block_unrated_read(self, endpoint: u16) -> Result<bool, Error>
Sourcepub async fn block_channel_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, BlockChannelStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn block_channel_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, BlockChannelStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn block_application_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, AppInfoStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn block_application_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, AppInfoStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn block_content_time_window_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, TimeWindowStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn block_content_time_window_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, TimeWindowStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>