pub struct DayOfWeekBitmap(/* private fields */);Implementations
Sourceimpl DayOfWeekBitmap
impl DayOfWeekBitmap
pub const SUNDAY: DayOfWeekBitmap
pub const MONDAY: DayOfWeekBitmap
pub const TUESDAY: DayOfWeekBitmap
pub const WEDNESDAY: DayOfWeekBitmap
pub const THURSDAY: DayOfWeekBitmap
pub const FRIDAY: DayOfWeekBitmap
pub const SATURDAY: DayOfWeekBitmap
pub const _INTERNAL_ALL_BITS: DayOfWeekBitmap
Sourceimpl DayOfWeekBitmap
impl DayOfWeekBitmap
Sourcepub const fn empty() -> DayOfWeekBitmap
pub const fn empty() -> DayOfWeekBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> DayOfWeekBitmap
pub const fn all() -> DayOfWeekBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<DayOfWeekBitmap>
pub const fn from_bits(bits: u8) -> Option<DayOfWeekBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> DayOfWeekBitmap
pub const fn from_bits_truncate(bits: u8) -> DayOfWeekBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> DayOfWeekBitmap
pub const fn from_bits_retain(bits: u8) -> DayOfWeekBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DayOfWeekBitmap>
pub fn from_name(name: &str) -> Option<DayOfWeekBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DayOfWeekBitmap) -> bool
pub const fn intersects(&self, other: DayOfWeekBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DayOfWeekBitmap) -> bool
pub const fn contains(&self, other: DayOfWeekBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DayOfWeekBitmap)
pub fn insert(&mut self, other: DayOfWeekBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DayOfWeekBitmap)
pub fn remove(&mut self, other: DayOfWeekBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DayOfWeekBitmap)
pub fn toggle(&mut self, other: DayOfWeekBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DayOfWeekBitmap, value: bool)
pub fn set(&mut self, other: DayOfWeekBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: DayOfWeekBitmap) -> DayOfWeekBitmap
pub const fn intersection(self, other: DayOfWeekBitmap) -> DayOfWeekBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: DayOfWeekBitmap) -> DayOfWeekBitmap
pub const fn union(self, other: DayOfWeekBitmap) -> DayOfWeekBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: DayOfWeekBitmap) -> DayOfWeekBitmap
pub const fn difference(self, other: DayOfWeekBitmap) -> DayOfWeekBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DayOfWeekBitmap,
) -> DayOfWeekBitmap
pub const fn symmetric_difference( self, other: DayOfWeekBitmap, ) -> DayOfWeekBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DayOfWeekBitmap
pub const fn complement(self) -> DayOfWeekBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DayOfWeekBitmap
impl DayOfWeekBitmap
Sourcepub const fn iter(&self) -> Iter<DayOfWeekBitmap> ⓘ
pub const fn iter(&self) -> Iter<DayOfWeekBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DayOfWeekBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<DayOfWeekBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.