pub struct DaysMaskMap(/* private fields */);Implementations
Sourceimpl DaysMaskMap
impl DaysMaskMap
pub const SUNDAY: DaysMaskMap
pub const MONDAY: DaysMaskMap
pub const TUESDAY: DaysMaskMap
pub const WEDNESDAY: DaysMaskMap
pub const THURSDAY: DaysMaskMap
pub const FRIDAY: DaysMaskMap
pub const SATURDAY: DaysMaskMap
pub const _INTERNAL_ALL_BITS: DaysMaskMap
Sourceimpl DaysMaskMap
impl DaysMaskMap
Sourcepub const fn empty() -> DaysMaskMap
pub const fn empty() -> DaysMaskMap
Get a flags value with all bits unset.
Sourcepub const fn all() -> DaysMaskMap
pub const fn all() -> DaysMaskMap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<DaysMaskMap>
pub const fn from_bits(bits: u8) -> Option<DaysMaskMap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> DaysMaskMap
pub const fn from_bits_truncate(bits: u8) -> DaysMaskMap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> DaysMaskMap
pub const fn from_bits_retain(bits: u8) -> DaysMaskMap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DaysMaskMap>
pub fn from_name(name: &str) -> Option<DaysMaskMap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DaysMaskMap) -> bool
pub const fn intersects(&self, other: DaysMaskMap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DaysMaskMap) -> bool
pub const fn contains(&self, other: DaysMaskMap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DaysMaskMap)
pub fn insert(&mut self, other: DaysMaskMap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DaysMaskMap)
pub fn remove(&mut self, other: DaysMaskMap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DaysMaskMap)
pub fn toggle(&mut self, other: DaysMaskMap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DaysMaskMap, value: bool)
pub fn set(&mut self, other: DaysMaskMap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: DaysMaskMap) -> DaysMaskMap
pub const fn intersection(self, other: DaysMaskMap) -> DaysMaskMap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: DaysMaskMap) -> DaysMaskMap
pub const fn union(self, other: DaysMaskMap) -> DaysMaskMap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: DaysMaskMap) -> DaysMaskMap
pub const fn difference(self, other: DaysMaskMap) -> DaysMaskMap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: DaysMaskMap) -> DaysMaskMap
pub const fn symmetric_difference(self, other: DaysMaskMap) -> DaysMaskMap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DaysMaskMap
pub const fn complement(self) -> DaysMaskMap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DaysMaskMap
impl DaysMaskMap
Sourcepub const fn iter(&self) -> Iter<DaysMaskMap> ⓘ
pub const fn iter(&self) -> Iter<DaysMaskMap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DaysMaskMap> ⓘ
pub const fn iter_names(&self) -> IterNames<DaysMaskMap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.