pub struct DlDefaultConfigurationRegister(/* private fields */);Implementations
Sourceimpl DlDefaultConfigurationRegister
impl DlDefaultConfigurationRegister
pub const ENABLE_LOCAL_PROGRAMMING_ENABLED: DlDefaultConfigurationRegister
pub const KEYPAD_INTERFACE_DEFAULT_ACCESS_ENABLED: DlDefaultConfigurationRegister
pub const REMOTE_INTERFACE_DEFAULT_ACCESS_IS_ENABLED: DlDefaultConfigurationRegister
pub const SOUND_ENABLED: DlDefaultConfigurationRegister
pub const AUTO_RELOCK_TIME_SET: DlDefaultConfigurationRegister
pub const LED_SETTINGS_SET: DlDefaultConfigurationRegister
pub const _INTERNAL_ALL_BITS: DlDefaultConfigurationRegister
Sourceimpl DlDefaultConfigurationRegister
impl DlDefaultConfigurationRegister
Sourcepub const fn empty() -> DlDefaultConfigurationRegister
pub const fn empty() -> DlDefaultConfigurationRegister
Get a flags value with all bits unset.
Sourcepub const fn all() -> DlDefaultConfigurationRegister
pub const fn all() -> DlDefaultConfigurationRegister
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<DlDefaultConfigurationRegister>
pub const fn from_bits(bits: u16) -> Option<DlDefaultConfigurationRegister>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> DlDefaultConfigurationRegister
pub const fn from_bits_truncate(bits: u16) -> DlDefaultConfigurationRegister
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> DlDefaultConfigurationRegister
pub const fn from_bits_retain(bits: u16) -> DlDefaultConfigurationRegister
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DlDefaultConfigurationRegister>
pub fn from_name(name: &str) -> Option<DlDefaultConfigurationRegister>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DlDefaultConfigurationRegister) -> bool
pub const fn intersects(&self, other: DlDefaultConfigurationRegister) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DlDefaultConfigurationRegister) -> bool
pub const fn contains(&self, other: DlDefaultConfigurationRegister) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DlDefaultConfigurationRegister)
pub fn insert(&mut self, other: DlDefaultConfigurationRegister)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DlDefaultConfigurationRegister)
pub fn remove(&mut self, other: DlDefaultConfigurationRegister)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DlDefaultConfigurationRegister)
pub fn toggle(&mut self, other: DlDefaultConfigurationRegister)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DlDefaultConfigurationRegister, value: bool)
pub fn set(&mut self, other: DlDefaultConfigurationRegister, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DlDefaultConfigurationRegister,
) -> DlDefaultConfigurationRegister
pub const fn intersection( self, other: DlDefaultConfigurationRegister, ) -> DlDefaultConfigurationRegister
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DlDefaultConfigurationRegister,
) -> DlDefaultConfigurationRegister
pub const fn union( self, other: DlDefaultConfigurationRegister, ) -> DlDefaultConfigurationRegister
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DlDefaultConfigurationRegister,
) -> DlDefaultConfigurationRegister
pub const fn difference( self, other: DlDefaultConfigurationRegister, ) -> DlDefaultConfigurationRegister
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DlDefaultConfigurationRegister,
) -> DlDefaultConfigurationRegister
pub const fn symmetric_difference( self, other: DlDefaultConfigurationRegister, ) -> DlDefaultConfigurationRegister
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DlDefaultConfigurationRegister
pub const fn complement(self) -> DlDefaultConfigurationRegister
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DlDefaultConfigurationRegister
impl DlDefaultConfigurationRegister
Sourcepub const fn iter(&self) -> Iter<DlDefaultConfigurationRegister> ⓘ
pub const fn iter(&self) -> Iter<DlDefaultConfigurationRegister> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DlDefaultConfigurationRegister> ⓘ
pub const fn iter_names(&self) -> IterNames<DlDefaultConfigurationRegister> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.