pub struct DlKeypadOperationEventMask(/* private fields */);Implementations
Sourceimpl DlKeypadOperationEventMask
impl DlKeypadOperationEventMask
pub const UNKNOWN: DlKeypadOperationEventMask
pub const LOCK: DlKeypadOperationEventMask
pub const UNLOCK: DlKeypadOperationEventMask
pub const LOCK_INVALID_PIN: DlKeypadOperationEventMask
pub const LOCK_INVALID_SCHEDULE: DlKeypadOperationEventMask
pub const UNLOCK_INVALID_CODE: DlKeypadOperationEventMask
pub const UNLOCK_INVALID_SCHEDULE: DlKeypadOperationEventMask
pub const NON_ACCESS_USER_OP_EVENT: DlKeypadOperationEventMask
pub const _INTERNAL_ALL_BITS: DlKeypadOperationEventMask
Sourceimpl DlKeypadOperationEventMask
impl DlKeypadOperationEventMask
Sourcepub const fn empty() -> DlKeypadOperationEventMask
pub const fn empty() -> DlKeypadOperationEventMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> DlKeypadOperationEventMask
pub const fn all() -> DlKeypadOperationEventMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<DlKeypadOperationEventMask>
pub const fn from_bits(bits: u16) -> Option<DlKeypadOperationEventMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> DlKeypadOperationEventMask
pub const fn from_bits_truncate(bits: u16) -> DlKeypadOperationEventMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> DlKeypadOperationEventMask
pub const fn from_bits_retain(bits: u16) -> DlKeypadOperationEventMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DlKeypadOperationEventMask>
pub fn from_name(name: &str) -> Option<DlKeypadOperationEventMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DlKeypadOperationEventMask) -> bool
pub const fn intersects(&self, other: DlKeypadOperationEventMask) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DlKeypadOperationEventMask) -> bool
pub const fn contains(&self, other: DlKeypadOperationEventMask) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DlKeypadOperationEventMask)
pub fn insert(&mut self, other: DlKeypadOperationEventMask)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DlKeypadOperationEventMask)
pub fn remove(&mut self, other: DlKeypadOperationEventMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DlKeypadOperationEventMask)
pub fn toggle(&mut self, other: DlKeypadOperationEventMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DlKeypadOperationEventMask, value: bool)
pub fn set(&mut self, other: DlKeypadOperationEventMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DlKeypadOperationEventMask,
) -> DlKeypadOperationEventMask
pub const fn intersection( self, other: DlKeypadOperationEventMask, ) -> DlKeypadOperationEventMask
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DlKeypadOperationEventMask,
) -> DlKeypadOperationEventMask
pub const fn union( self, other: DlKeypadOperationEventMask, ) -> DlKeypadOperationEventMask
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DlKeypadOperationEventMask,
) -> DlKeypadOperationEventMask
pub const fn difference( self, other: DlKeypadOperationEventMask, ) -> DlKeypadOperationEventMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DlKeypadOperationEventMask,
) -> DlKeypadOperationEventMask
pub const fn symmetric_difference( self, other: DlKeypadOperationEventMask, ) -> DlKeypadOperationEventMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DlKeypadOperationEventMask
pub const fn complement(self) -> DlKeypadOperationEventMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DlKeypadOperationEventMask
impl DlKeypadOperationEventMask
Sourcepub const fn iter(&self) -> Iter<DlKeypadOperationEventMask> ⓘ
pub const fn iter(&self) -> Iter<DlKeypadOperationEventMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DlKeypadOperationEventMask> ⓘ
pub const fn iter_names(&self) -> IterNames<DlKeypadOperationEventMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.