pub struct DlKeypadProgrammingEventMask(/* private fields */);Implementations
Sourceimpl DlKeypadProgrammingEventMask
impl DlKeypadProgrammingEventMask
pub const UNKNOWN: DlKeypadProgrammingEventMask
pub const PROGRAMMING_PIN_CHANGED: DlKeypadProgrammingEventMask
pub const PIN_ADDED: DlKeypadProgrammingEventMask
pub const PIN_CLEARED: DlKeypadProgrammingEventMask
pub const PIN_CHANGED: DlKeypadProgrammingEventMask
pub const _INTERNAL_ALL_BITS: DlKeypadProgrammingEventMask
Sourceimpl DlKeypadProgrammingEventMask
impl DlKeypadProgrammingEventMask
Sourcepub const fn empty() -> DlKeypadProgrammingEventMask
pub const fn empty() -> DlKeypadProgrammingEventMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> DlKeypadProgrammingEventMask
pub const fn all() -> DlKeypadProgrammingEventMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<DlKeypadProgrammingEventMask>
pub const fn from_bits(bits: u16) -> Option<DlKeypadProgrammingEventMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> DlKeypadProgrammingEventMask
pub const fn from_bits_truncate(bits: u16) -> DlKeypadProgrammingEventMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> DlKeypadProgrammingEventMask
pub const fn from_bits_retain(bits: u16) -> DlKeypadProgrammingEventMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DlKeypadProgrammingEventMask>
pub fn from_name(name: &str) -> Option<DlKeypadProgrammingEventMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DlKeypadProgrammingEventMask) -> bool
pub const fn intersects(&self, other: DlKeypadProgrammingEventMask) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DlKeypadProgrammingEventMask) -> bool
pub const fn contains(&self, other: DlKeypadProgrammingEventMask) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DlKeypadProgrammingEventMask)
pub fn insert(&mut self, other: DlKeypadProgrammingEventMask)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DlKeypadProgrammingEventMask)
pub fn remove(&mut self, other: DlKeypadProgrammingEventMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DlKeypadProgrammingEventMask)
pub fn toggle(&mut self, other: DlKeypadProgrammingEventMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DlKeypadProgrammingEventMask, value: bool)
pub fn set(&mut self, other: DlKeypadProgrammingEventMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DlKeypadProgrammingEventMask,
) -> DlKeypadProgrammingEventMask
pub const fn intersection( self, other: DlKeypadProgrammingEventMask, ) -> DlKeypadProgrammingEventMask
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DlKeypadProgrammingEventMask,
) -> DlKeypadProgrammingEventMask
pub const fn union( self, other: DlKeypadProgrammingEventMask, ) -> DlKeypadProgrammingEventMask
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DlKeypadProgrammingEventMask,
) -> DlKeypadProgrammingEventMask
pub const fn difference( self, other: DlKeypadProgrammingEventMask, ) -> DlKeypadProgrammingEventMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DlKeypadProgrammingEventMask,
) -> DlKeypadProgrammingEventMask
pub const fn symmetric_difference( self, other: DlKeypadProgrammingEventMask, ) -> DlKeypadProgrammingEventMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DlKeypadProgrammingEventMask
pub const fn complement(self) -> DlKeypadProgrammingEventMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DlKeypadProgrammingEventMask
impl DlKeypadProgrammingEventMask
Sourcepub const fn iter(&self) -> Iter<DlKeypadProgrammingEventMask> ⓘ
pub const fn iter(&self) -> Iter<DlKeypadProgrammingEventMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DlKeypadProgrammingEventMask> ⓘ
pub const fn iter_names(&self) -> IterNames<DlKeypadProgrammingEventMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.