pub struct DlLocalProgrammingFeatures(/* private fields */);Implementations
Sourceimpl DlLocalProgrammingFeatures
impl DlLocalProgrammingFeatures
pub const ADD_USERS_CREDENTIALS_SCHEDULES_LOCALLY: DlLocalProgrammingFeatures
pub const MODIFY_USERS_CREDENTIALS_SCHEDULES_LOCALLY: DlLocalProgrammingFeatures
pub const CLEAR_USERS_CREDENTIALS_SCHEDULES_LOCALLY: DlLocalProgrammingFeatures
pub const ADJUST_LOCK_SETTINGS_LOCALLY: DlLocalProgrammingFeatures
pub const _INTERNAL_ALL_BITS: DlLocalProgrammingFeatures
Sourceimpl DlLocalProgrammingFeatures
impl DlLocalProgrammingFeatures
Sourcepub const fn empty() -> DlLocalProgrammingFeatures
pub const fn empty() -> DlLocalProgrammingFeatures
Get a flags value with all bits unset.
Sourcepub const fn all() -> DlLocalProgrammingFeatures
pub const fn all() -> DlLocalProgrammingFeatures
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<DlLocalProgrammingFeatures>
pub const fn from_bits(bits: u8) -> Option<DlLocalProgrammingFeatures>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> DlLocalProgrammingFeatures
pub const fn from_bits_truncate(bits: u8) -> DlLocalProgrammingFeatures
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> DlLocalProgrammingFeatures
pub const fn from_bits_retain(bits: u8) -> DlLocalProgrammingFeatures
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DlLocalProgrammingFeatures>
pub fn from_name(name: &str) -> Option<DlLocalProgrammingFeatures>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DlLocalProgrammingFeatures) -> bool
pub const fn intersects(&self, other: DlLocalProgrammingFeatures) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DlLocalProgrammingFeatures) -> bool
pub const fn contains(&self, other: DlLocalProgrammingFeatures) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DlLocalProgrammingFeatures)
pub fn insert(&mut self, other: DlLocalProgrammingFeatures)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DlLocalProgrammingFeatures)
pub fn remove(&mut self, other: DlLocalProgrammingFeatures)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DlLocalProgrammingFeatures)
pub fn toggle(&mut self, other: DlLocalProgrammingFeatures)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DlLocalProgrammingFeatures, value: bool)
pub fn set(&mut self, other: DlLocalProgrammingFeatures, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DlLocalProgrammingFeatures,
) -> DlLocalProgrammingFeatures
pub const fn intersection( self, other: DlLocalProgrammingFeatures, ) -> DlLocalProgrammingFeatures
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DlLocalProgrammingFeatures,
) -> DlLocalProgrammingFeatures
pub const fn union( self, other: DlLocalProgrammingFeatures, ) -> DlLocalProgrammingFeatures
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DlLocalProgrammingFeatures,
) -> DlLocalProgrammingFeatures
pub const fn difference( self, other: DlLocalProgrammingFeatures, ) -> DlLocalProgrammingFeatures
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DlLocalProgrammingFeatures,
) -> DlLocalProgrammingFeatures
pub const fn symmetric_difference( self, other: DlLocalProgrammingFeatures, ) -> DlLocalProgrammingFeatures
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DlLocalProgrammingFeatures
pub const fn complement(self) -> DlLocalProgrammingFeatures
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DlLocalProgrammingFeatures
impl DlLocalProgrammingFeatures
Sourcepub const fn iter(&self) -> Iter<DlLocalProgrammingFeatures> ⓘ
pub const fn iter(&self) -> Iter<DlLocalProgrammingFeatures> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DlLocalProgrammingFeatures> ⓘ
pub const fn iter_names(&self) -> IterNames<DlLocalProgrammingFeatures> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.