pub struct DlRemoteOperationEventMask(/* private fields */);Implementations
Sourceimpl DlRemoteOperationEventMask
impl DlRemoteOperationEventMask
pub const UNKNOWN: DlRemoteOperationEventMask
pub const LOCK: DlRemoteOperationEventMask
pub const UNLOCK: DlRemoteOperationEventMask
pub const LOCK_INVALID_CODE: DlRemoteOperationEventMask
pub const LOCK_INVALID_SCHEDULE: DlRemoteOperationEventMask
pub const UNLOCK_INVALID_CODE: DlRemoteOperationEventMask
pub const UNLOCK_INVALID_SCHEDULE: DlRemoteOperationEventMask
pub const _INTERNAL_ALL_BITS: DlRemoteOperationEventMask
Sourceimpl DlRemoteOperationEventMask
impl DlRemoteOperationEventMask
Sourcepub const fn empty() -> DlRemoteOperationEventMask
pub const fn empty() -> DlRemoteOperationEventMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> DlRemoteOperationEventMask
pub const fn all() -> DlRemoteOperationEventMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<DlRemoteOperationEventMask>
pub const fn from_bits(bits: u16) -> Option<DlRemoteOperationEventMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> DlRemoteOperationEventMask
pub const fn from_bits_truncate(bits: u16) -> DlRemoteOperationEventMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> DlRemoteOperationEventMask
pub const fn from_bits_retain(bits: u16) -> DlRemoteOperationEventMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DlRemoteOperationEventMask>
pub fn from_name(name: &str) -> Option<DlRemoteOperationEventMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DlRemoteOperationEventMask) -> bool
pub const fn intersects(&self, other: DlRemoteOperationEventMask) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DlRemoteOperationEventMask) -> bool
pub const fn contains(&self, other: DlRemoteOperationEventMask) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DlRemoteOperationEventMask)
pub fn insert(&mut self, other: DlRemoteOperationEventMask)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DlRemoteOperationEventMask)
pub fn remove(&mut self, other: DlRemoteOperationEventMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DlRemoteOperationEventMask)
pub fn toggle(&mut self, other: DlRemoteOperationEventMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DlRemoteOperationEventMask, value: bool)
pub fn set(&mut self, other: DlRemoteOperationEventMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DlRemoteOperationEventMask,
) -> DlRemoteOperationEventMask
pub const fn intersection( self, other: DlRemoteOperationEventMask, ) -> DlRemoteOperationEventMask
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DlRemoteOperationEventMask,
) -> DlRemoteOperationEventMask
pub const fn union( self, other: DlRemoteOperationEventMask, ) -> DlRemoteOperationEventMask
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DlRemoteOperationEventMask,
) -> DlRemoteOperationEventMask
pub const fn difference( self, other: DlRemoteOperationEventMask, ) -> DlRemoteOperationEventMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DlRemoteOperationEventMask,
) -> DlRemoteOperationEventMask
pub const fn symmetric_difference( self, other: DlRemoteOperationEventMask, ) -> DlRemoteOperationEventMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DlRemoteOperationEventMask
pub const fn complement(self) -> DlRemoteOperationEventMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DlRemoteOperationEventMask
impl DlRemoteOperationEventMask
Sourcepub const fn iter(&self) -> Iter<DlRemoteOperationEventMask> ⓘ
pub const fn iter(&self) -> Iter<DlRemoteOperationEventMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DlRemoteOperationEventMask> ⓘ
pub const fn iter_names(&self) -> IterNames<DlRemoteOperationEventMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.