pub struct DlRemoteProgrammingEventMask(/* private fields */);Implementations
Sourceimpl DlRemoteProgrammingEventMask
impl DlRemoteProgrammingEventMask
pub const UNKNOWN: DlRemoteProgrammingEventMask
pub const PROGRAMMING_PIN_CHANGED: DlRemoteProgrammingEventMask
pub const PIN_ADDED: DlRemoteProgrammingEventMask
pub const PIN_CLEARED: DlRemoteProgrammingEventMask
pub const PIN_CHANGED: DlRemoteProgrammingEventMask
pub const RFID_CODE_ADDED: DlRemoteProgrammingEventMask
pub const RFID_CODE_CLEARED: DlRemoteProgrammingEventMask
pub const _INTERNAL_ALL_BITS: DlRemoteProgrammingEventMask
Sourceimpl DlRemoteProgrammingEventMask
impl DlRemoteProgrammingEventMask
Sourcepub const fn empty() -> DlRemoteProgrammingEventMask
pub const fn empty() -> DlRemoteProgrammingEventMask
Get a flags value with all bits unset.
Sourcepub const fn all() -> DlRemoteProgrammingEventMask
pub const fn all() -> DlRemoteProgrammingEventMask
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<DlRemoteProgrammingEventMask>
pub const fn from_bits(bits: u16) -> Option<DlRemoteProgrammingEventMask>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> DlRemoteProgrammingEventMask
pub const fn from_bits_truncate(bits: u16) -> DlRemoteProgrammingEventMask
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> DlRemoteProgrammingEventMask
pub const fn from_bits_retain(bits: u16) -> DlRemoteProgrammingEventMask
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<DlRemoteProgrammingEventMask>
pub fn from_name(name: &str) -> Option<DlRemoteProgrammingEventMask>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: DlRemoteProgrammingEventMask) -> bool
pub const fn intersects(&self, other: DlRemoteProgrammingEventMask) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: DlRemoteProgrammingEventMask) -> bool
pub const fn contains(&self, other: DlRemoteProgrammingEventMask) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: DlRemoteProgrammingEventMask)
pub fn insert(&mut self, other: DlRemoteProgrammingEventMask)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: DlRemoteProgrammingEventMask)
pub fn remove(&mut self, other: DlRemoteProgrammingEventMask)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: DlRemoteProgrammingEventMask)
pub fn toggle(&mut self, other: DlRemoteProgrammingEventMask)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: DlRemoteProgrammingEventMask, value: bool)
pub fn set(&mut self, other: DlRemoteProgrammingEventMask, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: DlRemoteProgrammingEventMask,
) -> DlRemoteProgrammingEventMask
pub const fn intersection( self, other: DlRemoteProgrammingEventMask, ) -> DlRemoteProgrammingEventMask
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: DlRemoteProgrammingEventMask,
) -> DlRemoteProgrammingEventMask
pub const fn union( self, other: DlRemoteProgrammingEventMask, ) -> DlRemoteProgrammingEventMask
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: DlRemoteProgrammingEventMask,
) -> DlRemoteProgrammingEventMask
pub const fn difference( self, other: DlRemoteProgrammingEventMask, ) -> DlRemoteProgrammingEventMask
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: DlRemoteProgrammingEventMask,
) -> DlRemoteProgrammingEventMask
pub const fn symmetric_difference( self, other: DlRemoteProgrammingEventMask, ) -> DlRemoteProgrammingEventMask
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> DlRemoteProgrammingEventMask
pub const fn complement(self) -> DlRemoteProgrammingEventMask
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl DlRemoteProgrammingEventMask
impl DlRemoteProgrammingEventMask
Sourcepub const fn iter(&self) -> Iter<DlRemoteProgrammingEventMask> ⓘ
pub const fn iter(&self) -> Iter<DlRemoteProgrammingEventMask> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<DlRemoteProgrammingEventMask> ⓘ
pub const fn iter_names(&self) -> IterNames<DlRemoteProgrammingEventMask> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.