pub struct AlarmBitmap(/* private fields */);Implementations
Sourceimpl AlarmBitmap
impl AlarmBitmap
pub const OVER_VOLTAGE: AlarmBitmap
pub const UNDER_VOLTAGE: AlarmBitmap
pub const SWAPPED_POLARITY: AlarmBitmap
pub const LOSS_OF_MEASUREMENT: AlarmBitmap
pub const LOSS_OF_GRID_POWER: AlarmBitmap
pub const POWER_IMPORTED: AlarmBitmap
pub const POWER_EXPORTED: AlarmBitmap
pub const OVER_FREQUENCY: AlarmBitmap
pub const UNDER_FREQUENCY: AlarmBitmap
pub const OVER_POWER: AlarmBitmap
pub const UNDER_POWER: AlarmBitmap
pub const OVER_CURRENT: AlarmBitmap
pub const UNDER_CURRENT: AlarmBitmap
pub const FREQUENCY_QUALITY: AlarmBitmap
pub const VOLTAGE_QUALITY: AlarmBitmap
pub const _INTERNAL_ALL_BITS: AlarmBitmap
Sourceimpl AlarmBitmap
impl AlarmBitmap
Sourcepub const fn empty() -> AlarmBitmap
pub const fn empty() -> AlarmBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> AlarmBitmap
pub const fn all() -> AlarmBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<AlarmBitmap>
pub const fn from_bits(bits: u64) -> Option<AlarmBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> AlarmBitmap
pub const fn from_bits_truncate(bits: u64) -> AlarmBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> AlarmBitmap
pub const fn from_bits_retain(bits: u64) -> AlarmBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AlarmBitmap>
pub fn from_name(name: &str) -> Option<AlarmBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AlarmBitmap) -> bool
pub const fn intersects(&self, other: AlarmBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: AlarmBitmap) -> bool
pub const fn contains(&self, other: AlarmBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: AlarmBitmap)
pub fn insert(&mut self, other: AlarmBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: AlarmBitmap)
pub fn remove(&mut self, other: AlarmBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AlarmBitmap)
pub fn toggle(&mut self, other: AlarmBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: AlarmBitmap, value: bool)
pub fn set(&mut self, other: AlarmBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AlarmBitmap) -> AlarmBitmap
pub const fn intersection(self, other: AlarmBitmap) -> AlarmBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: AlarmBitmap) -> AlarmBitmap
pub const fn union(self, other: AlarmBitmap) -> AlarmBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: AlarmBitmap) -> AlarmBitmap
pub const fn difference(self, other: AlarmBitmap) -> AlarmBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: AlarmBitmap) -> AlarmBitmap
pub const fn symmetric_difference(self, other: AlarmBitmap) -> AlarmBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> AlarmBitmap
pub const fn complement(self) -> AlarmBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AlarmBitmap
impl AlarmBitmap
Sourcepub const fn iter(&self) -> Iter<AlarmBitmap> ⓘ
pub const fn iter(&self) -> Iter<AlarmBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AlarmBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<AlarmBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.