pub struct SurgeProtectionClassBitmap(/* private fields */);Implementations
Sourceimpl SurgeProtectionClassBitmap
impl SurgeProtectionClassBitmap
pub const CLASS_I: SurgeProtectionClassBitmap
pub const CLASS_II: SurgeProtectionClassBitmap
pub const CLASS_III: SurgeProtectionClassBitmap
pub const _INTERNAL_ALL_BITS: SurgeProtectionClassBitmap
Sourceimpl SurgeProtectionClassBitmap
impl SurgeProtectionClassBitmap
Sourcepub const fn empty() -> SurgeProtectionClassBitmap
pub const fn empty() -> SurgeProtectionClassBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> SurgeProtectionClassBitmap
pub const fn all() -> SurgeProtectionClassBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<SurgeProtectionClassBitmap>
pub const fn from_bits(bits: u16) -> Option<SurgeProtectionClassBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> SurgeProtectionClassBitmap
pub const fn from_bits_truncate(bits: u16) -> SurgeProtectionClassBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> SurgeProtectionClassBitmap
pub const fn from_bits_retain(bits: u16) -> SurgeProtectionClassBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SurgeProtectionClassBitmap>
pub fn from_name(name: &str) -> Option<SurgeProtectionClassBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SurgeProtectionClassBitmap) -> bool
pub const fn intersects(&self, other: SurgeProtectionClassBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SurgeProtectionClassBitmap) -> bool
pub const fn contains(&self, other: SurgeProtectionClassBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SurgeProtectionClassBitmap)
pub fn insert(&mut self, other: SurgeProtectionClassBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SurgeProtectionClassBitmap)
pub fn remove(&mut self, other: SurgeProtectionClassBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SurgeProtectionClassBitmap)
pub fn toggle(&mut self, other: SurgeProtectionClassBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SurgeProtectionClassBitmap, value: bool)
pub fn set(&mut self, other: SurgeProtectionClassBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: SurgeProtectionClassBitmap,
) -> SurgeProtectionClassBitmap
pub const fn intersection( self, other: SurgeProtectionClassBitmap, ) -> SurgeProtectionClassBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: SurgeProtectionClassBitmap,
) -> SurgeProtectionClassBitmap
pub const fn union( self, other: SurgeProtectionClassBitmap, ) -> SurgeProtectionClassBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: SurgeProtectionClassBitmap,
) -> SurgeProtectionClassBitmap
pub const fn difference( self, other: SurgeProtectionClassBitmap, ) -> SurgeProtectionClassBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: SurgeProtectionClassBitmap,
) -> SurgeProtectionClassBitmap
pub const fn symmetric_difference( self, other: SurgeProtectionClassBitmap, ) -> SurgeProtectionClassBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SurgeProtectionClassBitmap
pub const fn complement(self) -> SurgeProtectionClassBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SurgeProtectionClassBitmap
impl SurgeProtectionClassBitmap
Sourcepub const fn iter(&self) -> Iter<SurgeProtectionClassBitmap> ⓘ
pub const fn iter(&self) -> Iter<SurgeProtectionClassBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SurgeProtectionClassBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<SurgeProtectionClassBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.