pub struct RockBitmap(/* private fields */);Implementations
Sourceimpl RockBitmap
impl RockBitmap
pub const ROCK_LEFT_RIGHT: RockBitmap
pub const ROCK_UP_DOWN: RockBitmap
pub const ROCK_ROUND: RockBitmap
pub const _INTERNAL_ALL_BITS: RockBitmap
Sourceimpl RockBitmap
impl RockBitmap
Sourcepub const fn empty() -> RockBitmap
pub const fn empty() -> RockBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> RockBitmap
pub const fn all() -> RockBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<RockBitmap>
pub const fn from_bits(bits: u8) -> Option<RockBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> RockBitmap
pub const fn from_bits_truncate(bits: u8) -> RockBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> RockBitmap
pub const fn from_bits_retain(bits: u8) -> RockBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RockBitmap>
pub fn from_name(name: &str) -> Option<RockBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RockBitmap) -> bool
pub const fn intersects(&self, other: RockBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RockBitmap) -> bool
pub const fn contains(&self, other: RockBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RockBitmap)
pub fn insert(&mut self, other: RockBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RockBitmap)
pub fn remove(&mut self, other: RockBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RockBitmap)
pub fn toggle(&mut self, other: RockBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RockBitmap, value: bool)
pub fn set(&mut self, other: RockBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: RockBitmap) -> RockBitmap
pub const fn intersection(self, other: RockBitmap) -> RockBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: RockBitmap) -> RockBitmap
pub const fn union(self, other: RockBitmap) -> RockBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: RockBitmap) -> RockBitmap
pub const fn difference(self, other: RockBitmap) -> RockBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: RockBitmap) -> RockBitmap
pub const fn symmetric_difference(self, other: RockBitmap) -> RockBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RockBitmap
pub const fn complement(self) -> RockBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RockBitmap
impl RockBitmap
Sourcepub const fn iter(&self) -> Iter<RockBitmap> ⓘ
pub const fn iter(&self) -> Iter<RockBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RockBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<RockBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.