pub struct OptionsBitmap(/* private fields */);Implementations
Sourceimpl OptionsBitmap
impl OptionsBitmap
pub const EXECUTE_IF_OFF: OptionsBitmap
pub const COUPLE_COLOR_TEMP_TO_LEVEL: OptionsBitmap
pub const _INTERNAL_ALL_BITS: OptionsBitmap
Sourceimpl OptionsBitmap
impl OptionsBitmap
Sourcepub const fn empty() -> OptionsBitmap
pub const fn empty() -> OptionsBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> OptionsBitmap
pub const fn all() -> OptionsBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<OptionsBitmap>
pub const fn from_bits(bits: u8) -> Option<OptionsBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> OptionsBitmap
pub const fn from_bits_truncate(bits: u8) -> OptionsBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> OptionsBitmap
pub const fn from_bits_retain(bits: u8) -> OptionsBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<OptionsBitmap>
pub fn from_name(name: &str) -> Option<OptionsBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: OptionsBitmap) -> bool
pub const fn intersects(&self, other: OptionsBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: OptionsBitmap) -> bool
pub const fn contains(&self, other: OptionsBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: OptionsBitmap)
pub fn insert(&mut self, other: OptionsBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: OptionsBitmap)
pub fn remove(&mut self, other: OptionsBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: OptionsBitmap)
pub fn toggle(&mut self, other: OptionsBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: OptionsBitmap, value: bool)
pub fn set(&mut self, other: OptionsBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: OptionsBitmap) -> OptionsBitmap
pub const fn intersection(self, other: OptionsBitmap) -> OptionsBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: OptionsBitmap) -> OptionsBitmap
pub const fn union(self, other: OptionsBitmap) -> OptionsBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: OptionsBitmap) -> OptionsBitmap
pub const fn difference(self, other: OptionsBitmap) -> OptionsBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: OptionsBitmap) -> OptionsBitmap
pub const fn symmetric_difference(self, other: OptionsBitmap) -> OptionsBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> OptionsBitmap
pub const fn complement(self) -> OptionsBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl OptionsBitmap
impl OptionsBitmap
Sourcepub const fn iter(&self) -> Iter<OptionsBitmap> ⓘ
pub const fn iter(&self) -> Iter<OptionsBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<OptionsBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<OptionsBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.