pub struct MessageControlBitmap(/* private fields */);Implementations
Sourceimpl MessageControlBitmap
impl MessageControlBitmap
pub const CONFIRMATION_REQUIRED: MessageControlBitmap
pub const RESPONSE_REQUIRED: MessageControlBitmap
pub const REPLY_MESSAGE: MessageControlBitmap
pub const MESSAGE_CONFIRMED: MessageControlBitmap
pub const MESSAGE_PROTECTED: MessageControlBitmap
pub const _INTERNAL_ALL_BITS: MessageControlBitmap
Sourceimpl MessageControlBitmap
impl MessageControlBitmap
Sourcepub const fn empty() -> MessageControlBitmap
pub const fn empty() -> MessageControlBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> MessageControlBitmap
pub const fn all() -> MessageControlBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<MessageControlBitmap>
pub const fn from_bits(bits: u8) -> Option<MessageControlBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> MessageControlBitmap
pub const fn from_bits_truncate(bits: u8) -> MessageControlBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> MessageControlBitmap
pub const fn from_bits_retain(bits: u8) -> MessageControlBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MessageControlBitmap>
pub fn from_name(name: &str) -> Option<MessageControlBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MessageControlBitmap) -> bool
pub const fn intersects(&self, other: MessageControlBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: MessageControlBitmap) -> bool
pub const fn contains(&self, other: MessageControlBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: MessageControlBitmap)
pub fn insert(&mut self, other: MessageControlBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: MessageControlBitmap)
pub fn remove(&mut self, other: MessageControlBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MessageControlBitmap)
pub fn toggle(&mut self, other: MessageControlBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: MessageControlBitmap, value: bool)
pub fn set(&mut self, other: MessageControlBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: MessageControlBitmap,
) -> MessageControlBitmap
pub const fn intersection( self, other: MessageControlBitmap, ) -> MessageControlBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: MessageControlBitmap) -> MessageControlBitmap
pub const fn union(self, other: MessageControlBitmap) -> MessageControlBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: MessageControlBitmap,
) -> MessageControlBitmap
pub const fn difference( self, other: MessageControlBitmap, ) -> MessageControlBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: MessageControlBitmap,
) -> MessageControlBitmap
pub const fn symmetric_difference( self, other: MessageControlBitmap, ) -> MessageControlBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> MessageControlBitmap
pub const fn complement(self) -> MessageControlBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl MessageControlBitmap
impl MessageControlBitmap
Sourcepub const fn iter(&self) -> Iter<MessageControlBitmap> ⓘ
pub const fn iter(&self) -> Iter<MessageControlBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<MessageControlBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<MessageControlBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.