pub struct MeterIdentificationClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the MeterIdentification cluster’s client operations. Returned by MeterIdentificationClient::meter_identification. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> MeterIdentificationClientView<'a>
impl<'a> MeterIdentificationClientView<'a>
pub async fn meter_type_read( self, endpoint: u16, ) -> Result<Maybe<MeterTypeEnum, AsNullable>, Error>
Sourcepub async fn point_of_delivery_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn point_of_delivery_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn meter_serial_number_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn meter_serial_number_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn protocol_version_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn protocol_version_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn power_threshold_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<PowerThresholdStruct<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn power_threshold_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<PowerThresholdStruct<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>