pub struct OnOffClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the OnOff cluster’s client operations. Returned by OnOffClient::on_off. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> OnOffClientView<'a>
impl<'a> OnOffClientView<'a>
pub async fn off(self, endpoint: u16) -> Result<(), Error>
pub async fn on(self, endpoint: u16) -> Result<(), Error>
pub async fn toggle(self, endpoint: u16) -> Result<(), Error>
pub async fn off_with_effect<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(OffWithEffectRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn on_with_recall_global_scene( self, endpoint: u16, ) -> Result<(), Error>
pub async fn on_with_timed_off<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(OnWithTimedOffRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn on_off_read(self, endpoint: u16) -> Result<bool, Error>
pub async fn global_scene_control_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn on_time_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn off_wait_time_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn start_up_on_off_read( self, endpoint: u16, ) -> Result<Maybe<StartUpOnOffEnum, AsNullable>, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn on_time_write(self, endpoint: u16, value: u16) -> Result<(), Error>
pub async fn off_wait_time_write( self, endpoint: u16, value: u16, ) -> Result<(), Error>
pub async fn start_up_on_off_write( self, endpoint: u16, value: Maybe<StartUpOnOffEnum, AsNullable>, ) -> Result<(), Error>