pub struct OperationalCredentialsClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the OperationalCredentials cluster’s client operations. Returned by OperationalCredentialsClient::operational_credentials. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> OperationalCredentialsClientView<'a>
impl<'a> OperationalCredentialsClientView<'a>
pub async fn attestation_request<F>(
self,
endpoint: u16,
request: F,
) -> Result<AttestationResponseHandle<'a>, Error>where
F: FnMut(AttestationRequestRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn certificate_chain_request<F>(
self,
endpoint: u16,
request: F,
) -> Result<CertificateChainResponseHandle<'a>, Error>where
F: FnMut(CertificateChainRequestRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn csr_request<F>(
self,
endpoint: u16,
request: F,
) -> Result<CSRResponseHandle<'a>, Error>where
F: FnMut(CSRRequestRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn add_noc<F>(
self,
endpoint: u16,
request: F,
) -> Result<NOCResponseHandle<'a>, Error>where
F: FnMut(AddNOCRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn update_noc<F>(
self,
endpoint: u16,
request: F,
) -> Result<NOCResponseHandle<'a>, Error>where
F: FnMut(UpdateNOCRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn update_fabric_label<F>(
self,
endpoint: u16,
request: F,
) -> Result<NOCResponseHandle<'a>, Error>where
F: FnMut(UpdateFabricLabelRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn remove_fabric<F>(
self,
endpoint: u16,
request: F,
) -> Result<NOCResponseHandle<'a>, Error>where
F: FnMut(RemoveFabricRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn add_trusted_root_certificate<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(AddTrustedRootCertificateRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_vid_verification_statement<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetVIDVerificationStatementRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn sign_vid_verification_request<F>(
self,
endpoint: u16,
request: F,
) -> Result<SignVIDVerificationResponseHandle<'a>, Error>where
F: FnMut(SignVIDVerificationRequestRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
Sourcepub async fn nocs_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, NOCStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn nocs_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, NOCStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn fabrics_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, FabricDescriptorStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn fabrics_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, FabricDescriptorStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn supported_fabrics_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn commissioned_fabrics_read(self, endpoint: u16) -> Result<u8, Error>
Sourcepub async fn trusted_root_certificates_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, Octets<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn trusted_root_certificates_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, Octets<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn current_fabric_index_read(self, endpoint: u16) -> Result<u8, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>