pub struct RadioBandBitmap(/* private fields */);Implementations
Sourceimpl RadioBandBitmap
impl RadioBandBitmap
pub const C2_G_4: RadioBandBitmap
pub const C3_G_65: RadioBandBitmap
pub const C5_G: RadioBandBitmap
pub const C6_G: RadioBandBitmap
pub const C60_G: RadioBandBitmap
pub const S_1_G: RadioBandBitmap
pub const C45_G: RadioBandBitmap
pub const _INTERNAL_ALL_BITS: RadioBandBitmap
Sourceimpl RadioBandBitmap
impl RadioBandBitmap
Sourcepub const fn empty() -> RadioBandBitmap
pub const fn empty() -> RadioBandBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> RadioBandBitmap
pub const fn all() -> RadioBandBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<RadioBandBitmap>
pub const fn from_bits(bits: u16) -> Option<RadioBandBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> RadioBandBitmap
pub const fn from_bits_truncate(bits: u16) -> RadioBandBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> RadioBandBitmap
pub const fn from_bits_retain(bits: u16) -> RadioBandBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RadioBandBitmap>
pub fn from_name(name: &str) -> Option<RadioBandBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RadioBandBitmap) -> bool
pub const fn intersects(&self, other: RadioBandBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RadioBandBitmap) -> bool
pub const fn contains(&self, other: RadioBandBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RadioBandBitmap)
pub fn insert(&mut self, other: RadioBandBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RadioBandBitmap)
pub fn remove(&mut self, other: RadioBandBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RadioBandBitmap)
pub fn toggle(&mut self, other: RadioBandBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RadioBandBitmap, value: bool)
pub fn set(&mut self, other: RadioBandBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: RadioBandBitmap) -> RadioBandBitmap
pub const fn intersection(self, other: RadioBandBitmap) -> RadioBandBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: RadioBandBitmap) -> RadioBandBitmap
pub const fn union(self, other: RadioBandBitmap) -> RadioBandBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: RadioBandBitmap) -> RadioBandBitmap
pub const fn difference(self, other: RadioBandBitmap) -> RadioBandBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: RadioBandBitmap,
) -> RadioBandBitmap
pub const fn symmetric_difference( self, other: RadioBandBitmap, ) -> RadioBandBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RadioBandBitmap
pub const fn complement(self) -> RadioBandBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RadioBandBitmap
impl RadioBandBitmap
Sourcepub const fn iter(&self) -> Iter<RadioBandBitmap> ⓘ
pub const fn iter(&self) -> Iter<RadioBandBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RadioBandBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<RadioBandBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.