pub struct RangingBandwidthBitmap(/* private fields */);Implementations
Sourceimpl RangingBandwidthBitmap
impl RangingBandwidthBitmap
pub const C1_M_HZ: RangingBandwidthBitmap
pub const C2_M_HZ: RangingBandwidthBitmap
pub const C4_M_HZ: RangingBandwidthBitmap
pub const C8_M_HZ: RangingBandwidthBitmap
pub const C16_M_HZ: RangingBandwidthBitmap
pub const C20_M_HZ: RangingBandwidthBitmap
pub const C40_M_HZ: RangingBandwidthBitmap
pub const C80_M_HZ: RangingBandwidthBitmap
pub const C160_M_HZ: RangingBandwidthBitmap
pub const C320_M_HZ: RangingBandwidthBitmap
pub const _INTERNAL_ALL_BITS: RangingBandwidthBitmap
Sourceimpl RangingBandwidthBitmap
impl RangingBandwidthBitmap
Sourcepub const fn empty() -> RangingBandwidthBitmap
pub const fn empty() -> RangingBandwidthBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> RangingBandwidthBitmap
pub const fn all() -> RangingBandwidthBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<RangingBandwidthBitmap>
pub const fn from_bits(bits: u32) -> Option<RangingBandwidthBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> RangingBandwidthBitmap
pub const fn from_bits_truncate(bits: u32) -> RangingBandwidthBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> RangingBandwidthBitmap
pub const fn from_bits_retain(bits: u32) -> RangingBandwidthBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RangingBandwidthBitmap>
pub fn from_name(name: &str) -> Option<RangingBandwidthBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RangingBandwidthBitmap) -> bool
pub const fn intersects(&self, other: RangingBandwidthBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RangingBandwidthBitmap) -> bool
pub const fn contains(&self, other: RangingBandwidthBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RangingBandwidthBitmap)
pub fn insert(&mut self, other: RangingBandwidthBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RangingBandwidthBitmap)
pub fn remove(&mut self, other: RangingBandwidthBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RangingBandwidthBitmap)
pub fn toggle(&mut self, other: RangingBandwidthBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RangingBandwidthBitmap, value: bool)
pub fn set(&mut self, other: RangingBandwidthBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: RangingBandwidthBitmap,
) -> RangingBandwidthBitmap
pub const fn intersection( self, other: RangingBandwidthBitmap, ) -> RangingBandwidthBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: RangingBandwidthBitmap,
) -> RangingBandwidthBitmap
pub const fn union( self, other: RangingBandwidthBitmap, ) -> RangingBandwidthBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: RangingBandwidthBitmap,
) -> RangingBandwidthBitmap
pub const fn difference( self, other: RangingBandwidthBitmap, ) -> RangingBandwidthBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: RangingBandwidthBitmap,
) -> RangingBandwidthBitmap
pub const fn symmetric_difference( self, other: RangingBandwidthBitmap, ) -> RangingBandwidthBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RangingBandwidthBitmap
pub const fn complement(self) -> RangingBandwidthBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RangingBandwidthBitmap
impl RangingBandwidthBitmap
Sourcepub const fn iter(&self) -> Iter<RangingBandwidthBitmap> ⓘ
pub const fn iter(&self) -> Iter<RangingBandwidthBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RangingBandwidthBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<RangingBandwidthBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.