pub struct PumpConfigurationAndControlClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the PumpConfigurationAndControl cluster’s client operations. Returned by PumpConfigurationAndControlClient::pump_configuration_and_control. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> PumpConfigurationAndControlClientView<'a>
impl<'a> PumpConfigurationAndControlClientView<'a>
pub async fn max_pressure_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn max_speed_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn max_flow_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn min_const_pressure_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn max_const_pressure_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn min_comp_pressure_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn max_comp_pressure_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn min_const_speed_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn max_const_speed_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn min_const_flow_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn max_const_flow_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn min_const_temp_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn max_const_temp_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn pump_status_read( self, endpoint: u16, ) -> Result<PumpStatusBitmap, Error>
pub async fn effective_operation_mode_read( self, endpoint: u16, ) -> Result<OperationModeEnum, Error>
pub async fn effective_control_mode_read( self, endpoint: u16, ) -> Result<ControlModeEnum, Error>
pub async fn capacity_read( self, endpoint: u16, ) -> Result<Maybe<i16, AsNullable>, Error>
pub async fn speed_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn lifetime_running_hours_read( self, endpoint: u16, ) -> Result<Maybe<u32, AsNullable>, Error>
pub async fn power_read( self, endpoint: u16, ) -> Result<Maybe<u32, AsNullable>, Error>
pub async fn lifetime_energy_consumed_read( self, endpoint: u16, ) -> Result<Maybe<u32, AsNullable>, Error>
pub async fn operation_mode_read( self, endpoint: u16, ) -> Result<OperationModeEnum, Error>
pub async fn control_mode_read( self, endpoint: u16, ) -> Result<ControlModeEnum, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn lifetime_running_hours_write( self, endpoint: u16, value: Maybe<u32, AsNullable>, ) -> Result<(), Error>
pub async fn lifetime_energy_consumed_write( self, endpoint: u16, value: Maybe<u32, AsNullable>, ) -> Result<(), Error>
pub async fn operation_mode_write( self, endpoint: u16, value: OperationModeEnum, ) -> Result<(), Error>
pub async fn control_mode_write( self, endpoint: u16, value: ControlModeEnum, ) -> Result<(), Error>