pub struct PumpStatusBitmap(/* private fields */);Implementations
Sourceimpl PumpStatusBitmap
impl PumpStatusBitmap
pub const DEVICE_FAULT: PumpStatusBitmap
pub const SUPPLY_FAULT: PumpStatusBitmap
pub const SPEED_LOW: PumpStatusBitmap
pub const SPEED_HIGH: PumpStatusBitmap
pub const LOCAL_OVERRIDE: PumpStatusBitmap
pub const RUNNING: PumpStatusBitmap
pub const REMOTE_PRESSURE: PumpStatusBitmap
pub const REMOTE_FLOW: PumpStatusBitmap
pub const REMOTE_TEMPERATURE: PumpStatusBitmap
pub const _INTERNAL_ALL_BITS: PumpStatusBitmap
Sourceimpl PumpStatusBitmap
impl PumpStatusBitmap
Sourcepub const fn empty() -> PumpStatusBitmap
pub const fn empty() -> PumpStatusBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> PumpStatusBitmap
pub const fn all() -> PumpStatusBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<PumpStatusBitmap>
pub const fn from_bits(bits: u16) -> Option<PumpStatusBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> PumpStatusBitmap
pub const fn from_bits_truncate(bits: u16) -> PumpStatusBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> PumpStatusBitmap
pub const fn from_bits_retain(bits: u16) -> PumpStatusBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<PumpStatusBitmap>
pub fn from_name(name: &str) -> Option<PumpStatusBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: PumpStatusBitmap) -> bool
pub const fn intersects(&self, other: PumpStatusBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: PumpStatusBitmap) -> bool
pub const fn contains(&self, other: PumpStatusBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: PumpStatusBitmap)
pub fn insert(&mut self, other: PumpStatusBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: PumpStatusBitmap)
pub fn remove(&mut self, other: PumpStatusBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: PumpStatusBitmap)
pub fn toggle(&mut self, other: PumpStatusBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: PumpStatusBitmap, value: bool)
pub fn set(&mut self, other: PumpStatusBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: PumpStatusBitmap) -> PumpStatusBitmap
pub const fn intersection(self, other: PumpStatusBitmap) -> PumpStatusBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: PumpStatusBitmap) -> PumpStatusBitmap
pub const fn union(self, other: PumpStatusBitmap) -> PumpStatusBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: PumpStatusBitmap) -> PumpStatusBitmap
pub const fn difference(self, other: PumpStatusBitmap) -> PumpStatusBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: PumpStatusBitmap,
) -> PumpStatusBitmap
pub const fn symmetric_difference( self, other: PumpStatusBitmap, ) -> PumpStatusBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> PumpStatusBitmap
pub const fn complement(self) -> PumpStatusBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl PumpStatusBitmap
impl PumpStatusBitmap
Sourcepub const fn iter(&self) -> Iter<PumpStatusBitmap> ⓘ
pub const fn iter(&self) -> Iter<PumpStatusBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<PumpStatusBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<PumpStatusBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.