pub struct Feature(/* private fields */);Implementations
Sourceimpl Feature
impl Feature
pub const SELECT_WHILE_RUNNING: Feature
pub const PROGRESS_REPORTING: Feature
pub const MAPS: Feature
pub const _INTERNAL_ALL_BITS: Feature
Sourceimpl Feature
impl Feature
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Feature>
pub const fn from_bits(bits: u32) -> Option<Feature>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Feature
pub const fn from_bits_truncate(bits: u32) -> Feature
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Feature
pub const fn from_bits_retain(bits: u32) -> Feature
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Feature>
pub fn from_name(name: &str) -> Option<Feature>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Feature) -> bool
pub const fn intersects(&self, other: Feature) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Feature) -> bool
pub const fn contains(&self, other: Feature) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Feature)
pub fn remove(&mut self, other: Feature)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Feature)
pub fn toggle(&mut self, other: Feature)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Feature, value: bool)
pub fn set(&mut self, other: Feature, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Feature) -> Feature
pub const fn intersection(self, other: Feature) -> Feature
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Feature) -> Feature
pub const fn union(self, other: Feature) -> Feature
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Feature) -> Feature
pub const fn difference(self, other: Feature) -> Feature
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Feature) -> Feature
pub const fn symmetric_difference(self, other: Feature) -> Feature
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Feature
pub const fn complement(self) -> Feature
The bitwise negation (!) of the bits in self, truncating the result.