pub struct RelayStateBitmap(/* private fields */);Implementations
Sourceimpl RelayStateBitmap
impl RelayStateBitmap
pub const HEAT: RelayStateBitmap
pub const COOL: RelayStateBitmap
pub const FAN: RelayStateBitmap
pub const HEAT_STAGE_2: RelayStateBitmap
pub const COOL_STAGE_2: RelayStateBitmap
pub const FAN_STAGE_2: RelayStateBitmap
pub const FAN_STAGE_3: RelayStateBitmap
pub const _INTERNAL_ALL_BITS: RelayStateBitmap
Sourceimpl RelayStateBitmap
impl RelayStateBitmap
Sourcepub const fn empty() -> RelayStateBitmap
pub const fn empty() -> RelayStateBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> RelayStateBitmap
pub const fn all() -> RelayStateBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<RelayStateBitmap>
pub const fn from_bits(bits: u16) -> Option<RelayStateBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> RelayStateBitmap
pub const fn from_bits_truncate(bits: u16) -> RelayStateBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> RelayStateBitmap
pub const fn from_bits_retain(bits: u16) -> RelayStateBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<RelayStateBitmap>
pub fn from_name(name: &str) -> Option<RelayStateBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: RelayStateBitmap) -> bool
pub const fn intersects(&self, other: RelayStateBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: RelayStateBitmap) -> bool
pub const fn contains(&self, other: RelayStateBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: RelayStateBitmap)
pub fn insert(&mut self, other: RelayStateBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: RelayStateBitmap)
pub fn remove(&mut self, other: RelayStateBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: RelayStateBitmap)
pub fn toggle(&mut self, other: RelayStateBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: RelayStateBitmap, value: bool)
pub fn set(&mut self, other: RelayStateBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: RelayStateBitmap) -> RelayStateBitmap
pub const fn intersection(self, other: RelayStateBitmap) -> RelayStateBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: RelayStateBitmap) -> RelayStateBitmap
pub const fn union(self, other: RelayStateBitmap) -> RelayStateBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: RelayStateBitmap) -> RelayStateBitmap
pub const fn difference(self, other: RelayStateBitmap) -> RelayStateBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: RelayStateBitmap,
) -> RelayStateBitmap
pub const fn symmetric_difference( self, other: RelayStateBitmap, ) -> RelayStateBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> RelayStateBitmap
pub const fn complement(self) -> RelayStateBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl RelayStateBitmap
impl RelayStateBitmap
Sourcepub const fn iter(&self) -> Iter<RelayStateBitmap> ⓘ
pub const fn iter(&self) -> Iter<RelayStateBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<RelayStateBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<RelayStateBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.