pub struct ScheduleModeBitmap(/* private fields */);Implementations
Sourceimpl ScheduleModeBitmap
impl ScheduleModeBitmap
pub const HEAT_SETPOINT_PRESENT: ScheduleModeBitmap
pub const COOL_SETPOINT_PRESENT: ScheduleModeBitmap
pub const _INTERNAL_ALL_BITS: ScheduleModeBitmap
Sourceimpl ScheduleModeBitmap
impl ScheduleModeBitmap
Sourcepub const fn empty() -> ScheduleModeBitmap
pub const fn empty() -> ScheduleModeBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> ScheduleModeBitmap
pub const fn all() -> ScheduleModeBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ScheduleModeBitmap>
pub const fn from_bits(bits: u8) -> Option<ScheduleModeBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ScheduleModeBitmap
pub const fn from_bits_truncate(bits: u8) -> ScheduleModeBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ScheduleModeBitmap
pub const fn from_bits_retain(bits: u8) -> ScheduleModeBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ScheduleModeBitmap>
pub fn from_name(name: &str) -> Option<ScheduleModeBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ScheduleModeBitmap) -> bool
pub const fn intersects(&self, other: ScheduleModeBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ScheduleModeBitmap) -> bool
pub const fn contains(&self, other: ScheduleModeBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ScheduleModeBitmap)
pub fn insert(&mut self, other: ScheduleModeBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ScheduleModeBitmap)
pub fn remove(&mut self, other: ScheduleModeBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ScheduleModeBitmap)
pub fn toggle(&mut self, other: ScheduleModeBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ScheduleModeBitmap, value: bool)
pub fn set(&mut self, other: ScheduleModeBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ScheduleModeBitmap) -> ScheduleModeBitmap
pub const fn intersection(self, other: ScheduleModeBitmap) -> ScheduleModeBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ScheduleModeBitmap) -> ScheduleModeBitmap
pub const fn union(self, other: ScheduleModeBitmap) -> ScheduleModeBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ScheduleModeBitmap) -> ScheduleModeBitmap
pub const fn difference(self, other: ScheduleModeBitmap) -> ScheduleModeBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ScheduleModeBitmap,
) -> ScheduleModeBitmap
pub const fn symmetric_difference( self, other: ScheduleModeBitmap, ) -> ScheduleModeBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ScheduleModeBitmap
pub const fn complement(self) -> ScheduleModeBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ScheduleModeBitmap
impl ScheduleModeBitmap
Sourcepub const fn iter(&self) -> Iter<ScheduleModeBitmap> ⓘ
pub const fn iter(&self) -> Iter<ScheduleModeBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ScheduleModeBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<ScheduleModeBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.