pub struct ConfigStatus(/* private fields */);Implementations
Sourceimpl ConfigStatus
impl ConfigStatus
pub const OPERATIONAL: ConfigStatus
pub const ONLINE_RESERVED: ConfigStatus
pub const LIFT_MOVEMENT_REVERSED: ConfigStatus
pub const LIFT_POSITION_AWARE: ConfigStatus
pub const TILT_POSITION_AWARE: ConfigStatus
pub const LIFT_ENCODER_CONTROLLED: ConfigStatus
pub const TILT_ENCODER_CONTROLLED: ConfigStatus
pub const _INTERNAL_ALL_BITS: ConfigStatus
Sourceimpl ConfigStatus
impl ConfigStatus
Sourcepub const fn empty() -> ConfigStatus
pub const fn empty() -> ConfigStatus
Get a flags value with all bits unset.
Sourcepub const fn all() -> ConfigStatus
pub const fn all() -> ConfigStatus
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<ConfigStatus>
pub const fn from_bits(bits: u8) -> Option<ConfigStatus>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> ConfigStatus
pub const fn from_bits_truncate(bits: u8) -> ConfigStatus
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> ConfigStatus
pub const fn from_bits_retain(bits: u8) -> ConfigStatus
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ConfigStatus>
pub fn from_name(name: &str) -> Option<ConfigStatus>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ConfigStatus) -> bool
pub const fn intersects(&self, other: ConfigStatus) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ConfigStatus) -> bool
pub const fn contains(&self, other: ConfigStatus) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ConfigStatus)
pub fn insert(&mut self, other: ConfigStatus)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ConfigStatus)
pub fn remove(&mut self, other: ConfigStatus)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ConfigStatus)
pub fn toggle(&mut self, other: ConfigStatus)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ConfigStatus, value: bool)
pub fn set(&mut self, other: ConfigStatus, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ConfigStatus) -> ConfigStatus
pub const fn intersection(self, other: ConfigStatus) -> ConfigStatus
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: ConfigStatus) -> ConfigStatus
pub const fn union(self, other: ConfigStatus) -> ConfigStatus
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: ConfigStatus) -> ConfigStatus
pub const fn difference(self, other: ConfigStatus) -> ConfigStatus
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ConfigStatus) -> ConfigStatus
pub const fn symmetric_difference(self, other: ConfigStatus) -> ConfigStatus
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ConfigStatus
pub const fn complement(self) -> ConfigStatus
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ConfigStatus
impl ConfigStatus
Sourcepub const fn iter(&self) -> Iter<ConfigStatus> ⓘ
pub const fn iter(&self) -> Iter<ConfigStatus> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ConfigStatus> ⓘ
pub const fn iter_names(&self) -> IterNames<ConfigStatus> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.