pub struct OperationalStatus(/* private fields */);Implementations
Sourceimpl OperationalStatus
impl OperationalStatus
pub const GLOBAL: OperationalStatus
pub const LIFT: OperationalStatus
pub const TILT: OperationalStatus
pub const _INTERNAL_ALL_BITS: OperationalStatus
Sourceimpl OperationalStatus
impl OperationalStatus
Sourcepub const fn empty() -> OperationalStatus
pub const fn empty() -> OperationalStatus
Get a flags value with all bits unset.
Sourcepub const fn all() -> OperationalStatus
pub const fn all() -> OperationalStatus
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<OperationalStatus>
pub const fn from_bits(bits: u8) -> Option<OperationalStatus>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> OperationalStatus
pub const fn from_bits_truncate(bits: u8) -> OperationalStatus
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> OperationalStatus
pub const fn from_bits_retain(bits: u8) -> OperationalStatus
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<OperationalStatus>
pub fn from_name(name: &str) -> Option<OperationalStatus>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: OperationalStatus) -> bool
pub const fn intersects(&self, other: OperationalStatus) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: OperationalStatus) -> bool
pub const fn contains(&self, other: OperationalStatus) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: OperationalStatus)
pub fn insert(&mut self, other: OperationalStatus)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: OperationalStatus)
pub fn remove(&mut self, other: OperationalStatus)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: OperationalStatus)
pub fn toggle(&mut self, other: OperationalStatus)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: OperationalStatus, value: bool)
pub fn set(&mut self, other: OperationalStatus, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: OperationalStatus) -> OperationalStatus
pub const fn intersection(self, other: OperationalStatus) -> OperationalStatus
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: OperationalStatus) -> OperationalStatus
pub const fn union(self, other: OperationalStatus) -> OperationalStatus
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: OperationalStatus) -> OperationalStatus
pub const fn difference(self, other: OperationalStatus) -> OperationalStatus
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: OperationalStatus,
) -> OperationalStatus
pub const fn symmetric_difference( self, other: OperationalStatus, ) -> OperationalStatus
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> OperationalStatus
pub const fn complement(self) -> OperationalStatus
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl OperationalStatus
impl OperationalStatus
Sourcepub const fn iter(&self) -> Iter<OperationalStatus> ⓘ
pub const fn iter(&self) -> Iter<OperationalStatus> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<OperationalStatus> ⓘ
pub const fn iter_names(&self) -> IterNames<OperationalStatus> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.