pub struct SafetyStatus(/* private fields */);Implementations
Sourceimpl SafetyStatus
impl SafetyStatus
pub const REMOTE_LOCKOUT: SafetyStatus
pub const TAMPER_DETECTION: SafetyStatus
pub const FAILED_COMMUNICATION: SafetyStatus
pub const POSITION_FAILURE: SafetyStatus
pub const THERMAL_PROTECTION: SafetyStatus
pub const OBSTACLE_DETECTED: SafetyStatus
pub const POWER: SafetyStatus
pub const STOP_INPUT: SafetyStatus
pub const MOTOR_JAMMED: SafetyStatus
pub const HARDWARE_FAILURE: SafetyStatus
pub const MANUAL_OPERATION: SafetyStatus
pub const PROTECTION: SafetyStatus
pub const _INTERNAL_ALL_BITS: SafetyStatus
Sourceimpl SafetyStatus
impl SafetyStatus
Sourcepub const fn empty() -> SafetyStatus
pub const fn empty() -> SafetyStatus
Get a flags value with all bits unset.
Sourcepub const fn all() -> SafetyStatus
pub const fn all() -> SafetyStatus
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<SafetyStatus>
pub const fn from_bits(bits: u16) -> Option<SafetyStatus>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> SafetyStatus
pub const fn from_bits_truncate(bits: u16) -> SafetyStatus
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> SafetyStatus
pub const fn from_bits_retain(bits: u16) -> SafetyStatus
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SafetyStatus>
pub fn from_name(name: &str) -> Option<SafetyStatus>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SafetyStatus) -> bool
pub const fn intersects(&self, other: SafetyStatus) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: SafetyStatus) -> bool
pub const fn contains(&self, other: SafetyStatus) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: SafetyStatus)
pub fn insert(&mut self, other: SafetyStatus)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: SafetyStatus)
pub fn remove(&mut self, other: SafetyStatus)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SafetyStatus)
pub fn toggle(&mut self, other: SafetyStatus)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: SafetyStatus, value: bool)
pub fn set(&mut self, other: SafetyStatus, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SafetyStatus) -> SafetyStatus
pub const fn intersection(self, other: SafetyStatus) -> SafetyStatus
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: SafetyStatus) -> SafetyStatus
pub const fn union(self, other: SafetyStatus) -> SafetyStatus
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: SafetyStatus) -> SafetyStatus
pub const fn difference(self, other: SafetyStatus) -> SafetyStatus
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SafetyStatus) -> SafetyStatus
pub const fn symmetric_difference(self, other: SafetyStatus) -> SafetyStatus
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> SafetyStatus
pub const fn complement(self) -> SafetyStatus
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl SafetyStatus
impl SafetyStatus
Sourcepub const fn iter(&self) -> Iter<SafetyStatus> ⓘ
pub const fn iter(&self) -> Iter<SafetyStatus> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SafetyStatus> ⓘ
pub const fn iter_names(&self) -> IterNames<SafetyStatus> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.