pub struct WindowCoveringClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the WindowCovering cluster’s client operations. Returned by WindowCoveringClient::window_covering. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> WindowCoveringClientView<'a>
impl<'a> WindowCoveringClientView<'a>
pub async fn up_or_open(self, endpoint: u16) -> Result<(), Error>
pub async fn down_or_close(self, endpoint: u16) -> Result<(), Error>
pub async fn stop_motion(self, endpoint: u16) -> Result<(), Error>
pub async fn go_to_lift_value<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(GoToLiftValueRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn go_to_lift_percentage<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(GoToLiftPercentageRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn go_to_tilt_value<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(GoToTiltValueRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn go_to_tilt_percentage<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(GoToTiltPercentageRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn type_read(self, endpoint: u16) -> Result<Type, Error>
pub async fn physical_closed_limit_lift_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn physical_closed_limit_tilt_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn current_position_lift_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn current_position_tilt_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn number_of_actuations_lift_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn number_of_actuations_tilt_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn config_status_read( self, endpoint: u16, ) -> Result<ConfigStatus, Error>
pub async fn current_position_lift_percentage_read( self, endpoint: u16, ) -> Result<Maybe<u8, AsNullable>, Error>
pub async fn current_position_tilt_percentage_read( self, endpoint: u16, ) -> Result<Maybe<u8, AsNullable>, Error>
pub async fn operational_status_read( self, endpoint: u16, ) -> Result<OperationalStatus, Error>
pub async fn target_position_lift_percent_100_ths_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn target_position_tilt_percent_100_ths_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn end_product_type_read( self, endpoint: u16, ) -> Result<EndProductType, Error>
pub async fn current_position_lift_percent_100_ths_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn current_position_tilt_percent_100_ths_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn installed_open_limit_lift_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn installed_closed_limit_lift_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn installed_open_limit_tilt_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn installed_closed_limit_tilt_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn mode_read(self, endpoint: u16) -> Result<Mode, Error>
pub async fn safety_status_read( self, endpoint: u16, ) -> Result<SafetyStatus, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn mode_write(self, endpoint: u16, value: Mode) -> Result<(), Error>