pub struct GeneralCommissioningClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the GeneralCommissioning cluster’s client operations. Returned by GeneralCommissioningClient::general_commissioning. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> GeneralCommissioningClientView<'a>
impl<'a> GeneralCommissioningClientView<'a>
pub async fn arm_fail_safe<F>(
self,
endpoint: u16,
request: F,
) -> Result<ArmFailSafeResponseHandle<'a>, Error>where
F: FnMut(ArmFailSafeRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_regulatory_config<F>(
self,
endpoint: u16,
request: F,
) -> Result<SetRegulatoryConfigResponseHandle<'a>, Error>where
F: FnMut(SetRegulatoryConfigRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn commissioning_complete( self, endpoint: u16, ) -> Result<CommissioningCompleteResponseHandle<'a>, Error>
pub async fn set_tc_acknowledgements<F>(
self,
endpoint: u16,
request: F,
) -> Result<SetTCAcknowledgementsResponseHandle<'a>, Error>where
F: FnMut(SetTCAcknowledgementsRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
Sourcepub async fn basic_commissioning_info_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<BasicCommissioningInfo<'_>, Error>) -> R,
) -> Result<R, Error>
pub async fn basic_commissioning_info_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<BasicCommissioningInfo<'_>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn regulatory_config_read( self, endpoint: u16, ) -> Result<RegulatoryLocationTypeEnum, Error>
pub async fn location_capability_read( self, endpoint: u16, ) -> Result<RegulatoryLocationTypeEnum, Error>
pub async fn supports_concurrent_connection_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn tc_accepted_version_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn tc_min_required_version_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn tc_acknowledgements_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn tc_acknowledgements_required_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn tc_update_deadline_read( self, endpoint: u16, ) -> Result<Maybe<u32, AsNullable>, Error>
Sourcepub async fn recovery_identifier_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Octets<'_>, Error>) -> R,
) -> Result<R, Error>
pub async fn recovery_identifier_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Octets<'_>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn network_recovery_reason_read( self, endpoint: u16, ) -> Result<Maybe<NetworkRecoveryReasonEnum, AsNullable>, Error>
pub async fn is_commissioning_without_power_read( self, endpoint: u16, ) -> Result<bool, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>