pub struct IcdManagementClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the IcdManagement cluster’s client operations. Returned by IcdManagementClient::icd_management. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> IcdManagementClientView<'a>
impl<'a> IcdManagementClientView<'a>
pub async fn register_client<F>(
self,
endpoint: u16,
request: F,
) -> Result<RegisterClientResponseHandle<'a>, Error>where
F: FnMut(RegisterClientRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn unregister_client<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(UnregisterClientRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn stay_active_request<F>(
self,
endpoint: u16,
request: F,
) -> Result<StayActiveResponseHandle<'a>, Error>where
F: FnMut(StayActiveRequestRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn idle_mode_duration_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn active_mode_duration_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn active_mode_threshold_read( self, endpoint: u16, ) -> Result<u16, Error>
Sourcepub async fn registered_clients_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, MonitoringRegistrationStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn registered_clients_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, MonitoringRegistrationStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn icd_counter_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn clients_supported_per_fabric_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn user_active_mode_trigger_hint_read( self, endpoint: u16, ) -> Result<UserActiveModeTriggerBitmap, Error>
Sourcepub async fn user_active_mode_trigger_instruction_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<&str, Error>) -> R,
) -> Result<R, Error>
pub async fn user_active_mode_trigger_instruction_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<&str, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn operating_mode_read( self, endpoint: u16, ) -> Result<OperatingModeEnum, Error>
pub async fn maximum_check_in_back_off_read( self, endpoint: u16, ) -> Result<u32, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>