pub struct UserActiveModeTriggerBitmap(/* private fields */);Implementations
Sourceimpl UserActiveModeTriggerBitmap
impl UserActiveModeTriggerBitmap
pub const POWER_CYCLE: UserActiveModeTriggerBitmap
pub const SETTINGS_MENU: UserActiveModeTriggerBitmap
pub const CUSTOM_INSTRUCTION: UserActiveModeTriggerBitmap
pub const DEVICE_MANUAL: UserActiveModeTriggerBitmap
pub const ACTUATE_SENSOR: UserActiveModeTriggerBitmap
pub const ACTUATE_SENSOR_SECONDS: UserActiveModeTriggerBitmap
pub const ACTUATE_SENSOR_TIMES: UserActiveModeTriggerBitmap
pub const ACTUATE_SENSOR_LIGHTS_BLINK: UserActiveModeTriggerBitmap
pub const RESET_BUTTON: UserActiveModeTriggerBitmap
pub const RESET_BUTTON_LIGHTS_BLINK: UserActiveModeTriggerBitmap
pub const RESET_BUTTON_SECONDS: UserActiveModeTriggerBitmap
pub const RESET_BUTTON_TIMES: UserActiveModeTriggerBitmap
pub const SETUP_BUTTON: UserActiveModeTriggerBitmap
pub const SETUP_BUTTON_SECONDS: UserActiveModeTriggerBitmap
pub const SETUP_BUTTON_LIGHTS_BLINK: UserActiveModeTriggerBitmap
pub const SETUP_BUTTON_TIMES: UserActiveModeTriggerBitmap
pub const APP_DEFINED_BUTTON: UserActiveModeTriggerBitmap
pub const _INTERNAL_ALL_BITS: UserActiveModeTriggerBitmap
Sourceimpl UserActiveModeTriggerBitmap
impl UserActiveModeTriggerBitmap
Sourcepub const fn empty() -> UserActiveModeTriggerBitmap
pub const fn empty() -> UserActiveModeTriggerBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> UserActiveModeTriggerBitmap
pub const fn all() -> UserActiveModeTriggerBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<UserActiveModeTriggerBitmap>
pub const fn from_bits(bits: u32) -> Option<UserActiveModeTriggerBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> UserActiveModeTriggerBitmap
pub const fn from_bits_truncate(bits: u32) -> UserActiveModeTriggerBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> UserActiveModeTriggerBitmap
pub const fn from_bits_retain(bits: u32) -> UserActiveModeTriggerBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<UserActiveModeTriggerBitmap>
pub fn from_name(name: &str) -> Option<UserActiveModeTriggerBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: UserActiveModeTriggerBitmap) -> bool
pub const fn intersects(&self, other: UserActiveModeTriggerBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: UserActiveModeTriggerBitmap) -> bool
pub const fn contains(&self, other: UserActiveModeTriggerBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: UserActiveModeTriggerBitmap)
pub fn insert(&mut self, other: UserActiveModeTriggerBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: UserActiveModeTriggerBitmap)
pub fn remove(&mut self, other: UserActiveModeTriggerBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: UserActiveModeTriggerBitmap)
pub fn toggle(&mut self, other: UserActiveModeTriggerBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: UserActiveModeTriggerBitmap, value: bool)
pub fn set(&mut self, other: UserActiveModeTriggerBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: UserActiveModeTriggerBitmap,
) -> UserActiveModeTriggerBitmap
pub const fn intersection( self, other: UserActiveModeTriggerBitmap, ) -> UserActiveModeTriggerBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: UserActiveModeTriggerBitmap,
) -> UserActiveModeTriggerBitmap
pub const fn union( self, other: UserActiveModeTriggerBitmap, ) -> UserActiveModeTriggerBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: UserActiveModeTriggerBitmap,
) -> UserActiveModeTriggerBitmap
pub const fn difference( self, other: UserActiveModeTriggerBitmap, ) -> UserActiveModeTriggerBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: UserActiveModeTriggerBitmap,
) -> UserActiveModeTriggerBitmap
pub const fn symmetric_difference( self, other: UserActiveModeTriggerBitmap, ) -> UserActiveModeTriggerBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> UserActiveModeTriggerBitmap
pub const fn complement(self) -> UserActiveModeTriggerBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl UserActiveModeTriggerBitmap
impl UserActiveModeTriggerBitmap
Sourcepub const fn iter(&self) -> Iter<UserActiveModeTriggerBitmap> ⓘ
pub const fn iter(&self) -> Iter<UserActiveModeTriggerBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<UserActiveModeTriggerBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<UserActiveModeTriggerBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.