NetworkScanInfo

Enum NetworkScanInfo 

pub enum NetworkScanInfo<'a> {
    Wifi {
        security: WiFiSecurityBitmap,
        ssid: &'a [u8],
        bssid: &'a [u8],
        channel: u16,
        band: WiFiBandEnum,
        rssi: i8,
    },
    Thread {
        pan_id: u16,
        ext_pan_id: u64,
        network_name: &'a str,
        channel: u16,
        version: u8,
        ext_addr: &'a [u8],
        rssi: i8,
        lqi: u8,
    },
}
Network scan information as returned by the NetCtl::scan method

Variants



Wifi

WiFi network scan information when the network type is NetworkType::Wifi

Fields

ssid: &'a [u8]
bssid: &'a [u8]
channel: u16
rssi: i8


Thread

Thread network scan information when the network type is NetworkType::Thread

Fields

pan_id: u16
ext_pan_id: u64
network_name: &'a str
channel: u16
version: u8
ext_addr: &'a [u8]
rssi: i8
lqi: u8

Implementations

Source

impl NetworkScanInfo<'_>

pub fn wifi_read_into<P>( &self, builder: WiFiInterfaceScanResultStructBuilder<P>, ) -> Result<P, Error>

Read the network scan information into the given NetworkScanInfoStructBuilder. If the network type is not NetworkType::Wifi, this method will panic.

pub fn thread_read_into<P>( &self, builder: ThreadInterfaceScanResultStructBuilder<P>, ) -> Result<P, Error>

Read the network scan information into the given ThreadInterfaceScanResultStructBuilder. If the network type is not NetworkType::Thread, this method will panic.