pub struct SharedNetworks<N> { /* private fields */ }Expand description
A type providing shared access to a Networks implementation with change notification capabilities.
Implementations
Sourcepub const fn new(networks: N) -> SharedNetworks<N>
pub const fn new(networks: N) -> SharedNetworks<N>
Create a new instance.
Sourcepub fn init(networks: impl Init<N>) -> impl Init<SharedNetworks<N>>
pub fn init(networks: impl Init<N>) -> impl Init<SharedNetworks<N>>
Return an in-place initializer for the struct.
Sourcepub fn get_mut(&mut self) -> &mut RefCell<N>
pub fn get_mut(&mut self) -> &mut RefCell<N>
Get a mutable reference to the inner Networks implementation.
Sourcepub fn wait_state_changed(&self) -> impl Future<Output = ()>
pub fn wait_state_changed(&self) -> impl Future<Output = ()>
Wait for the state to change.