pub struct ThreadCapabilitiesBitmap(/* private fields */);Implementations
Sourceimpl ThreadCapabilitiesBitmap
impl ThreadCapabilitiesBitmap
pub const IS_BORDER_ROUTER_CAPABLE: ThreadCapabilitiesBitmap
pub const IS_ROUTER_CAPABLE: ThreadCapabilitiesBitmap
pub const IS_SLEEPY_END_DEVICE_CAPABLE: ThreadCapabilitiesBitmap
pub const IS_FULL_THREAD_DEVICE: ThreadCapabilitiesBitmap
pub const IS_SYNCHRONIZED_SLEEPY_END_DEVICE_CAPABLE: ThreadCapabilitiesBitmap
pub const _INTERNAL_ALL_BITS: ThreadCapabilitiesBitmap
Sourceimpl ThreadCapabilitiesBitmap
impl ThreadCapabilitiesBitmap
Sourcepub const fn empty() -> ThreadCapabilitiesBitmap
pub const fn empty() -> ThreadCapabilitiesBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> ThreadCapabilitiesBitmap
pub const fn all() -> ThreadCapabilitiesBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<ThreadCapabilitiesBitmap>
pub const fn from_bits(bits: u16) -> Option<ThreadCapabilitiesBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> ThreadCapabilitiesBitmap
pub const fn from_bits_truncate(bits: u16) -> ThreadCapabilitiesBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> ThreadCapabilitiesBitmap
pub const fn from_bits_retain(bits: u16) -> ThreadCapabilitiesBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ThreadCapabilitiesBitmap>
pub fn from_name(name: &str) -> Option<ThreadCapabilitiesBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ThreadCapabilitiesBitmap) -> bool
pub const fn intersects(&self, other: ThreadCapabilitiesBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: ThreadCapabilitiesBitmap) -> bool
pub const fn contains(&self, other: ThreadCapabilitiesBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: ThreadCapabilitiesBitmap)
pub fn insert(&mut self, other: ThreadCapabilitiesBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: ThreadCapabilitiesBitmap)
pub fn remove(&mut self, other: ThreadCapabilitiesBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ThreadCapabilitiesBitmap)
pub fn toggle(&mut self, other: ThreadCapabilitiesBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: ThreadCapabilitiesBitmap, value: bool)
pub fn set(&mut self, other: ThreadCapabilitiesBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(
self,
other: ThreadCapabilitiesBitmap,
) -> ThreadCapabilitiesBitmap
pub const fn intersection( self, other: ThreadCapabilitiesBitmap, ) -> ThreadCapabilitiesBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(
self,
other: ThreadCapabilitiesBitmap,
) -> ThreadCapabilitiesBitmap
pub const fn union( self, other: ThreadCapabilitiesBitmap, ) -> ThreadCapabilitiesBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(
self,
other: ThreadCapabilitiesBitmap,
) -> ThreadCapabilitiesBitmap
pub const fn difference( self, other: ThreadCapabilitiesBitmap, ) -> ThreadCapabilitiesBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: ThreadCapabilitiesBitmap,
) -> ThreadCapabilitiesBitmap
pub const fn symmetric_difference( self, other: ThreadCapabilitiesBitmap, ) -> ThreadCapabilitiesBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> ThreadCapabilitiesBitmap
pub const fn complement(self) -> ThreadCapabilitiesBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ThreadCapabilitiesBitmap
impl ThreadCapabilitiesBitmap
Sourcepub const fn iter(&self) -> Iter<ThreadCapabilitiesBitmap> ⓘ
pub const fn iter(&self) -> Iter<ThreadCapabilitiesBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ThreadCapabilitiesBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<ThreadCapabilitiesBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.