pub struct WiFiSecurityBitmap(/* private fields */);Implementations
Sourceimpl WiFiSecurityBitmap
impl WiFiSecurityBitmap
pub const UNENCRYPTED: WiFiSecurityBitmap
pub const WEP: WiFiSecurityBitmap
pub const WPA_PERSONAL: WiFiSecurityBitmap
pub const WPA_2_PERSONAL: WiFiSecurityBitmap
pub const WPA_3_PERSONAL: WiFiSecurityBitmap
pub const _INTERNAL_ALL_BITS: WiFiSecurityBitmap
Sourceimpl WiFiSecurityBitmap
impl WiFiSecurityBitmap
Sourcepub const fn empty() -> WiFiSecurityBitmap
pub const fn empty() -> WiFiSecurityBitmap
Get a flags value with all bits unset.
Sourcepub const fn all() -> WiFiSecurityBitmap
pub const fn all() -> WiFiSecurityBitmap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<WiFiSecurityBitmap>
pub const fn from_bits(bits: u8) -> Option<WiFiSecurityBitmap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> WiFiSecurityBitmap
pub const fn from_bits_truncate(bits: u8) -> WiFiSecurityBitmap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> WiFiSecurityBitmap
pub const fn from_bits_retain(bits: u8) -> WiFiSecurityBitmap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<WiFiSecurityBitmap>
pub fn from_name(name: &str) -> Option<WiFiSecurityBitmap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: WiFiSecurityBitmap) -> bool
pub const fn intersects(&self, other: WiFiSecurityBitmap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: WiFiSecurityBitmap) -> bool
pub const fn contains(&self, other: WiFiSecurityBitmap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: WiFiSecurityBitmap)
pub fn insert(&mut self, other: WiFiSecurityBitmap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: WiFiSecurityBitmap)
pub fn remove(&mut self, other: WiFiSecurityBitmap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: WiFiSecurityBitmap)
pub fn toggle(&mut self, other: WiFiSecurityBitmap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: WiFiSecurityBitmap, value: bool)
pub fn set(&mut self, other: WiFiSecurityBitmap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: WiFiSecurityBitmap) -> WiFiSecurityBitmap
pub const fn intersection(self, other: WiFiSecurityBitmap) -> WiFiSecurityBitmap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: WiFiSecurityBitmap) -> WiFiSecurityBitmap
pub const fn union(self, other: WiFiSecurityBitmap) -> WiFiSecurityBitmap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: WiFiSecurityBitmap) -> WiFiSecurityBitmap
pub const fn difference(self, other: WiFiSecurityBitmap) -> WiFiSecurityBitmap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: WiFiSecurityBitmap,
) -> WiFiSecurityBitmap
pub const fn symmetric_difference( self, other: WiFiSecurityBitmap, ) -> WiFiSecurityBitmap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> WiFiSecurityBitmap
pub const fn complement(self) -> WiFiSecurityBitmap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl WiFiSecurityBitmap
impl WiFiSecurityBitmap
Sourcepub const fn iter(&self) -> Iter<WiFiSecurityBitmap> ⓘ
pub const fn iter(&self) -> Iter<WiFiSecurityBitmap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<WiFiSecurityBitmap> ⓘ
pub const fn iter_names(&self) -> IterNames<WiFiSecurityBitmap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.