pub struct PowerSourceHandler<'a> { /* private fields */ }Expand description
The system implementation of a handler for the PowerSource Matter cluster.
Per-endpoint instance: a node with several power sources hosts one handler
per source, each on its own endpoint with its own Dataver.
Implementations
Sourceimpl<'a> PowerSourceHandler<'a>
impl<'a> PowerSourceHandler<'a>
Sourcepub const fn new(
dataver: Dataver,
config: &'a PowerSourceConfig<'a>,
) -> PowerSourceHandler<'a>
pub const fn new( dataver: Dataver, config: &'a PowerSourceConfig<'a>, ) -> PowerSourceHandler<'a>
Create a new handler describing config.
Sourcepub const fn adapt(self) -> HandlerAdaptor<PowerSourceHandler<'a>>
pub const fn adapt(self) -> HandlerAdaptor<PowerSourceHandler<'a>>
Adapt the handler instance to the generic rs-matter Handler trait.