pub enum UtcTime {
Reliable(u64),
LastKnown(u64),
}Expand description
An enum describing the current UTC timestamp the real-time clock is aware of.
The timestamp is expressed as Matter-epoch microseconds.
Variants
Reliable(u64)
The RTC is actively tracking the current time, anchored at the given Matter-epoch microseconds value.
LastKnown(u64)
The RTC is not currently tracking the current time, but the given Matter-epoch microseconds value is the last known good UTC time persisted on the device.
Do note that a “last known” time is always available, as the firmware build timestamp is used as the initial value on a freshly-flashed device.
Implementations
Sourceimpl UtcTime
impl UtcTime
Sourcepub const fn reliable(&self) -> Option<u64>
pub const fn reliable(&self) -> Option<u64>
Return the current UTC time if available, or None if no reliable time is currently tracked.
Sourcepub const fn any(&self) -> u64
pub const fn any(&self) -> u64
Return the current UTC time if available, or the persisted LKG UTC otherwise.
Sourcepub const fn reliable_secs(&self) -> Option<u64>
pub const fn reliable_secs(&self) -> Option<u64>
Return the current UTC time in seconds if available, or None if no reliable time is currently tracked.