pub struct Options(/* private fields */);Expand description
Cluster-shape selectors for the TimeSyncHandler. Each bit
turns on exactly one Matter Feature — there are no
independent-optional toggles on this cluster, so the mapping
is 1:1.
Used as the const-generic argument to cluster (via its
bits() value) to compute the matching Cluster<'static>
metadata, which is then installed onto the endpoint via the
clusters! / root_endpoint! macros (e.g.
clusters!(eth, time_sync(time_zone, ntp_client); …)).
Implementations
Sourceimpl Options
impl Options
Sourcepub const TIME_ZONE: Options
pub const TIME_ZONE: Options
Claim the Matter TIME_ZONE feature. Advertises TimeZone,
DSTOffset, LocalTime, TimeZoneDatabase,
TimeZoneListMaxSize, DSTOffsetListMaxSize attributes
and the SetTimeZone + SetDSTOffset commands.
Sourcepub const NTP_CLIENT: Options
pub const NTP_CLIENT: Options
Claim the Matter NTP_CLIENT feature. Advertises
DefaultNTP + SupportsDNSResolve attributes and the
SetDefaultNTP command.
Sourcepub const NTP_SERVER: Options
pub const NTP_SERVER: Options
Claim the Matter NTP_SERVER feature. Advertises the
NTPServerAvailable attribute.
Sourcepub const TIME_SYNC_CLIENT: Options
pub const TIME_SYNC_CLIENT: Options
Claim the Matter TIME_SYNC_CLIENT feature. Advertises the
TrustedTimeSource attribute and the SetTrustedTimeSource
command.
Sourceimpl Options
impl Options
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Options>
pub const fn from_bits(bits: u8) -> Option<Options>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Options
pub const fn from_bits_truncate(bits: u8) -> Options
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Options
pub const fn from_bits_retain(bits: u8) -> Options
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Options>
pub fn from_name(name: &str) -> Option<Options>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Options) -> bool
pub const fn intersects(&self, other: Options) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Options) -> bool
pub const fn contains(&self, other: Options) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Options)
pub fn remove(&mut self, other: Options)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Options)
pub fn toggle(&mut self, other: Options)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Options, value: bool)
pub fn set(&mut self, other: Options, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Options) -> Options
pub const fn intersection(self, other: Options) -> Options
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Options) -> Options
pub const fn union(self, other: Options) -> Options
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Options) -> Options
pub const fn difference(self, other: Options) -> Options
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Options) -> Options
pub const fn symmetric_difference(self, other: Options) -> Options
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Options
pub const fn complement(self) -> Options
The bitwise negation (!) of the bits in self, truncating the result.