pub struct Bitmap8MaskMap(/* private fields */);Implementations
Sourceimpl Bitmap8MaskMap
impl Bitmap8MaskMap
pub const MASK_VAL_1: Bitmap8MaskMap
pub const MASK_VAL_2: Bitmap8MaskMap
pub const MASK_VAL_3: Bitmap8MaskMap
pub const MASK_VAL_4: Bitmap8MaskMap
pub const _INTERNAL_ALL_BITS: Bitmap8MaskMap
Sourceimpl Bitmap8MaskMap
impl Bitmap8MaskMap
Sourcepub const fn empty() -> Bitmap8MaskMap
pub const fn empty() -> Bitmap8MaskMap
Get a flags value with all bits unset.
Sourcepub const fn all() -> Bitmap8MaskMap
pub const fn all() -> Bitmap8MaskMap
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Bitmap8MaskMap>
pub const fn from_bits(bits: u8) -> Option<Bitmap8MaskMap>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Bitmap8MaskMap
pub const fn from_bits_truncate(bits: u8) -> Bitmap8MaskMap
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Bitmap8MaskMap
pub const fn from_bits_retain(bits: u8) -> Bitmap8MaskMap
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Bitmap8MaskMap>
pub fn from_name(name: &str) -> Option<Bitmap8MaskMap>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Bitmap8MaskMap) -> bool
pub const fn intersects(&self, other: Bitmap8MaskMap) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Bitmap8MaskMap) -> bool
pub const fn contains(&self, other: Bitmap8MaskMap) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Bitmap8MaskMap)
pub fn insert(&mut self, other: Bitmap8MaskMap)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: Bitmap8MaskMap)
pub fn remove(&mut self, other: Bitmap8MaskMap)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Bitmap8MaskMap)
pub fn toggle(&mut self, other: Bitmap8MaskMap)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Bitmap8MaskMap, value: bool)
pub fn set(&mut self, other: Bitmap8MaskMap, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
pub const fn intersection(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
pub const fn union(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
pub const fn difference(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
pub const fn symmetric_difference(self, other: Bitmap8MaskMap) -> Bitmap8MaskMap
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Bitmap8MaskMap
pub const fn complement(self) -> Bitmap8MaskMap
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Bitmap8MaskMap
impl Bitmap8MaskMap
Sourcepub const fn iter(&self) -> Iter<Bitmap8MaskMap> ⓘ
pub const fn iter(&self) -> Iter<Bitmap8MaskMap> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Bitmap8MaskMap> ⓘ
pub const fn iter_names(&self) -> IterNames<Bitmap8MaskMap> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.