pub struct LabelEntry {
pub label: StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 16]>>,
pub value: StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 16]>>,
}Expand description
One entry in a LabelList.
Named struct (rather than a tuple) so the derive(FromTLV, ToTLV)
pair gives us a stable persisted shape for free — the on-disk
representation matches the Matter spec’s LabelStruct field layout
(label at tag 0, value at tag 1).
Fields
label: StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 16]>>value: StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 16]>>Trait Implementations
Sourceimpl Clone for LabelEntry
impl Clone for LabelEntry
Sourcefn clone(&self) -> LabelEntry
fn clone(&self) -> LabelEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LabelEntry
impl Debug for LabelEntry
impl Eq for LabelEntry
Sourceimpl<'__from_tlv> FromTLV<'__from_tlv> for LabelEntry
impl<'__from_tlv> FromTLV<'__from_tlv> for LabelEntry
Sourcefn from_tlv(element: &TLVElement<'__from_tlv>) -> Result<LabelEntry, Error>
fn from_tlv(element: &TLVElement<'__from_tlv>) -> Result<LabelEntry, Error>
Deserialize the type from a TLV-encoded element.
Sourcefn init_from_tlv(
element: TLVElement<'__from_tlv>,
) -> impl Init<LabelEntry, Error>
fn init_from_tlv( element: TLVElement<'__from_tlv>, ) -> impl Init<LabelEntry, Error>
Generate an in-place initializer for the type that initializes
the type from a TLV-encoded element.
Sourcefn nullable_from_tlv(element: &TLVElement<'a>) -> Result<Self, Error>
fn nullable_from_tlv(element: &TLVElement<'a>) -> Result<Self, Error>
Deserialize the type from a TLV-encoded element. Read more
Sourcefn init_nullable_from_tlv(element: TLVElement<'a>) -> impl Init<Self, Error>
fn init_nullable_from_tlv(element: TLVElement<'a>) -> impl Init<Self, Error>
Generate an in-place initializer for the type that initializes
the type from a TLV-encoded element. Read more
Sourceimpl PartialEq for LabelEntry
impl PartialEq for LabelEntry
Sourcefn eq(&self, other: &LabelEntry) -> bool
fn eq(&self, other: &LabelEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LabelEntry
Sourceimpl ToTLV for LabelEntry
impl ToTLV for LabelEntry
Sourcefn to_tlv<W>(&self, tag: &TLVTag, tw: W) -> Result<(), Error>where
W: TLVWrite,
fn to_tlv<W>(&self, tag: &TLVTag, tw: W) -> Result<(), Error>where
W: TLVWrite,
Serialize the type to a TLV-encoded stream.
Sourcefn tlv_iter(&self, tag: TLVTag) -> impl Iterator<Item = Result<TLV<'_>, Error>>
fn tlv_iter(&self, tag: TLVTag) -> impl Iterator<Item = Result<TLV<'_>, Error>>
Serialize the type as an iterator of
TLV instances by potentially borrowing
data from the type.Sourceimpl<'__from_tlv> TryFrom<&TLVElement<'__from_tlv>> for LabelEntry
impl<'__from_tlv> TryFrom<&TLVElement<'__from_tlv>> for LabelEntry
Sourcefn try_from(
element: &TLVElement<'__from_tlv>,
) -> Result<LabelEntry, <LabelEntry as TryFrom<&TLVElement<'__from_tlv>>>::Error>
fn try_from( element: &TLVElement<'__from_tlv>, ) -> Result<LabelEntry, <LabelEntry as TryFrom<&TLVElement<'__from_tlv>>>::Error>
Performs the conversion.