pub struct Access(/* private fields */);Implementations
Sourceimpl Access
impl Access
pub const NEED_VIEW: Access
pub const NEED_OPERATE: Access
pub const NEED_MANAGE: Access
pub const NEED_ADMIN: Access
pub const READ: Access
pub const WRITE: Access
pub const FAB_SCOPED: Access
pub const FAB_SENSITIVE: Access
pub const TIMED_ONLY: Access
pub const READ_PRIVILEGE_MASK: Access
pub const WRITE_PRIVILEGE_MASK: Access
pub const RV: Access
pub const RF: Access
pub const RA: Access
pub const RWVA: Access
pub const RWFA: Access
pub const RWVM: Access
pub const RWFVM: Access
pub const WO: Access
pub const WM: Access
pub const WA: Access
Sourceimpl Access
impl Access
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Access>
pub const fn from_bits(bits: u16) -> Option<Access>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Access
pub const fn from_bits_truncate(bits: u16) -> Access
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Access
pub const fn from_bits_retain(bits: u16) -> Access
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Access>
pub fn from_name(name: &str) -> Option<Access>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Access) -> bool
pub const fn intersects(&self, other: Access) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Access) -> bool
pub const fn contains(&self, other: Access) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Access)
pub fn remove(&mut self, other: Access)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Access)
pub fn toggle(&mut self, other: Access)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Access, value: bool)
pub fn set(&mut self, other: Access, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Access) -> Access
pub const fn intersection(self, other: Access) -> Access
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Access) -> Access
pub const fn union(self, other: Access) -> Access
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Access) -> Access
pub const fn difference(self, other: Access) -> Access
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Access) -> Access
pub const fn symmetric_difference(self, other: Access) -> Access
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Access
pub const fn complement(self) -> Access
The bitwise negation (!) of the bits in self, truncating the result.