pub struct Async<T>(pub T);Expand description
An adaptor that adapts a NonBlockingHandler trait implementation to the AsyncHandler trait contract.
The adaptor also implements NonBlockingHandler so that the adapted handler can be used in any context.
Tuple Fields
0: TTrait Implementations
Sourceimpl<T> AsyncHandler for Async<T>where
T: NonBlockingHandler,
impl<T> AsyncHandler for Async<T>where
T: NonBlockingHandler,
Sourcefn read_awaits(&self, _ctx: impl ReadContext) -> bool
fn read_awaits(&self, _ctx: impl ReadContext) -> bool
Provide information whether the handler will internally await while reading
the current value of the provided attribute. Read more
Sourcefn write_awaits(&self, _ctx: impl WriteContext) -> bool
fn write_awaits(&self, _ctx: impl WriteContext) -> bool
Provide information whether the handler will internally await while updating
the value of the provided attribute. Read more
Sourcefn invoke_awaits(&self, _ctx: impl InvokeContext) -> bool
fn invoke_awaits(&self, _ctx: impl InvokeContext) -> bool
Provide information whether the handler will internally await while invoking
the provided command. Read more
Sourcefn read(
&self,
ctx: impl ReadContext,
reply: impl ReadReply,
) -> impl Future<Output = Result<(), Error>>
fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> impl Future<Output = Result<(), Error>>
Read from the requested attribute and encode the result using the provided reply type.
Sourcefn write(
&self,
ctx: impl WriteContext,
) -> impl Future<Output = Result<(), Error>>
fn write( &self, ctx: impl WriteContext, ) -> impl Future<Output = Result<(), Error>>
Write into the requested attribute using the provided data. Read more
Sourcefn invoke(
&self,
ctx: impl InvokeContext,
reply: impl InvokeReply,
) -> impl Future<Output = Result<(), Error>>
fn invoke( &self, ctx: impl InvokeContext, reply: impl InvokeReply, ) -> impl Future<Output = Result<(), Error>>
Invoke the requested command with the provided data and encode the result using the provided reply type. Read more
Sourcefn bump_dataver(&self, ctx: impl MatchContext)
fn bump_dataver(&self, ctx: impl MatchContext)
Bump the per-cluster
Dataver for the cluster handler matching
the supplied context endpoint_id / cluster_id.Sourcefn lifecycle(
&self,
ctx: impl HandlerContext,
op: LifecycleOp,
) -> Result<(), Error>
fn lifecycle( &self, ctx: impl HandlerContext, op: LifecycleOp, ) -> Result<(), Error>
Process a lifecycle operation (
LifecycleOp). Read moreimpl<T> Copy for Async<T>where
T: Copy,
impl<T> Eq for Async<T>where
T: Eq,
Sourceimpl<T> Handler for Async<T>where
T: Handler,
impl<T> Handler for Async<T>where
T: Handler,
Sourcefn read(
&self,
ctx: impl ReadContext,
reply: impl ReadReply,
) -> Result<(), Error>
fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> Result<(), Error>
Read from the requested attribute and encode the result using the provided reply type.
Sourcefn write(&self, ctx: impl WriteContext) -> Result<(), Error>
fn write(&self, ctx: impl WriteContext) -> Result<(), Error>
Write into the requested attribute using the provided data.
Sourcefn invoke(
&self,
ctx: impl InvokeContext,
reply: impl InvokeReply,
) -> Result<(), Error>
fn invoke( &self, ctx: impl InvokeContext, reply: impl InvokeReply, ) -> Result<(), Error>
Invoke the requested command with the provided data and encode the result using the provided reply type.
Sourcefn bump_dataver(&self, ctx: impl MatchContext)
fn bump_dataver(&self, ctx: impl MatchContext)
Bump the per-cluster
Dataver for the cluster handler matching
the supplied context endpoint_id / cluster_id.Sourcefn lifecycle(
&self,
ctx: impl HandlerContext,
op: LifecycleOp,
) -> Result<(), Error>
fn lifecycle( &self, ctx: impl HandlerContext, op: LifecycleOp, ) -> Result<(), Error>
Process a lifecycle operation (
LifecycleOp). Read moreimpl<T> NonBlockingHandler for Async<T>where
T: NonBlockingHandler,
impl<T> StructuralPartialEq for Async<T>where
T: PartialEq,