ChainedHandler

Struct ChainedHandler 

pub struct ChainedHandler<M, H, T> {
    pub matcher: M,
    pub handler: H,
    pub next: T,
}
A handler that chains two handlers together in a composite handler.

Fields

matcher: M

The matcher that determines whether the handler should be invoked for the incoming operation.

handler: H

The handler to be invoked if the matcher returns true.

next: T

The next handler to be invoked if the matcher returns false.

Implementations

Source

impl<M, H, T> ChainedHandler<M, H, T>

pub const fn new(matcher: M, handler: H, next: T) -> ChainedHandler<M, H, T>

Construct a chained handler that works as follows:

  • It will call the provided handler instance if the provided matcher returns true for the ReadContext/WriteContext/InvokeContext of the incoming operation
  • Otherwise, it will call the next handler

Arguments:

  • matcher: A matcher that determines whether the handler should be invoked for the incoming operation.
  • handler: The handler to be invoked if the matcher returns true.
  • next: The next handler to be invoked if the matcher returns false.
pub const fn chain<M2, H2>( self, matcher: M2, handler: H2, ) -> ChainedHandler<M2, H2, ChainedHandler<M, H, T>>

Chain itself with another handler.

The returned chained handler works as follows:

  • It will call the provided handler instance if the provided matcher returns true for the ReadContext/WriteContext/InvokeContext of the incoming operation
  • Otherwise, it will call the self handler

Arguments:

  • matcher: A matcher that determines whether the handler should be invoked for the incoming operation.
  • handler: The handler to be invoked if the matcher returns true.