pub struct EmptyHandler;Expand description
A handler that always fails with attribute / command not found.
Useful when chaining multiple handlers together as the end of the chain.
Implementations
Sourceimpl EmptyHandler
impl EmptyHandler
Sourcepub const fn chain<M, H>(
self,
matcher: M,
handler: H,
) -> ChainedHandler<M, H, EmptyHandler>
pub const fn chain<M, H>( self, matcher: M, handler: H, ) -> ChainedHandler<M, H, EmptyHandler>
Chain the empty handler with another handler thus providing an “end of handler chain” fallback that errors out.
The returned chained handler works as follows:
- It will call the provided
handlerinstance if the provided matcher returnstruefor theReadContext/WriteContext/InvokeContextof the incoming operation - Otherwise, the empty handler would be invoked, causing the operation to error out.
Arguments:
matcher: A matcher that determines whether the handler should be invoked for the incoming operation.handler: The handler to be invoked if the matcher returnstrue.