pub struct Privilege(/* private fields */);Implementations
Sourceimpl Privilege
impl Privilege
pub const V: Privilege
pub const O: Privilege
pub const M: Privilege
pub const A: Privilege
pub const P: Privilege
pub const VIEW: Privilege
pub const OPERATE: Privilege
pub const MANAGE: Privilege
pub const ADMIN: Privilege
pub const PROXYVIEW: Privilege
Sourceimpl Privilege
impl Privilege
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Privilege>
pub const fn from_bits(bits: u8) -> Option<Privilege>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Privilege
pub const fn from_bits_truncate(bits: u8) -> Privilege
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Privilege
pub const fn from_bits_retain(bits: u8) -> Privilege
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Privilege>
pub fn from_name(name: &str) -> Option<Privilege>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Privilege) -> bool
pub const fn intersects(&self, other: Privilege) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Privilege) -> bool
pub const fn contains(&self, other: Privilege) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Privilege)
pub fn remove(&mut self, other: Privilege)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Privilege)
pub fn toggle(&mut self, other: Privilege)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Privilege, value: bool)
pub fn set(&mut self, other: Privilege, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Privilege) -> Privilege
pub const fn intersection(self, other: Privilege) -> Privilege
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Privilege) -> Privilege
pub const fn union(self, other: Privilege) -> Privilege
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Privilege) -> Privilege
pub const fn difference(self, other: Privilege) -> Privilege
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Privilege) -> Privilege
pub const fn symmetric_difference(self, other: Privilege) -> Privilege
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Privilege
pub const fn complement(self) -> Privilege
The bitwise negation (!) of the bits in self, truncating the result.