pub struct Quality(/* private fields */);Implementations
Sourceimpl Quality
impl Quality
pub const NONE: Quality
pub const SCENE: Quality
pub const PERSISTENT: Quality
pub const FIXED: Quality
pub const NULLABLE: Quality
pub const OPTIONAL: Quality
pub const ARRAY: Quality
pub const SN: Quality
pub const S: Quality
pub const N: Quality
pub const F: Quality
pub const X: Quality
pub const O: Quality
pub const A: Quality
pub const OA: Quality
Sourceimpl Quality
impl Quality
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Quality>
pub const fn from_bits(bits: u8) -> Option<Quality>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Quality
pub const fn from_bits_truncate(bits: u8) -> Quality
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Quality
pub const fn from_bits_retain(bits: u8) -> Quality
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Quality>
pub fn from_name(name: &str) -> Option<Quality>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Quality) -> bool
pub const fn intersects(&self, other: Quality) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Quality) -> bool
pub const fn contains(&self, other: Quality) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Quality)
pub fn remove(&mut self, other: Quality)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Quality)
pub fn toggle(&mut self, other: Quality)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Quality, value: bool)
pub fn set(&mut self, other: Quality, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Quality) -> Quality
pub const fn intersection(self, other: Quality) -> Quality
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Quality) -> Quality
pub const fn union(self, other: Quality) -> Quality
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Quality) -> Quality
pub const fn difference(self, other: Quality) -> Quality
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Quality) -> Quality
pub const fn symmetric_difference(self, other: Quality) -> Quality
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Quality
pub const fn complement(self) -> Quality
The bitwise negation (!) of the bits in self, truncating the result.