AsyncHandler

Trait AsyncHandler 

pub trait AsyncHandler {
    // Required methods
    fn read(
        &self,
        ctx: impl ReadContext,
        reply: impl ReadReply,
    ) -> impl Future<Output = Result<(), Error>>;
    fn bump_dataver(&self, ctx: impl MatchContext);

    // Provided methods
    fn read_awaits(&self, _ctx: impl ReadContext) -> bool { ... }
    fn write_awaits(&self, _ctx: impl WriteContext) -> bool { ... }
    fn invoke_awaits(&self, _ctx: impl InvokeContext) -> bool { ... }
    fn write(
        &self,
        _ctx: impl WriteContext,
    ) -> impl Future<Output = Result<(), Error>> { ... }
    fn invoke(
        &self,
        _ctx: impl InvokeContext,
        _reply: impl InvokeReply,
    ) -> impl Future<Output = Result<(), Error>> { ... }
    fn lifecycle(
        &self,
        _ctx: impl HandlerContext,
        _op: LifecycleOp,
    ) -> Result<(), Error> { ... }
    fn run(
        &self,
        _ctx: impl HandlerContext,
    ) -> impl Future<Output = Result<(), Error>> { ... }
}
A handler for processing a single IM operation: read an attribute, write an attribute, or invoke a command.

Handlers are typically implemented by user-defined clusters, but there is no 1:1 correspondence between a handler and a cluster, as a single handler can handle multiple clusters and even multiple endpoints.

Moreover, the InteractionModel implementation expects a single AsyncHandler instance, so the expectation is that the user will compose multiple handlers into a single AsyncHandler instance, using ChainedHandler or other means.

Required Methods

fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> impl Future<Output = Result<(), Error>>

Read from the requested attribute and encode the result using the provided reply type.

fn bump_dataver(&self, ctx: impl MatchContext)

Bump the per-cluster Dataver for the cluster handler matching the supplied context endpoint_id / cluster_id.

Provided Methods

fn read_awaits(&self, _ctx: impl ReadContext) -> bool

Provide information whether the handler will internally await while reading the current value of the provided attribute.

Handlers which report false via this method provide an opportunity for the Data Model processing to use less memory by not storing the incoming request in an intermediate buffer.

The default implementation unconditionally returns true i.e. the handler is assumed to await while reading any attribute.

fn write_awaits(&self, _ctx: impl WriteContext) -> bool

Provide information whether the handler will internally await while updating the value of the provided attribute.

Handlers which report false via this method provide an opportunity for the Data Model processing to use less memory by not storing the incoming request in an intermediate buffer.

The default implementation unconditionally returns true i.e. the handler is assumed to await while writing any attribute.

fn invoke_awaits(&self, _ctx: impl InvokeContext) -> bool

Provide information whether the handler will internally await while invoking the provided command.

Handlers which report false via this method provide an opportunity for the Data Model processing to use less memory by not storing the incoming request in an intermediate buffer.

The default implementation unconditionally returns true i.e. the handler is assumed to await while invoking any command.

fn write( &self, _ctx: impl WriteContext, ) -> impl Future<Output = Result<(), Error>>

Write into the requested attribute using the provided data.

The default implementation errors out with ErrorCode::AttributeNotFound.

fn invoke( &self, _ctx: impl InvokeContext, _reply: impl InvokeReply, ) -> impl Future<Output = Result<(), Error>>

Invoke the requested command with the provided data and encode the result using the provided reply type.

The default implementation errors out with ErrorCode::CommandNotFound.

fn lifecycle( &self, _ctx: impl HandlerContext, _op: LifecycleOp, ) -> Result<(), Error>

Process a lifecycle operation (LifecycleOp).

Unlike read/write/invoke - which are routed to the single handler matching the operation path - this method is invoked on every handler in the handler chain.

Deliberately synchronous - like AsyncHandler::bump_dataver - even on the async handler trait, so that lifecycle broadcasts can be dispatched eagerly from synchronous call sites (see HandlerContext::notify_fabric_removed).

The default implementation does nothing.

fn run( &self, _ctx: impl HandlerContext, ) -> impl Future<Output = Result<(), Error>>

A hook (a scheduling facility) for placing handler-impl-specific code that needs to run asynchronously - forever and in the “background”.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<M, H> AsyncHandler for (M, H)
where H: AsyncHandler,

Source

fn read_awaits(&self, ctx: impl ReadContext) -> bool

Source

fn write_awaits(&self, ctx: impl WriteContext) -> bool

Source

fn invoke_awaits(&self, ctx: impl InvokeContext) -> bool

Source

fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> impl Future<Output = Result<(), Error>>

Source

fn write( &self, ctx: impl WriteContext, ) -> impl Future<Output = Result<(), Error>>

Source

fn invoke( &self, ctx: impl InvokeContext, reply: impl InvokeReply, ) -> impl Future<Output = Result<(), Error>>

Source

fn bump_dataver(&self, ctx: impl MatchContext)

Source

fn lifecycle( &self, ctx: impl HandlerContext, op: LifecycleOp, ) -> Result<(), Error>

Source

fn run( &self, ctx: impl HandlerContext, ) -> impl Future<Output = Result<(), Error>>

Source

impl<T> AsyncHandler for &T
where T: AsyncHandler,

Source

fn read_awaits(&self, ctx: impl ReadContext) -> bool

Source

fn write_awaits(&self, ctx: impl WriteContext) -> bool

Source

fn invoke_awaits(&self, ctx: impl InvokeContext) -> bool

Source

fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> impl Future<Output = Result<(), Error>>

Source

fn write( &self, ctx: impl WriteContext, ) -> impl Future<Output = Result<(), Error>>

Source

fn invoke( &self, ctx: impl InvokeContext, reply: impl InvokeReply, ) -> impl Future<Output = Result<(), Error>>

Source

fn bump_dataver(&self, ctx: impl MatchContext)

Source

fn lifecycle( &self, ctx: impl HandlerContext, op: LifecycleOp, ) -> Result<(), Error>

Source

fn run( &self, ctx: impl HandlerContext, ) -> impl Future<Output = Result<(), Error>>

Source

impl<T> AsyncHandler for &mut T
where T: AsyncHandler,

Source

fn read_awaits(&self, ctx: impl ReadContext) -> bool

Source

fn write_awaits(&self, ctx: impl WriteContext) -> bool

Source

fn invoke_awaits(&self, ctx: impl InvokeContext) -> bool

Source

fn read( &self, ctx: impl ReadContext, reply: impl ReadReply, ) -> impl Future<Output = Result<(), Error>>

Source

fn write( &self, ctx: impl WriteContext, ) -> impl Future<Output = Result<(), Error>>

Source

fn invoke( &self, ctx: impl InvokeContext, reply: impl InvokeReply, ) -> impl Future<Output = Result<(), Error>>

Source

fn bump_dataver(&self, ctx: impl MatchContext)

Source

fn lifecycle( &self, ctx: impl HandlerContext, op: LifecycleOp, ) -> Result<(), Error>

Source

fn run( &self, ctx: impl HandlerContext, ) -> impl Future<Output = Result<(), Error>>

Implementors

Source

impl AsyncHandler for EmptyHandler

Source

impl<M, H, T> AsyncHandler for ChainedHandler<M, H, T>

Source

impl<T> AsyncHandler for Async<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::identify::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::groups::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::on_off::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::level_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::pulse_width_modulation::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::desc::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::binding::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::acl::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::actions::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::basic_info::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::ota_prov::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::ota_req::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::localization_configuration::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::time_format_localization::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::unit_localization::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::power_source_configuration::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::power_source::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::gen_comm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::net_comm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::diag_logs::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::gen_diag::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::sw_diag::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::thread_diag::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::wifi_diag::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::eth_diag::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::time_sync::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::bridged_device_basic_information::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::switch::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::adm_comm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::noc::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::grp_key_mgmt::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::fixed_label::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::user_label::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::proxy_configuration::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::proxy_discovery::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::proxy_valid::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::boolean_state::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::icd_mgmt::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::oven_cavity_operational_state::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::oven_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::laundry_dryer_controls::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::temperature_controlled_cabinet_topology::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::mode_select::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::laundry_washer_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::refrigerator_and_temperature_controlled_cabinet_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::laundry_washer_controls::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::rvc_run_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::rvc_clean_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::temperature_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::refrigerator_alarm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::dishwasher_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::air_quality::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::smoke_co_alarm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::dishwasher_alarm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::microwave_oven_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::microwave_oven_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::operational_state::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::rvc_operational_state::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::scenes::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::groupcast::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::hepa_filter_monitoring::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::activated_carbon_filter_monitoring::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::water_tank_level_monitoring::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::boolean_state_configuration::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::valve_configuration_and_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::electrical_power_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::electrical_energy_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::water_heater_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::commodity_price::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::messages::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::device_energy_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::energy_evse::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::energy_preference::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::power_topology::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::energy_evse_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::water_heater_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::device_energy_management_mode::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::electrical_grid_conditions::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::electrical_alarm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::electrical_distribution::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::electrical_protection_alarm::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::door_lock::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::window_covering::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::closure_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::closure_dimension::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::service_area::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::pump_configuration_and_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::thermostat::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::fan_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::thermostat_user_interface_configuration::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::humidistat::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::color_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::ballast_configuration::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::dynamic_lighting::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::illuminance_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::temperature_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::pressure_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::flow_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::relative_humidity_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::occupancy_sensing::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::carbon_monoxide_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::carbon_dioxide_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::nitrogen_dioxide_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::ozone_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::pm_25_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::formaldehyde_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::pm_1_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::pm_10_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::total_volatile_organic_compounds_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::radon_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::soil_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::ambient_context_sensing::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::ambient_sensing_union::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::proximity_ranging::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::smoke_concentration_measurement::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::network_identity_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::wi_fi_network_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::thread_border_router_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::thread_network_directory::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::wake_on_lan::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::channel::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::target_navigator::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::media_playback::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::media_input::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::low_power::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::keypad_input::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::content_launcher::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::audio_output::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::application_launcher::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::application_basic::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::account_login::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::content_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::content_app_observer::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::zone_mgmt::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::cam_av_stream::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::cam_av_settings::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::webrtc_prov::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::webrtc_req::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::push_av_stream::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::app::chime::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::av_analysis::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::commodity_tariff::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::ecosystem_information::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::commissioner_control::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::joint_fabric_datastore::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::joint_fabric_administrator::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::tls_certificate_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::tls_client_management::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::meter_identification::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::commodity_metering::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::unit_testing::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::fault_injection::HandlerAsyncAdaptor<T>

Source

impl<T> AsyncHandler for rs_matter_stack::matter::dm::clusters::decl::sample_mei::HandlerAsyncAdaptor<T>