InvokeContext

Trait InvokeContext 

pub trait InvokeContext: OperationContext {
    // Required methods
    fn cmd(&self) -> &CmdDetails;
    fn data(&self) -> &TLVElement<'_>;
}

Required Methods

fn cmd(&self) -> &CmdDetails

Return the command object that is associated with this invoke operation.

fn data(&self) -> &TLVElement<'_>

Return the command data that is associated with this invoke operation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> InvokeContext for &T
where T: InvokeContext,

Source

fn cmd(&self) -> &CmdDetails

Source

fn data(&self) -> &TLVElement<'_>

Implementors