InvokeReply

Trait InvokeReply 

pub trait InvokeReply {
    // Required method
    fn with_command(self, cmd: u32) -> Result<impl Reply, Error>;
}
A trait for encoding the result from a command invoke operation.

Required Methods

fn with_command(self, cmd: u32) -> Result<impl Reply, Error>

Return the reply data writer for a command with the provided Command ID.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors