MatchContext

Trait MatchContext 

pub trait MatchContext {
    // Required methods
    fn endpt(&self) -> Option<u16>;
    fn cluster(&self) -> Option<u32>;
}
A context super-type that is passed to the handler when bumping a dataver

Required Methods

fn endpt(&self) -> Option<u16>

Return the endpoint ID that is associated with context. None if the context is not associated with a specific endpoint (e.g. a global handler’s dataver bump).

fn cluster(&self) -> Option<u32>

Return the cluster ID that is associated with this operation. None if the context is not associated with a specific cluster (e.g. a global handler’s dataver bump).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> MatchContext for &T
where T: MatchContext,

Source

fn endpt(&self) -> Option<u16>

Source

fn cluster(&self) -> Option<u32>

Implementors