ReadContext

Trait ReadContext 

pub trait ReadContext: OperationContext {
    // Required method
    fn attr(&self) -> &AttrDetails;
}
A context type that is passed to the handler when processing an attribute Read operation.

Required Methods

fn attr(&self) -> &AttrDetails

Return the attribute object that is associated with this read operation.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> ReadContext for &T
where T: ReadContext,

Implementors