ReadReply

Trait ReadReply 

pub trait ReadReply {
    // Required method
    fn with_dataver(self, dataver: u32) -> Result<Option<impl Reply>, Error>;
}
A trait for encoding the attribute value for an attribute read operation.

Required Methods

fn with_dataver(self, dataver: u32) -> Result<Option<impl Reply>, Error>

Return the reply data writer for an attribute, if the given dataver is still the latest cluster dataver.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors