WriteContext

Trait WriteContext 

pub trait WriteContext: OperationContext {
    // Required methods
    fn attr(&self) -> &AttrDetails;
    fn data(&self) -> &TLVElement<'_>;

    // Provided method
    fn notify_changed(&self) { ... }
}
A context type that is passed to the handler when processing an attribute Write operation.

Required Methods

fn attr(&self) -> &AttrDetails

Return the attribute object that is associated with this write operation.

fn data(&self) -> &TLVElement<'_>

Return the attribute data that is associated with this write operation.

Provided Methods

fn notify_changed(&self)

Notify that the state of the attribute whose write operation is processed has changed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> WriteContext for &T
where T: WriteContext,

Implementors