Fabrics

Struct Fabrics 

pub struct Fabrics { /* private fields */ }
All fabrics

Implementations

Source

impl Fabrics

pub const fn new() -> Fabrics

Create a new Fabrics instance

pub fn init() -> impl Init<Fabrics>

Return an in-place-initializer for a Fabrics type

pub fn reset(&mut self)

Remove all fabrics

pub fn reset_persist<S>( &mut self, store: S, buf: &mut [u8], ) -> Result<(), Error>
where S: KvBlobStore,

Remove all fabrics from the provided BLOB store as well as from memory.

Arguments
  • store: the BLOB store to remove the fabrics from
  • buf: a temporary buffer to use for removing the fabrics
pub fn load_persist<S>(&mut self, store: S, buf: &mut [u8]) -> Result<(), Error>
where S: KvBlobStore,

Load all fabrics from the provided BLOB store

Arguments
  • store: the BLOB store to load the fabrics from
  • buf: a temporary buffer to use for loading the fabrics
pub fn add_with_post_init<F>( &mut self, post_init: F, ) -> Result<&mut Fabric, Error>
where F: FnOnce(&mut Fabric) -> Result<(), Error>,

Add a new fabric to the fabrics with the provided data and immediately updates it with the provided post-init updater.

This method is unlikely to be useful outside of tests.

If this operation succeeds, the fabric immediately becomes operational.

pub fn add<C>( &mut self, crypto: C, secret_key: CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonPkcSecretKeyRef::{constant#0}>, root_ca: &[u8], noc: &[u8], icac: &[u8], epoch_key: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonAeadKeyRef::{constant#0}>>, vendor_id: u16, case_admin_subject: u64, ) -> Result<&mut Fabric, Error>
where C: Crypto,

Add a new fabric to the fabrics with the provided data.

If this operation succeeds, the fabric immediately becomes operational.

pub fn update<C>( &mut self, crypto: C, fab_idx: NonZero<u8>, secret_key: CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonPkcSecretKeyRef::{constant#0}>, noc: &[u8], icac: &[u8], ) -> Result<&mut Fabric, Error>
where C: Crypto,

Update an existing fabric with the provided data (usually, as a result of an UpdateNOC IM command).

The fabric’s existing root cert is preserved across this call — UpdateNOC per Matter Core spec is not allowed to change the root, and re-passing the bytes would force the caller to take a (large) heap-less copy of Fabric::root_ca.

If this operation succeeds, the fabric immediately becomes operational. Note however, that the caller is expected to remove all sessions associated with the fabric, as they would contain invalid keys after the NOC update.

pub fn update_label( &mut self, fab_idx: NonZero<u8>, label: &str, ) -> Result<&mut Fabric, Error>

pub fn remove(&mut self, fab_idx: NonZero<u8>) -> Result<(), Error>

Remove a fabric from the fabrics

pub fn get_by_dest_id<C>( &self, crypto: C, random: &[u8], target: &[u8], ) -> Option<&Fabric>
where C: Crypto,

Get a fabric that matches the provided destination ID

pub fn get(&self, fab_idx: NonZero<u8>) -> Option<&Fabric>

Get a fabric by its local index

pub fn get_mut(&mut self, fab_idx: NonZero<u8>) -> Option<&mut Fabric>

Get a mutable fabric reference by its local index

pub fn iter(&self) -> impl Iterator<Item = &Fabric>

Iterate over the fabrics

pub fn fabric(&self, fab_idx: NonZero<u8>) -> Result<&Fabric, Error>

Get a fabric by its local index

Returns an error if the fabric is not found

pub fn fabric_mut(&mut self, fab_idx: NonZero<u8>) -> Result<&mut Fabric, Error>

Get a mutable fabric reference by its local index

Returns an error if the fabric is not found

pub fn allow(&self, req: &AccessReq<'_>, aux_acl_enabled: bool) -> bool

Check if the given access request should be allowed, based on all operational fabrics and their ACLs

aux_acl_enabled conveys whether the node advertises the Access Control cluster’s AUXILIARY feature - see AclEntry::allow.