pub struct Groups { /* private fields */ }Implementations
Sourceimpl Groups
impl Groups
Sourcepub fn key_set_iter(&self) -> impl Iterator<Item = &GroupKeySet>
pub fn key_set_iter(&self) -> impl Iterator<Item = &GroupKeySet>
Return an iterator over the group key sets of the fabric
Sourcepub fn key_set_get(&self, id: u16) -> Option<&GroupKeySet>
pub fn key_set_get(&self, id: u16) -> Option<&GroupKeySet>
Find a group key set by ID
Sourcepub fn key_set_add(&mut self, entry: GroupKeySet) -> Result<(), Error>
pub fn key_set_add(&mut self, entry: GroupKeySet) -> Result<(), Error>
Add or update a group key set
Sourcepub fn key_set_remove(&mut self, id: u16) -> Result<(), Error>
pub fn key_set_remove(&mut self, id: u16) -> Result<(), Error>
Remove a group key set by ID. Returns true if found and removed.
pub fn key_map_add(&mut self, entry: GroupKeyMapping) -> Result<(), Error>
Sourcepub fn key_map_iter(&self) -> impl Iterator<Item = &GroupKeyMapping>
pub fn key_map_iter(&self) -> impl Iterator<Item = &GroupKeyMapping>
Return an iterator over the group key map entries of the fabric
Sourcepub fn key_map_replace(
&mut self,
entries: impl Iterator<Item = GroupKeyMapping>,
) -> Result<(), Error>
pub fn key_map_replace( &mut self, entries: impl Iterator<Item = GroupKeyMapping>, ) -> Result<(), Error>
Replace all group key map entries
Sourcepub fn key_map_remove_by_key_set(&mut self, key_set_id: u16)
pub fn key_map_remove_by_key_set(&mut self, key_set_id: u16)
Remove group key map entries that reference a specific key set ID
Sourcepub fn iter(&self) -> impl Iterator<Item = &GroupEndpointMapping>
pub fn iter(&self) -> impl Iterator<Item = &GroupEndpointMapping>
Return an iterator over the group table entries
Sourcepub fn get(&self, group_id: u16) -> Option<&GroupEndpointMapping>
pub fn get(&self, group_id: u16) -> Option<&GroupEndpointMapping>
Look up a group by ID