pub struct NocFlags(/* private fields */);Implementations
Sourceimpl NocFlags
impl NocFlags
pub const ADD_CSR_REQ_RECVD: NocFlags
pub const UPDATE_CSR_REQ_RECVD: NocFlags
pub const ADD_ROOT_CERT_RECVD: NocFlags
pub const ADD_NOC_RECVD: NocFlags
pub const UPDATE_NOC_RECVD: NocFlags
Sourceimpl NocFlags
impl NocFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<NocFlags>
pub const fn from_bits(bits: u8) -> Option<NocFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> NocFlags
pub const fn from_bits_truncate(bits: u8) -> NocFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> NocFlags
pub const fn from_bits_retain(bits: u8) -> NocFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<NocFlags>
pub fn from_name(name: &str) -> Option<NocFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: NocFlags) -> bool
pub const fn intersects(&self, other: NocFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: NocFlags) -> bool
pub const fn contains(&self, other: NocFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: NocFlags)
pub fn remove(&mut self, other: NocFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: NocFlags)
pub fn toggle(&mut self, other: NocFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: NocFlags, value: bool)
pub fn set(&mut self, other: NocFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: NocFlags) -> NocFlags
pub const fn intersection(self, other: NocFlags) -> NocFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: NocFlags) -> NocFlags
pub const fn union(self, other: NocFlags) -> NocFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: NocFlags) -> NocFlags
pub const fn difference(self, other: NocFlags) -> NocFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: NocFlags) -> NocFlags
pub const fn symmetric_difference(self, other: NocFlags) -> NocFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> NocFlags
pub const fn complement(self) -> NocFlags
The bitwise negation (!) of the bits in self, truncating the result.