BusyInteractionModel

Struct BusyInteractionModel 

pub struct BusyInteractionModel(/* private fields */);
A Interaction Model implementation that is only capable of sending Busy status codes

Use with e.g.

let matter = Matter::new(...);

// ...

let busy_responder = Responder::new("IM Busy Responder", BusyInteractionModel::new(), &matter, 200/*ms*/);
busy_responder.run::<10>().await?;

… to respond with “I’m busy, please try later” or similar status codes to all incoming IM messages, which were not accepted in time by the actual Interaction Model responder, due to all its handlers being occupied with work.

Implementations

Source

impl BusyInteractionModel

pub const fn new() -> BusyInteractionModel

pub async fn handle(&self, exchange: Exchange<'_>) -> Result<(), Error>