AttrStatus

Struct AttrStatus 

pub struct AttrStatus {
    pub path: AttrPath,
    pub status: Status,
}
A status response for an attribute in the Interaction Model.

Corresponds to the AttrStatusIB TLV structure in the Interaction Model.

Fields

path: AttrPath

The path to the attribute.

status: Status

The status of the attribute operation.

Implementations

Source

impl AttrStatus

pub const fn new( path: AttrPath, status: IMStatusCode, cluster_status: Option<u16>, ) -> AttrStatus

Create a new AttrStatus with the given path, status code, and optional cluster status.

pub const fn from_gp( path: &GenericPath, status: IMStatusCode, cluster_status: Option<u16>, ) -> AttrStatus

Create a new AttrStatus from a GenericPath, status code, and optional cluster status.

ATTENTION: the actual reply AttrPath will be filled with the GenericPath values, however these are not necessarily expressing the full path of the incoming data as AttrPath does.

Hence, this method is primarily useful for unit tests.