pub struct GenericPath {
pub endpoint: Option<u16>,
pub cluster: Option<u32>,
pub leaf: Option<u32>,
}Expand description
A generic (possibly a wildcard) path with endpoint, clusters, and a leaf
The leaf could be a command, an attribute, or an event
Note that this type does not implement FromTLV / ToTLV because it does not correspond
to a specific TLV structure in the Interaction Model.
Note also that it only captures a subset of the fields of AttrPath, and as such, it should be used with care!
Look at AttrPath, CmdPath, and EventPath for specific TLV structures, which
can be turned into GenericPath using their to_gp() method.
Fields
endpoint: Option<u16>The endpoint ID, if specified, otherwise None for wildcard
cluster: Option<u32>The cluster ID, if specified, otherwise None for wildcard
leaf: Option<u32>The leaf ID, if specified, otherwise None for wildcard
Implementations
Sourceimpl GenericPath
impl GenericPath
Sourcepub const fn new(
endpoint: Option<u16>,
cluster: Option<u32>,
leaf: Option<u32>,
) -> GenericPath
pub const fn new( endpoint: Option<u16>, cluster: Option<u32>, leaf: Option<u32>, ) -> GenericPath
Create a new GenericPath with the given endpoint, cluster, and leaf.
Sourcepub fn not_wildcard(&self) -> Result<(u16, u32, u32), Error>
pub fn not_wildcard(&self) -> Result<(u16, u32, u32), Error>
Return Ok, if the path is non wildcard, otherwise returns an error
Sourcepub const fn is_wildcard(&self) -> bool
pub const fn is_wildcard(&self) -> bool
Return true, if the path is wildcard