OpCode

Enum OpCode 

pub enum OpCode {
    Reserved = 0,
    StatusResponse = 1,
    ReadRequest = 2,
    SubscribeRequest = 3,
    SubscribeResponse = 4,
    ReportData = 5,
    WriteRequest = 6,
    WriteResponse = 7,
    InvokeRequest = 8,
    InvokeResponse = 9,
    TimedRequest = 10,
}
An enumeration of all possible opcodes used in the Interaction Model.

Variants



Reserved = 0



StatusResponse = 1



ReadRequest = 2



SubscribeRequest = 3



SubscribeResponse = 4



ReportData = 5



WriteRequest = 6



WriteResponse = 7



InvokeRequest = 8



InvokeResponse = 9



TimedRequest = 10

Implementations

Source

impl OpCode

pub const fn meta(&self) -> MessageMeta

Return the opcode as a MessageMeta structure, which contains the protocol ID, opcode, and reliability information.

Reliability is set to true as all IM messages are reliable.

pub const fn is_tlv(&self) -> bool

Return true if the opcode payload is in TLV format.

Currently, the payload of all IM opcodes except Reserved is in TLV format.