expand_write

Function expand_write 

pub fn expand_write<'m, M>(
    metadata: M,
    req: &'m WriteReq<'_>,
    accessor: &'m Accessor<'m>,
) -> Result<impl Iterator<Item = Result<Result<(AttrDetails, TLVElement<'m>), AttrStatus>, Error>> + 'm, Error>
where M: Metadata + 'm,
Expand (potentially wildcard) write requests into concrete attribute details using the node metadata.

As part of the expansion, the method will check whether the attributes are accessible by the accessor and filter out the inaccessible ones (wildcard writes) or report an error status for the non-wildcard ones.