pub struct HandlerInvoker<'a, 'b, C> { /* private fields */ }Implementations
Sourceimpl<'a, 'b, C> HandlerInvoker<'a, 'b, C>where
C: HandlerContext,
impl<'a, 'b, C> HandlerInvoker<'a, 'b, C>where
C: HandlerContext,
pub const fn new( exchange: &'b mut Exchange<'a>, context: C, ) -> HandlerInvoker<'a, 'b, C>
pub fn exchange(&mut self) -> &mut Exchange<'a>
pub async fn process_read( &mut self, item: &Result<AttrDetails, AttrStatus>, tw: &mut WriteBuf<'_>, ) -> Result<(), Error>
pub async fn read( &mut self, attr: &AttrDetails, tw: &mut WriteBuf<'_>, ) -> Result<(), Error>
pub async fn process_write( &mut self, item: &Result<(AttrDetails, TLVElement<'_>), AttrStatus>, tw: &mut WriteBuf<'_>, ) -> Result<(), Error>
pub async fn write( &mut self, attr: &AttrDetails, data: &TLVElement<'_>, ) -> Result<(), Error>
Sourcepub async fn process_invoke(
&mut self,
item: &Result<(CmdDetails, TLVElement<'_>), CmdStatus>,
tw: &mut WriteBuf<'_>,
) -> Result<bool, Error>
pub async fn process_invoke( &mut self, item: &Result<(CmdDetails, TLVElement<'_>), CmdStatus>, tw: &mut WriteBuf<'_>, ) -> Result<bool, Error>
Process one expanded invoke item.
Returns whether the item was successfully invoked on its handler (used by the Groupcast testing mode to report group-invoke outcomes).
pub async fn invoke( &mut self, cmd: &CmdDetails, data: &TLVElement<'_>, tw: &mut WriteBuf<'_>, ) -> Result<(), Error>