pub struct InvReq<'a>(/* private fields */);Expand description
A request to invoke commands in the Interaction Model.
Corresponds to the InvokeRequestMessage struct in the Matter Core spec.
Implementations
Sourceimpl<'a> InvReq<'a>
impl<'a> InvReq<'a>
Sourcepub const fn new(element: TLVElement<'a>) -> InvReq<'a>
pub const fn new(element: TLVElement<'a>) -> InvReq<'a>
Create a new InvReq instance from the given TLV element.
Sourcepub fn suppress_response(&self) -> Result<bool, Error>
pub fn suppress_response(&self) -> Result<bool, Error>
Return true if the request indicates that the response should be suppressed.
Sourcepub fn timed_request(&self) -> Result<bool, Error>
pub fn timed_request(&self) -> Result<bool, Error>
Return true if the request indicates that it is a timed request.
Sourcepub fn inv_requests(
&self,
) -> Result<Option<TLVContainer<'a, CmdData<'a>, ArrayContainer>>, Error>
pub fn inv_requests( &self, ) -> Result<Option<TLVContainer<'a, CmdData<'a>, ArrayContainer>>, Error>
Return the invocation requests contained in this request.