pub struct ReadReq<'a>(/* private fields */);Expand description
A request to read attributes and events from a Matter device.
Corresponds to the ReadRequestMessage TLV structure in the Interaction Model.
Implementations
Sourceimpl<'a> ReadReq<'a>
impl<'a> ReadReq<'a>
Sourcepub const fn new(element: TLVElement<'a>) -> ReadReq<'a>
pub const fn new(element: TLVElement<'a>) -> ReadReq<'a>
Create a new ReadReq from a TLVElement.
Sourcepub fn attr_requests(
&self,
) -> Result<Option<TLVContainer<'a, AttrPath, ArrayContainer>>, Error>
pub fn attr_requests( &self, ) -> Result<Option<TLVContainer<'a, AttrPath, ArrayContainer>>, Error>
Return the attribute requests in this read request, if any.
Sourcepub fn event_requests(
&self,
) -> Result<Option<TLVContainer<'a, EventPath, ArrayContainer>>, Error>
pub fn event_requests( &self, ) -> Result<Option<TLVContainer<'a, EventPath, ArrayContainer>>, Error>
Return the event requests in this read request, if any.
Sourcepub fn event_filters(
&self,
) -> Result<Option<TLVContainer<'a, EventFilter, ArrayContainer>>, Error>
pub fn event_filters( &self, ) -> Result<Option<TLVContainer<'a, EventFilter, ArrayContainer>>, Error>
Return the event filters in this read request, if any.
Sourcepub fn fabric_filtered(&self) -> Result<bool, Error>
pub fn fabric_filtered(&self) -> Result<bool, Error>
Return Ok(true) if this read request is fabric-filtered.
Sourcepub fn dataver_filters(
&self,
) -> Result<Option<TLVContainer<'a, DataVersionFilter, ArrayContainer>>, Error>
pub fn dataver_filters( &self, ) -> Result<Option<TLVContainer<'a, DataVersionFilter, ArrayContainer>>, Error>
Return the data version filters in this read request, if any.