pub struct SubscribeReq<'a>(/* private fields */);Expand description
A request to subscribe to attributes and events from a Matter device.
Corresponds to the SubscribeRequestMessage TLV structure in the Interaction Model.
Implementations
Sourceimpl<'a> SubscribeReq<'a>
impl<'a> SubscribeReq<'a>
Sourcepub const fn new(element: TLVElement<'a>) -> SubscribeReq<'a>
pub const fn new(element: TLVElement<'a>) -> SubscribeReq<'a>
Create a new SubscribeReq from a TLVElement.
Sourcepub fn keep_subs(&self) -> Result<bool, Error>
pub fn keep_subs(&self) -> Result<bool, Error>
Return Ok(true) if this subscription request should keep existing subscriptions.
Sourcepub fn min_int_floor(&self) -> Result<u16, Error>
pub fn min_int_floor(&self) -> Result<u16, Error>
Return the minimum interval floor for this subscription request.
Sourcepub fn max_int_ceil(&self) -> Result<u16, Error>
pub fn max_int_ceil(&self) -> Result<u16, Error>
Return the maximum interval ceiling for this subscription request.
Sourcepub fn attr_requests(
&self,
) -> Result<Option<TLVContainer<'a, AttrPath, ArrayContainer>>, Error>
pub fn attr_requests( &self, ) -> Result<Option<TLVContainer<'a, AttrPath, ArrayContainer>>, Error>
Return the attribute requests in this subscription request, if any.
Sourcepub fn event_requests(
&self,
) -> Result<Option<TLVContainer<'a, EventPath, ArrayContainer>>, Error>
pub fn event_requests( &self, ) -> Result<Option<TLVContainer<'a, EventPath, ArrayContainer>>, Error>
Return the event requests in this subscription request, if any.
Sourcepub fn event_filters(
&self,
) -> Result<Option<TLVContainer<'a, EventFilter, ArrayContainer>>, Error>
pub fn event_filters( &self, ) -> Result<Option<TLVContainer<'a, EventFilter, ArrayContainer>>, Error>
Return the event filters in this subscription request, if any.
Sourcepub fn fabric_filtered(&self) -> Result<bool, Error>
pub fn fabric_filtered(&self) -> Result<bool, Error>
Return Ok(true) if this subscription request is fabric-filtered.
Sourcepub fn dataver_filters(
&self,
) -> Result<Option<TLVContainer<'a, DataVersionFilter, ArrayContainer>>, Error>
pub fn dataver_filters( &self, ) -> Result<Option<TLVContainer<'a, DataVersionFilter, ArrayContainer>>, Error>
Return the data version filters in this subscription request, if any.