pub struct WriteReq<'a>(/* private fields */);Expand description
A request to write attributes to a Matter device.
Corresponds to the WriteRequestMessage TLV structure in the Interaction Model.
Implementations
Sourceimpl<'a> WriteReq<'a>
impl<'a> WriteReq<'a>
Sourcepub const fn new(element: TLVElement<'a>) -> WriteReq<'a>
pub const fn new(element: TLVElement<'a>) -> WriteReq<'a>
Create a new WriteReq from a TLVElement.
Sourcepub fn supress_response(&self) -> Result<bool, Error>
pub fn supress_response(&self) -> Result<bool, Error>
Return Ok(true) if this write request should suppress the response.
Sourcepub fn timed_request(&self) -> Result<bool, Error>
pub fn timed_request(&self) -> Result<bool, Error>
Return Ok(true) if this write request is a timed request.
Sourcepub fn write_requests(
&self,
) -> Result<TLVContainer<'a, AttrData<'_>, ArrayContainer>, Error>
pub fn write_requests( &self, ) -> Result<TLVContainer<'a, AttrData<'_>, ArrayContainer>, Error>
Return the attribute data to write in this write request.
Sourcepub fn more_chunks(&self) -> Result<bool, Error>
pub fn more_chunks(&self) -> Result<bool, Error>
Return Ok(true) if this write request has more chunks
(i.e. more write requests coming after this one, which are for the same exchange/transaction).