Module subscriptions

Module subscriptions 

Structs

ReportContext
Per-subscription context for an in-progress report.
Subscription
SubscriptionIds
The IDs of a subscription, used to identify it across the system and to route reports to it.
Subscriptions
A type for tracking subscriptions accepted by the data model.
SubscriptionsBuffers
A struct for the RX buffers containing the read requests of the tracked subscriptions.

Constants

DEFAULT_MAX_SUBSCRIPTIONS
The maximum number of subscriptions that can be tracked at the same time by default.
MAX_CHANGED_ATTRS
The maximum number of changed-attribute entries tracked simultaneously.