pub struct SubscriptionIds {
pub id: u32,
pub fab_idx: NonZero<u8>,
pub peer_node_id: u64,
}Expand description
The IDs of a subscription, used to identify it across the system and to route reports to it.
Fields
id: u32The ID of the subscription. Uniquely identifies the subscription across all of them.
fab_idx: NonZero<u8>The fabric index of the subscriber. Used to route reports and to remove all subscriptions of a fabric when it gets removed.
peer_node_id: u64The node ID of the subscriber. Used to route reports and to remove all subscriptions of a peer when it gets removed.