macro_rules! attributes {
() => { ... };
($attr0:expr $(, $attr:expr)* $(,)?) => { ... };
}Expand description
Re-export the rs-matter crate
A macro to generate the attributes for a cluster.
macro_rules! attributes {
() => { ... };
($attr0:expr $(, $attr:expr)* $(,)?) => { ... };
}Re-export the rs-matter crate
A macro to generate the attributes for a cluster.