macro_rules! commands {
($($cmd:expr $(,)?)*) => { ... };
}Expand description
Re-export the rs-matter crate
A macro to generate the commands for a cluster.
macro_rules! commands {
($($cmd:expr $(,)?)*) => { ... };
}Re-export the rs-matter crate
A macro to generate the commands for a cluster.