pub struct Persist<S> { /* private fields */ }Expand description
A utility for persisting a value in a KvBlobStore instance.
Implementations
Sourceimpl<S> Persist<S>where
S: KvBlobStoreAccess,
impl<S> Persist<S>where
S: KvBlobStoreAccess,
Sourcepub const fn new(kvb: S) -> Persist<S>
pub const fn new(kvb: S) -> Persist<S>
Create a new Persist instance with the given key-value store instance.
Sourcepub fn store<F>(&mut self, key: u16, f: F) -> Result<(), Error>
pub fn store<F>(&mut self, key: u16, f: F) -> Result<(), Error>
Save a value in the storage with the specified key by calling the provided closure to serialize the value into a buffer.
Sourcepub fn store_tlv<T>(&mut self, key: u16, tlv: T) -> Result<(), Error>where
T: ToTLV,
pub fn store_tlv<T>(&mut self, key: u16, tlv: T) -> Result<(), Error>where
T: ToTLV,
Save a value that implements the ToTLV trait in the storage with the specified key.