pub struct ChainedExchangeHandler<H, T> {
pub handler_proto: u16,
pub handler: H,
pub next: T,
}Expand description
A struct for chaining two exchange handlers into a single one, where each handler is handling one specific protocol (i.e. SC vs IM) in a sequential fashion. I.e. if the first exchange handler refuses to handle the exchange, the second one is tried.
Fields
handler_proto: u16handler: Hnext: TImplementations
Sourceimpl<H, T> ChainedExchangeHandler<H, T>
impl<H, T> ChainedExchangeHandler<H, T>
Sourcepub const fn new(
handler_proto: u16,
handler: H,
next: T,
) -> ChainedExchangeHandler<H, T>
pub const fn new( handler_proto: u16, handler: H, next: T, ) -> ChainedExchangeHandler<H, T>
Construct a chained handler that works as follows:
- It will call the provided
handlerinstance if the protocol ID of the incoming message does match the suppliedhandler_protovalue. - Otherwise, it will call the
nexthandler
Sourcepub const fn chain<H2>(
self,
handler_proto: u16,
handler: H2,
) -> ChainedExchangeHandler<H2, ChainedExchangeHandler<H, T>>
pub const fn chain<H2>( self, handler_proto: u16, handler: H2, ) -> ChainedExchangeHandler<H2, ChainedExchangeHandler<H, T>>
Chain itself with another exchange handler.
The returned chained handler works as follows:
- It will call the provided
handlerinstance if the protocol ID of the incoming message does match the suppliedhandler_protovalue. - Otherwise, it will call the
selfhandler