DefaultResponder

Struct DefaultResponder 

pub struct DefaultResponder<'d, 'a, C, B, T, K, N, NC = NoopWirelessNetCtl, R = (), const NS: usize = rs_matter::::respond::DefaultResponder::{constant#0}, const NE: usize = rs_matter::::respond::DefaultResponder::{constant#1}>
where B: Buffers<Vec<u8, rs_matter::::transport::exchange::Buffer::{constant#0}>>,
{ /* private fields */ }
A composition of the Responder::new_default and Responder::new_busy responders.

Implementations

Source

impl<'d, 'a, C, B, T, K, N, NC, R, const NS: usize, const NE: usize> DefaultResponder<'d, 'a, C, B, T, K, N, NC, R, NS, NE>
where C: Crypto, B: Buffers<Vec<u8, rs_matter::::transport::exchange::Buffer::{constant#0}>>, T: DataModel, K: KvBlobStoreAccess, N: Networks, R: ReportDataHandler,

pub const fn new( data_model: &'d InteractionModel<'a, C, B, T, K, N, NC, R, NS, NE>, ) -> DefaultResponder<'d, 'a, C, B, T, K, N, NC, R, NS, NE>

Creates the responder composition.

pub async fn run<const A: usize, const O: usize>(&self) -> Result<(), Error>

Run the responder.

pub const fn responder( &self, ) -> &Responder<'a, ChainedExchangeHandler<&'d InteractionModel<'a, C, B, T, K, N, NC, R, NS, NE>, SecureChannel<'d, &'d C>>>

Get a reference to the main responder.

Useful when the user would like to organize its own herd of responders rather than using the run method.

pub const fn busy_responder( &self, ) -> &Responder<'a, ChainedExchangeHandler<BusyInteractionModel, BusySecureChannel>>

Get a reference to the busy responder.

Useful when the user would like to organize its own herd of busy responders rather than using the run method.