ExchangeHandler

Trait ExchangeHandler 

pub trait ExchangeHandler {
    // Required method
    async fn handle(&self, exchange: Exchange<'_>) -> Result<(), Error>;
}
A trait modeling a generic handler for an exchange.

The handler takes ownership of the exchange: once handling is done, the only thing left to do with the exchange is to drop it (which ends it).

Required Methods

async fn handle(&self, exchange: Exchange<'_>) -> Result<(), Error>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> ExchangeHandler for &T
where T: ExchangeHandler,

Source

fn handle( &self, exchange: Exchange<'_>, ) -> impl Future<Output = Result<(), Error>>

Implementors

Source

impl ExchangeHandler for BusyInteractionModel

Source

impl ExchangeHandler for BusySecureChannel

Source

impl ExchangeHandler for EmptyExchangeHandler

Source

impl<C, B, T, K, N, NC, R, const NS: usize, const NE: usize> ExchangeHandler for InteractionModel<'_, C, B, T, K, N, NC, R, NS, NE>
where C: Crypto, B: Buffers<Vec<u8, rs_matter::::transport::exchange::Buffer::{constant#0}>>, T: DataModel, K: KvBlobStoreAccess, N: Networks, R: ReportDataHandler,

Source

impl<C, H> ExchangeHandler for SecureChannel<'_, C, H>
where C: Crypto, H: AsyncScHandler,

Source

impl<H, T> ExchangeHandler for ChainedExchangeHandler<H, T>

Source

impl<T> ExchangeHandler for Bdx<T>
where T: BdxHandler,