pub enum CommWindowState {
Closed,
Open {
opener: Option<CommWindowOpener>,
},
}Expand description
Whether a PASE commissioning window is open, and - if so - who opened it
Variants
Closed
No commissioning window is open
Open
A commissioning window is open
Fields

opener: Option<CommWindowOpener>The administrator that opened the window over a CASE session, or None when the
device opened it itself, which is the case for initial commissioning
Implementations
Sourceimpl CommWindowState
impl CommWindowState
Sourcepub const fn is_open(&self) -> bool
pub const fn is_open(&self) -> bool
Return true if a commissioning window is open.
This is the condition under which the device is discoverable as commissionable and will accept PASE.
Sourcepub const fn is_open_on_all_transports(&self) -> bool
pub const fn is_open_on_all_transports(&self) -> bool
Return true if a commissioning window is open and should be advertised on every
supported transport, rather than on the operational IP network alone.