Pase

Struct Pase 

pub struct Pase { /* private fields */ }
The PASE state

Implementations

Source

impl Pase

pub const fn new() -> Pase

Create a new PASE state

pub fn init() -> impl Init<Pase>

Return an in-place initializer for the PASE manager

pub fn check_comm_window_timeout( &mut self, notify_mdns: impl FnMut(), notify_change: impl FnMut(u16, u32), ) -> Result<bool, Error>

Check if the opened commissioning window has expired, and close it if so.

This should be called periodically to ensure that the commissioning window state is updated in a timely manner. Ideally, it should also be called at the beginning of any API that requires the commissioning window to be opened to ensure that the state is up to date.

pub fn comm_window(&self) -> Option<&CommWindow>

Get the opened commissioning window, if any

pub fn comm_window_state(&self) -> CommWindowState

Return the state of the commissioning window - whether one is open, and if so who opened it. See CommWindowState for what the answer is good for.

pub fn open_basic_comm_window( &mut self, mdns_id: u64, salt: &[u8], password: CryptoSensitiveRef<'_, rs_matter::::sc::pase::spake2p::Spake2pVerifierPasswordRef::{constant#0}>, discriminator: u16, timeout_secs: u16, opener: Option<CommWindowOpener>, notify_mdns: impl FnMut(), notify_change: impl FnMut(u16, u32), ) -> Result<(), Error>

Open a basic commissioning window using a passcode

Arguments
  • mdns_id - The mDNS identifier
  • salt - The salt bytes (16..=32 bytes, validated upstream)
  • password - The passcode
  • discriminator - The discriminator
  • timeout_secs - The timeout in seconds of the validity of the window
  • opener - The opener info
  • mdns_notif - The mDNS notification callback
Returns
  • Ok(()) if the window was opened successfully
  • Err(Error) if an error occurred (i.e. there is another non-expired commissioning window already opened or the timeout is invalid)
pub fn open_comm_window( &mut self, mdns_id: u64, verifier: CryptoSensitiveRef<'_, rs_matter::::sc::pase::spake2p::Spake2pVerifierStrRef::{constant#0}>, salt: &[u8], count: u32, discriminator: u16, timeout_secs: u16, opener: Option<CommWindowOpener>, notify_mdns: impl FnMut(), notify_change: impl FnMut(u16, u32), ) -> Result<(), Error>

Open an enhanced commissioning window using a verifier

Arguments
  • mdns_id - The mDNS identifier
  • verifier - The verifier bytes
  • salt - The salt bytes (16..=32 bytes, validated upstream)
  • count - The iteration count
  • discriminator - The discriminator
  • timeout_secs - The timeout in seconds of the validity of the window
  • opener - The opener info
  • mdns_notif - The mDNS notification callback
Returns
  • Ok(()) if the window was opened successfully
  • Err(Error) if an error occurred (i.e. there is another non-expired commissioning window already opened or the timeout is invalid)
pub fn record_pake_failure( &mut self, notify_mdns: impl FnMut(), notify_change: impl FnMut(u16, u32), ) -> Result<(), Error>

Record a failed PAKE handshake against the currently-open commissioning window, and revoke the window if the limit is reached.

Per Matter Core spec, after 20 unsuccessful PAKE attempts the device SHALL revoke the open commissioning window.

Also clears the in-progress PASE establishment timeout so that the next handshake attempt is not rejected as “another session in progress” — without this, only the first wrong-passcode attempt would be counted because subsequent attempts would be short-circuited at the session-timeout gate.

Has no effect on the failure counter if no window is open.

pub fn close_comm_window( &mut self, notify_mdns: impl FnMut(), notify_change: impl FnMut(u16, u32), ) -> Result<bool, Error>

Close the opened commissioning window, if any

Arguments
  • ctx - The handler context
Returns
  • Ok(true) if a commissioning window was closed
  • Ok(false) if there was no commissioning window to close