pub struct BasicCommData {
pub password: CryptoSensitive<rs_matter::::sc::pase::spake2p::Spake2pVerifierPassword::{constant#0}>,
pub discriminator: u16,
}Expand description
Re-export the rs-matter crate
Device basic commissioning data
Fields
password: CryptoSensitive<rs_matter::::sc::pase::spake2p::Spake2pVerifierPassword::{constant#0}>The password which is necessary to authenticate the device in either initial commissioning, or when the basic commissioning window is opened
discriminator: u16The 12-bit discriminator used to differentiate between multiple devices
Implementations
Sourceimpl BasicCommData
impl BasicCommData
Sourcepub fn compute_pairing_code(
&self,
) -> StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 11]>>
pub fn compute_pairing_code( &self, ) -> StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 11]>>
Compute the manual pairing code string from the commissioning data
Sourcepub fn compute_pretty_pairing_code(
&self,
) -> StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 13]>>
pub fn compute_pretty_pairing_code( &self, ) -> StringInner<usize, VecStorageInner<[MaybeUninit<u8>; 13]>>
Compute the manual pairing code string from the commissioning data and return it in a pretty format with dashes.