pub enum TLVTag {
Anonymous,
Context(u8),
CommonPrf16(u16),
CommonPrf32(u32),
ImplPrf16(u16),
ImplPrf32(u32),
FullQual48 {
vendor_id: u16,
profile: u16,
tag: u16,
},
FullQual64 {
vendor_id: u16,
profile: u16,
tag: u32,
},
}Expand description
A high-level representation of a TLV tag (tag type and tag value).
A TLVTag can be constructed programmatically, or returned from a TLVElement.
Variants
Anonymous
Context(u8)
CommonPrf16(u16)
CommonPrf32(u32)
ImplPrf16(u16)
ImplPrf32(u32)
FullQual48
FullQual64
Implementations
Sourceimpl TLVTag
impl TLVTag
Sourcepub const fn tag_type(&self) -> TLVTagType
pub const fn tag_type(&self) -> TLVTagType
Return the tag type of the TLV tag.
Sourcepub fn iter(&self) -> TLVTagIter<&TLVTag> ⓘ
pub fn iter(&self) -> TLVTagIter<&TLVTag> ⓘ
Return an iterator over the bytes of the TLV tag.
Sourcepub fn into_iterator(self) -> TLVTagIter<TLVTag> ⓘ
pub fn into_iterator(self) -> TLVTagIter<TLVTag> ⓘ
Converts itself into an iterator over the bytes of the TLV tag.