#[repr(u8)]pub enum TLVValueType {
Show 25 variants
S8 = 0,
S16 = 1,
S32 = 2,
S64 = 3,
U8 = 4,
U16 = 5,
U32 = 6,
U64 = 7,
False = 8,
True = 9,
F32 = 10,
F64 = 11,
Utf8l = 12,
Utf16l = 13,
Utf32l = 14,
Utf64l = 15,
Str8l = 16,
Str16l = 17,
Str32l = 18,
Str64l = 19,
Null = 20,
Struct = 21,
Array = 22,
List = 23,
EndCnt = 24,
}Expand description
Represents the TLV value type encoded in the control byte of each TLV element.
Variants
S8 = 0
S16 = 1
S32 = 2
S64 = 3
U8 = 4
U16 = 5
U32 = 6
U64 = 7
False = 8
True = 9
F32 = 10
F64 = 11
Utf8l = 12
Utf16l = 13
Utf32l = 14
Utf64l = 15
Str8l = 16
Str16l = 17
Str32l = 18
Str64l = 19
Null = 20
Struct = 21
Array = 22
List = 23
EndCnt = 24
Implementations
Sourceimpl TLVValueType
impl TLVValueType
Sourcepub const fn fixed_size(&self) -> Option<usize>
pub const fn fixed_size(&self) -> Option<usize>
Return the size of the value corresponding to this value type.
If the value type has a variable size (i.e. octet and Utf8 strings), this function returns None.
Sourcepub const fn variable_size_len(&self) -> usize
pub const fn variable_size_len(&self) -> usize
Return the size of the length field for variable size value types.
if the value type has a fixed size, this function returns 0. Variable size types are only octet strings and utf8 strings.
Sourcepub const fn is_container(&self) -> bool
pub const fn is_container(&self) -> bool
Convenience method to check if the value type is a container type (container start or end).
Sourcepub const fn is_container_start(&self) -> bool
pub const fn is_container_start(&self) -> bool
Convenience method to check if the value type is a container start type.
Sourcepub const fn is_container_end(&self) -> bool
pub const fn is_container_end(&self) -> bool
Convenience method to check if the value type is a container end type.
Sourcepub const fn is_str(&self) -> bool
pub const fn is_str(&self) -> bool
Convenience method to check if the value type is an Octet String type.
Sourcepub const fn is_utf8(&self) -> bool
pub const fn is_utf8(&self) -> bool
Convenience method to check if the value type is a UTF-8 String type.
pub fn container_value<'a>(&self) -> Result<TLVValue<'a>, Error>