Skippable

Struct Skippable 

pub struct Skippable<T> { /* private fields */ }
A wrapper for a type T which might not always be present in the TLV stream.

Unlike Option<T> and Optional<T> though, Skippable<T> is NOT initialized to None when the value is not present in the TLV stream, but to a default T.

Implementations

Source

impl<T> Skippable<T>

pub const fn new(value: T) -> Skippable<T>

Create a new Skippable with the given value.

pub fn init<I, E>(value: I) -> impl Init<Skippable<T>, E>
where I: Init<T, E>,

Initialize a Skippable with the given initializer.

pub const fn value(&self) -> &T

pub const fn value_mut(&mut self) -> &mut T

Source

impl<T> Skippable<T>
where T: Default + InitDefault,

pub fn new_default() -> Skippable<T>

Create a new Skippable with the default value of T.

pub fn init_default() -> impl Init<Skippable<T>>

Initialize a Skippable with the default value of T.