pub struct TLVContainer<'a, T, C = ()> { /* private fields */ }Expand description
TLVContainer is an efficient (memory-wise) way to represent a serialized TLV container, in that
it does not materialize the container elements until the container is iterated over.
Therefore, TLVContainer is just a wrapper (newtype) of the serialized TLV container &[u8] slice.
Implementations
Sourceimpl<'a, T, C> TLVContainer<'a, T, C>where
T: FromTLV<'a>,
impl<'a, T, C> TLVContainer<'a, T, C>where
T: FromTLV<'a>,
Sourcepub const fn new_unchecked(element: TLVElement<'a>) -> TLVContainer<'a, T, C>
pub const fn new_unchecked(element: TLVElement<'a>) -> TLVContainer<'a, T, C>
Creates a new TLVContainer from a TLV element.
The constructor does not check whether the passed slice is a valid TLV container.
pub fn element(&self) -> &TLVElement<'a>
Sourcepub fn iter(&self) -> TLVContainerIter<'a, T> ⓘ
pub fn iter(&self) -> TLVContainerIter<'a, T> ⓘ
Returns an iterator over the elements of the container.
Sourceimpl<'a, T> TLVContainer<'a, T>where
T: FromTLV<'a>,
impl<'a, T> TLVContainer<'a, T>where
T: FromTLV<'a>,
Sourcepub fn new(element: TLVElement<'a>) -> Result<TLVContainer<'a, T>, Error>
pub fn new(element: TLVElement<'a>) -> Result<TLVContainer<'a, T>, Error>
Creates a new TLVContainer from a TLV element that can be any container.
Sourceimpl<'a, T> TLVContainer<'a, T, ArrayContainer>where
T: FromTLV<'a>,
impl<'a, T> TLVContainer<'a, T, ArrayContainer>where
T: FromTLV<'a>,
Sourcepub fn new(
element: TLVElement<'a>,
) -> Result<TLVContainer<'a, T, ArrayContainer>, Error>
pub fn new( element: TLVElement<'a>, ) -> Result<TLVContainer<'a, T, ArrayContainer>, Error>
Creates a new TLVContainer from a TLV element that is expected to be of type array.
Sourceimpl<'a, T> TLVContainer<'a, T, ListContainer>where
T: FromTLV<'a>,
impl<'a, T> TLVContainer<'a, T, ListContainer>where
T: FromTLV<'a>,
Sourcepub fn new(
element: TLVElement<'a>,
) -> Result<TLVContainer<'a, T, ListContainer>, Error>
pub fn new( element: TLVElement<'a>, ) -> Result<TLVContainer<'a, T, ListContainer>, Error>
Creates a new TLVContainer from a TLV element that is expected to be of type list.
Sourceimpl<'a, T> TLVContainer<'a, T, StructContainer>where
T: FromTLV<'a>,
impl<'a, T> TLVContainer<'a, T, StructContainer>where
T: FromTLV<'a>,
Sourcepub fn new(
element: TLVElement<'a>,
) -> Result<TLVContainer<'a, T, StructContainer>, Error>
pub fn new( element: TLVElement<'a>, ) -> Result<TLVContainer<'a, T, StructContainer>, Error>
Creates a new TLVContainer from a TLV element that is expected to be of type struct.