pub struct TLVControl {
pub tag_type: TLVTagType,
pub value_type: TLVValueType,
}Expand description
Represents the control byte of a TLV element (i.e. the tag type and the value type).
Fields
tag_type: TLVTagTypevalue_type: TLVValueTypeImplementations
Sourceimpl TLVControl
impl TLVControl
Sourcepub const fn new(tag_type: TLVTagType, value_type: TLVValueType) -> TLVControl
pub const fn new(tag_type: TLVTagType, value_type: TLVValueType) -> TLVControl
Create a new TLV control byte by parsing the provided tag type and value type.
Sourcepub fn parse(control: u8) -> Result<TLVControl, Error>
pub fn parse(control: u8) -> Result<TLVControl, Error>
Create a new TLV control byte by parsing the provided control byte into a tag type and a value type.
The function will return an error if the provided control byte is invalid.
Sourcepub fn is_container_start(&self) -> bool
pub fn is_container_start(&self) -> bool
Return true if the control byte represents a container start (struct, array or list).
Sourcepub fn is_container_end(&self) -> bool
pub fn is_container_end(&self) -> bool
Return true if the control byte represents a container end.
Sourcepub fn confirm_container_end(&self) -> Result<(), Error>
pub fn confirm_container_end(&self) -> Result<(), Error>
Return an error if the control byte does not represent a container start.