pub struct ToTLVBuilder<P, T> { /* private fields */ }Expand description
The ToTLVBuilder is a helper struct that allows for an ergonomic writing of
a TLV type that implements the ToTLV trait into a TLVWrite implementation.
This implementation is useful when the T type implements ToTLV.
Note that this implementation should be avoided when T has a large size, as it
needs the T instance to be materialized prior to writing into the TLV.
Implementations
Sourceimpl<P, T> ToTLVBuilder<P, T>where
P: TLVBuilderParent,
T: ToTLV + 'static,
impl<P, T> ToTLVBuilder<P, T>where
P: TLVBuilderParent,
T: ToTLV + 'static,