pub struct MessageMeta {
pub proto_id: u16,
pub proto_opcode: u8,
pub reliable: bool,
}Expand description
Meta-data when sending/receving messages via an Exchange. Basically, the protocol ID, the protocol opcode and whether the message should be set in a reliable manner.
Fields
proto_id: u16proto_opcode: u8reliable: boolImplementations
Sourceimpl MessageMeta
impl MessageMeta
pub const fn new(proto_id: u16, proto_opcode: u8, reliable: bool) -> MessageMeta
Sourcepub fn opcode<T>(&self) -> Result<T, Error>where
T: FromPrimitive,
pub fn opcode<T>(&self) -> Result<T, Error>where
T: FromPrimitive,
Try to cast the protocol opcode to a specific type
Sourcepub fn check_opcode<T>(&self, opcode: T) -> Result<(), Error>where
T: FromPrimitive + PartialEq,
pub fn check_opcode<T>(&self, opcode: T) -> Result<(), Error>where
T: FromPrimitive + PartialEq,
Check if the protocol opcode is equal to a specific value
Sourcepub fn from(proto: &ProtoHdr) -> MessageMeta
pub fn from(proto: &ProtoHdr) -> MessageMeta
Create an instance from a ProtoHdr instance
Sourcepub fn set_into(&self, proto: &mut ProtoHdr)
pub fn set_into(&self, proto: &mut ProtoHdr)
Set the protocol ID and opcode into a ProtoHdr instance
pub fn reliable(self, reliable: bool) -> MessageMeta