pub struct TxMessage<'a> { /* private fields */ }Expand description
Accessor to the TX message buffer of the underlying Matter transport stack.
This is used to construct a new TX message to be sent on an Exchange instance.
NOTE: It is strongly advised to use the TxMessage accessor in combination with the Sender utility,
which takes care of all message retransmission logic. Alternatively, one can use the
Exchange::send or Exchange::send_with which also take care of re-transmissions.
Implementations
Sourceimpl TxMessage<'_>
impl TxMessage<'_>
Sourcepub fn payload(&mut self) -> &mut [u8] ⓘ
pub fn payload(&mut self) -> &mut [u8] ⓘ
Get a reference to the payload buffer of the TX message being built
Sourcepub fn complete<M>(
self,
payload_start: usize,
payload_end: usize,
meta: M,
) -> Result<(), Error>where
M: Into<MessageMeta>,
pub fn complete<M>(
self,
payload_start: usize,
payload_end: usize,
meta: M,
) -> Result<(), Error>where
M: Into<MessageMeta>,
Complete and send a TX message by providing:
- The payload size that was filled-in by user code in the payload buffer returned by
TxMessage::payload - The TX message meta-data