ReliableMessage

Struct ReliableMessage 

pub struct ReliableMessage { /* private fields */ }

Implementations

Source

impl ReliableMessage

pub fn new() -> ReliableMessage

pub fn is_retrans_pending(&self) -> bool

pub fn is_ack_pending(&self) -> bool

pub fn has_rx_timed_out(&self, timeout_ms: u64) -> bool

pub fn pre_send( &mut self, tx_plain: &PlainHdr, tx_proto: &mut ProtoHdr, session_active_interval_ms: Option<u32>, _session_idle_interval_ms: Option<u32>, ) -> Result<(), Error>

pub fn post_recv( &mut self, rx_plain: &PlainHdr, rx_proto: &ProtoHdr, ) -> Result<(), Error>

This method will update the state of the rentransmission and ACK tables with the data from the incoming packet.

The method will return Ok if the message needs to be processed by the exchange layer, and an error if it needs to be dropped.

A note about Message ACKs, it is a bit asymmetric in the sense that:

  • there can be only one pending ACK per exchange (so this is per-exchange)
  • there can be only one pending retransmission per exchange (so this is per-exchange)
  • duplicate detection should happen per session (obviously), so that part is per-session