pub struct ChainedNetwork<H, T, F> {
pub handler_can_send: F,
pub handler: H,
pub next: T,
}Expand description
A network implementation that chains two network implementations together in a composite network interface.
This allows for e.g. a network implementation that can send/receive data to/from both a UDP and a TCP network interface - or - with e.g. further chaining - from all of UDP, TCP and BTP network interfaces.
Fields
handler_can_send: Fhandler: Hnext: TImplementations
Sourceimpl<H, T, F> ChainedNetwork<H, T, F>
impl<H, T, F> ChainedNetwork<H, T, F>
Sourcepub const fn new(
handler_can_send: F,
handler: H,
next: T,
) -> ChainedNetwork<H, T, F>
pub const fn new( handler_can_send: F, handler: H, next: T, ) -> ChainedNetwork<H, T, F>
Construct a chained handler that works as follows:
- When a packet is about to be send, the
handler_can_sendfunction is called with the destination address. If it returnstrue, the packet is sent via thehandlernetwork interface, otherwise it is sent via thenextnetwork interface. - When
wait_availableis called, the function waits until a packet is available on either network interface. - When
recv_fromis called, the function receives a packet from the first network interface that has a packet available.
Sourcepub const fn chain<H2, F2>(
self,
handler_can_send: F2,
handler: H2,
) -> ChainedNetwork<H2, ChainedNetwork<H, T, F>, F2>
pub const fn chain<H2, F2>( self, handler_can_send: F2, handler: H2, ) -> ChainedNetwork<H2, ChainedNetwork<H, T, F>, F2>
Chain itself with another handler.
The returned chained handler works as follows:
- When a packet is about to be send, the
handler_can_sendfunction is called with the destination address. If it returnstrue, the packet is sent via thehandlernetwork interface, otherwise it is sent viaself. - When
wait_availableis called, the function waits until a packet is available on either network interface. - When
recv_fromis called, the function receives a packet from the first network interface that has a packet available.