pub struct MsgFlags(/* private fields */);Implementations
Sourceimpl MsgFlags
impl MsgFlags
pub const DSIZ_UNICAST_NODEID: MsgFlags
pub const DSIZ_GROUPCAST_NODEID: MsgFlags
pub const SRC_ADDR_PRESENT: MsgFlags
Sourceimpl MsgFlags
impl MsgFlags
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<MsgFlags>
pub const fn from_bits(bits: u8) -> Option<MsgFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> MsgFlags
pub const fn from_bits_truncate(bits: u8) -> MsgFlags
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> MsgFlags
pub const fn from_bits_retain(bits: u8) -> MsgFlags
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<MsgFlags>
pub fn from_name(name: &str) -> Option<MsgFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: MsgFlags) -> bool
pub const fn intersects(&self, other: MsgFlags) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: MsgFlags) -> bool
pub const fn contains(&self, other: MsgFlags) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: MsgFlags)
pub fn remove(&mut self, other: MsgFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: MsgFlags)
pub fn toggle(&mut self, other: MsgFlags)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: MsgFlags, value: bool)
pub fn set(&mut self, other: MsgFlags, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: MsgFlags) -> MsgFlags
pub const fn intersection(self, other: MsgFlags) -> MsgFlags
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: MsgFlags) -> MsgFlags
pub const fn union(self, other: MsgFlags) -> MsgFlags
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: MsgFlags) -> MsgFlags
pub const fn difference(self, other: MsgFlags) -> MsgFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: MsgFlags) -> MsgFlags
pub const fn symmetric_difference(self, other: MsgFlags) -> MsgFlags
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> MsgFlags
pub const fn complement(self) -> MsgFlags
The bitwise negation (!) of the bits in self, truncating the result.