Module cell

Module cell 

A modification of the Rust RefCell type which provides in-place initialization via RefCell::init.

NOTE: TEMPORARY and subject to removal once all Matter state is hidden behind a blmutex::Mutex in future.

Structs

BorrowError
An error returned by RefCell::try_borrow.
BorrowMutError
An error returned by RefCell::try_borrow_mut.
Ref
Wraps a borrowed reference to a value in a RefCell box. A wrapper type for an immutably borrowed value from a RefCell<T>.
RefCell
A mutable memory location with dynamically checked borrow rules
RefMut
A wrapper type for a mutably borrowed value from a RefCell<T>.