decode

Function decode 

pub fn decode(base38_str: &str) -> impl Iterator<Item = Result<u8, Error>>
Decode a base38-encoded string into a byte slice

Arguments

  • base38_str - base38-encoded string to decode

Fails if the string contains invalid characters or if the supplied buffer is too small to fit the decoded data