Module pooled

Module pooled 

Structs

PooledBuffer
PooledBuffers
A concrete implementation of Buffers utilizing an internal pool of buffers. Accessing a buffer would fail when all buffers are still used elsewhere after a wait timeout expires.

Constants

DEFAULT_BUFFER_POOL_SIZE
The default number of buffers held by a PooledBuffers pool.

Traits

Buffers
A trait for getting access to a &mut T buffer, potentially awaiting until a buffer becomes available.