WriteBuf

Struct WriteBuf 

pub struct WriteBuf<'a> { /* private fields */ }

Implementations

Source

impl WriteBuf<'_>

pub fn str_cb( &mut self, tag: &TLVTag, cb: impl FnOnce(&mut [u8]) -> Result<usize, Error>, ) -> Result<(), Error>

Write a tag and a TLV Octet String to the TLV stream, where the Octet String is a slice of u8 bytes.

The writing is done via a user-supplied callback cb, that is expected to fill the provided buffer with the data and to return the length of the written data.

This method is useful when the data to be written needs to be computed first, and the computation needs a buffer where to operate.

Note that this method reserves a Str16l header before invoking the callback, restricting the data length to no more than 65535 bytes. If the actual length fits in a single byte, the header is downgraded in-place to a canonical Str8l encoding (shortest-form length), which some strict Matter controllers (e.g. SmartThings) require.

pub fn utf8_cb( &mut self, tag: &TLVTag, cb: impl FnOnce(&mut [u8]) -> Result<usize, Error>, ) -> Result<(), Error>

Write a tag and a TLV UTF-8 String to the TLV stream, where the UTF-8 String is a str.

The writing is done via a user-supplied callback cb, that is expected to fill the provided buffer with the data and to return the length of the written data.

This method is useful when the data to be written needs to be computed first, and the computation needs a buffer where to operate.

Note that this method reserves a Utf16l header before invoking the callback, restricting the data length to no more than 65535 bytes. If the actual length fits in a single byte, the header is downgraded in-place to a canonical Utf8l encoding (shortest-form length).

Source

impl<'a> WriteBuf<'a>

pub fn new(buf: &'a mut [u8]) -> WriteBuf<'a>

pub fn new_with(buf: &'a mut [u8], start: usize, end: usize) -> WriteBuf<'a>

pub fn get_start(&self) -> usize

pub fn get_tail(&self) -> usize

pub fn rewind_tail_to(&mut self, new_end: usize)

pub fn forward_tail_by(&mut self, new_offset: usize)

pub fn as_slice(&self) -> &[u8]

pub fn as_mut_slice(&mut self) -> &mut [u8]

pub fn empty_as_mut_slice(&mut self) -> &mut [u8]

pub fn split(self) -> (&'a mut [u8], WriteBuf<'a>)

pub fn split_str(self) -> (&'a str, WriteBuf<'a>)

pub fn into_buf(self) -> &'a mut [u8]

pub fn reset(&mut self)

pub fn load(&mut self, wb: &WriteBuf<'_>) -> Result<(), Error>

pub fn reserve(&mut self, reserve: usize) -> Result<(), Error>

pub fn shrink(&mut self, with: usize) -> Result<(), Error>

pub fn expand(&mut self, by: usize) -> Result<(), Error>

pub fn prepend_with<F>(&mut self, size: usize, f: F) -> Result<(), Error>
where F: FnOnce(&mut WriteBuf<'a>),

pub fn prepend(&mut self, src: &[u8]) -> Result<(), Error>

pub fn append_with_buf<F>(&mut self, f: F) -> Result<usize, Error>
where F: FnOnce(&mut [u8]) -> Result<usize, Error>,

pub fn append_with<F>(&mut self, size: usize, f: F) -> Result<(), Error>
where F: FnOnce(&mut WriteBuf<'a>),

pub fn append(&mut self, src: &[u8]) -> Result<(), Error>

pub fn copy_from_slice(&mut self, src: &[u8]) -> Result<(), Error>

pub fn le_i8(&mut self, data: i8) -> Result<(), Error>

pub fn le_u8(&mut self, data: u8) -> Result<(), Error>

pub fn le_u16(&mut self, data: u16) -> Result<(), Error>

pub fn le_i16(&mut self, data: i16) -> Result<(), Error>

pub fn le_u32(&mut self, data: u32) -> Result<(), Error>

pub fn le_i32(&mut self, data: i32) -> Result<(), Error>

pub fn le_u64(&mut self, data: u64) -> Result<(), Error>

pub fn le_i64(&mut self, data: i64) -> Result<(), Error>