IfMutex

Struct IfMutex 

pub struct IfMutex<T, M = NoopRawMutex>
where M: RawMutex, T: ?Sized,
{ /* private fields */ }
Async mutex with conditional locking based on the data inside the mutex. Check embassy_sync::Mutex for the original unconditional implementation.

Implementations

Source

impl<T, M> IfMutex<T, M>
where M: RawMutex,

Async mutex.

pub const fn new(value: T) -> IfMutex<T, M>

Create a new mutex with the given value.

pub fn init<I>(value: I) -> impl Init<IfMutex<T, M>>
where I: Init<T>,

Creates a mutex in-place initializer with the given value initializer.

Source

impl<T, M> IfMutex<T, M>
where M: RawMutex, T: ?Sized,

pub async fn lock(&self) -> IfMutexGuard<'_, T, M>

Lock the mutex.

This will wait for the mutex to be unlocked if it’s already locked.

pub async fn lock_if<F>(&self, f: F) -> IfMutexGuard<'_, T, M>
where F: Fn(&T) -> bool,

Lock the mutex.

This will wait for the mutex to be unlocked if it’s already locked and for the provided condition on the data to become true.

pub async fn with<F, R>(&self, f: F) -> R
where F: FnMut(&mut T) -> Option<R>,

Waits for the mutex to become unlocked and then executes the provided closure. Will become ready only when the callback closure returns a Some result.

pub fn try_lock(&self) -> Result<IfMutexGuard<'_, T, M>, TryLockError>

Attempt to immediately lock the mutex.

pub fn try_lock_if<F>( &self, f: F, ) -> Result<IfMutexGuard<'_, T, M>, TryLockError>
where F: FnMut(&T) -> bool,

Attempt to immediately lock the mutex.

If the mutex is already locked or the condition on the data is not true, this will return an error instead of waiting.

pub fn into_inner(self) -> T
where T: Sized,

Consumes this mutex, returning the underlying data.

pub fn get_mut(&mut self) -> &mut T

Returns a mutable reference to the underlying data.

Since this call borrows the Mutex mutably, no actual locking needs to take place – the mutable borrow statically guarantees no locks exist.