pub struct IfMutexGuard<'a, T, M = NoopRawMutex>{ /* private fields */ }Expand description
Async mutex guard.
Owning an instance of this type indicates having successfully locked the mutex, and grants access to the contents.
Dropping it unlocks the mutex.