pub struct Signal<S, M = NoopRawMutex> { /* private fields */ }Expand description
Signal is an async synchonization primitive that can be viewed as a generalization of the embassy_sync::Signal primitive
that takes callback closures.
It allows for waiting on a condition of its state S to become true, where whether the condition is met is decided by a callback closure.
It also allows for modifying the state S and waking up the waiters - but only as long as a callback closure provides information that
the state is modified in such a way, that the waiters should be notified.
The generic nature of Signal allows for a wide range of use cases, including the implementation of:
- the
Notificationprimitive - the
IfMutexprimitive
Implementations
Sourceimpl<S, M> Signal<S, M>where
M: RawMutex,
impl<S, M> Signal<S, M>where
M: RawMutex,
Sourcepub fn init<I>(state: I) -> impl Init<Signal<S, M>>where
I: Init<S>,
pub fn init<I>(state: I) -> impl Init<Signal<S, M>>where
I: Init<S>,
Create a Signal in-place initializer with the given initial state initializer I.
pub fn modify<F, R>(&self, f: F) -> R
pub async fn wait<F, R>(&self, f: F) -> R
pub fn poll_wait<F, R>(&self, ctx: &mut Context<'_>, f: F) -> Poll<R>