Module nal

Module nal 

Modules

io
Re-export the edge-nal crate

Structs

NoopNet
Re-export the edge-nal crate A type that implements all edge-nal traits but does not support any operation and panics when any method is called.
WithTimeout
Re-export the edge-nal crate A type that wraps an IO stream type and adds a timeout to all operations.

Enums

AddrType
Re-export the edge-nal crate This is the host address type to be returned by gethostbyname.
Close
Re-export the edge-nal crate Enum representing the different ways to close a TCP socket
WithTimeoutError
Re-export the edge-nal crate Error type for the with_timeout function and WithTimeout struct.

Traits

Dns
Re-export the edge-nal crate This trait provides DNS resolution facility for embedded applications.
MulticastV4
Re-export the edge-nal crate
MulticastV6
Re-export the edge-nal crate
NetStack
The network stack used by rs-matter-stack
RawBind
Re-export the edge-nal crate This trait is implemented by raw socket stacks. The trait allows the underlying driver to construct multiple connections that implement the raw socket traits
RawReceive
Re-export the edge-nal crate This trait is implemented by raw sockets and models their datagram receiving functionality.
RawSend
Re-export the edge-nal crate This trait is implemented by UDP sockets and models their datagram sending functionality.
RawSplit
Re-export the edge-nal crate This trait is implemented by raw sockets that can be split into separate send and receive halves that can operate independently from each other (i.e., a full-duplex connection)
Readable
Re-export the edge-nal crate
TcpAccept
Re-export the edge-nal crate This is a factory trait for accepting incoming connections on server-side TCP sockets
TcpBind
Re-export the edge-nal crate This is a factory trait for creating server-side TCP sockets
TcpConnect
Re-export the edge-nal crate This is a factory trait for connecting to remote TCP peers
TcpShutdown
Re-export the edge-nal crate This trait is implemented by TCP sockets and models their shutdown functionality, which is unique to the TCP protocol (UDP sockets do not have a shutdown procedure).
TcpSplit
Re-export the edge-nal crate This trait is implemented by TCP sockets that can be split into separate send and receive halves that can operate independently from each other (i.e., a full-duplex connection).
UdpBind
Re-export the edge-nal crate This is a factory trait for binding UDP sockets
UdpConnect
Re-export the edge-nal crate This is a factory trait for creating connected UDP sockets
UdpReceive
Re-export the edge-nal crate This trait is implemented by UDP sockets and models their datagram receiving functionality.
UdpSend
Re-export the edge-nal crate This trait is implemented by UDP sockets and models their datagram sending functionality.
UdpSocket
Re-export the edge-nal crate
UdpSplit
Re-export the edge-nal crate This trait is implemented by UDP sockets that can be split into separate send and receive halves that can operate independently from each other (i.e., a full-duplex connection)
UdpSplitMulticast
Re-export the edge-nal crate This trait is implemented by UDP sockets that can be split into separate receive, send, MulticastV4, and MulticastV6 parts that can operate independently from each other (i.e., a full-duplex connection with multicasting capabilities)

Functions

with_timeout
Re-export the edge-nal crate Run a fallible future with a timeout.

Type Aliases

MacAddr
Re-export the edge-nal crate A MAC address