pub enum AddrType {
IPv4,
IPv6,
Either,
}Expand description
Re-export the edge-nal crate
This is the host address type to be returned by gethostbyname.
An IPv4 address type always looks for A records, while IPv6 address type
will look for AAAA records
Variants
IPv4
Result is A record
IPv6
Result is AAAA record
Either
Result is either a A record, or a AAAA record