pub enum Close {
Read,
Write,
Both,
}Expand description
Re-export the edge-nal crate
Enum representing the different ways to close a TCP socket
Variants
Read
Close the read half of the socket
Write
Close the write half of the socket
Both
Close both the read and write halves of the socket