WithTimeout

Struct WithTimeout 

pub struct WithTimeout<T>(/* private fields */);
Re-export the edge-nal crate A type that wraps an IO stream type and adds a timeout to all operations.

The operations decorated with a timeout are the ones offered via the following traits:

  • embedded_io_async::Read
  • embedded_io_async::Write
  • Readable
  • TcpConnect
  • TcpShutdown

Additionally, wrapping with WithTimeout an IO type that implements TcpAccept will result in a TcpAccept implementation that - while waiting potentially indefinitely for an incoming connection - will return a connected socket readily wrapped with a timeout.

Implementations

Source

impl<T> WithTimeout<T>

pub const fn new(timeout_ms: u32, io: T) -> WithTimeout<T>

Create a new WithTimeout instance.

Parameters:

  • timeout_ms: The timeout duration in milliseconds
  • io: The IO type to add a timeout to
pub fn io(&self) -> &T

Get a reference to the inner IO type.

pub fn io_mut(&mut self) -> &mut T

Get a mutable reference to the inner IO type.

pub fn timeout_ms(&self) -> u32

Get the timeout duration in milliseconds.

pub fn into_io(self) -> T

Get the IO type by destructuring the WithTimeout instance.