RawSplit

Trait RawSplit 

pub trait RawSplit: ErrorType {
    type Receive<'a>: RawReceive<Error = Self::Error, Error = Self::Error> + Readable
       where Self: 'a;
    type Send<'a>: RawSend<Error = Self::Error>
       where Self: 'a;

    // Required method
    fn split(&mut self) -> (Self::Receive<'_>, Self::Send<'_>);
}
Re-export the edge-nal crate This trait is implemented by raw sockets that can be split into separate send and receive halves that can operate independently from each other (i.e., a full-duplex connection)

Required Associated Types

type Receive<'a>: RawReceive<Error = Self::Error, Error = Self::Error> + Readable where Self: 'a

type Send<'a>: RawSend<Error = Self::Error> where Self: 'a

Required Methods

fn split(&mut self) -> (Self::Receive<'_>, Self::Send<'_>)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> RawSplit for &mut T
where T: RawSplit,

Source

type Receive<'a> = <T as RawSplit>::Receive<'a> where &mut T: 'a

Source

type Send<'a> = <T as RawSplit>::Send<'a> where &mut T: 'a

Source

fn split( &mut self, ) -> (<&mut T as RawSplit>::Receive<'_>, <&mut T as RawSplit>::Send<'_>)

Implementors