UdpSplitMulticast

Trait UdpSplitMulticast 

pub trait UdpSplitMulticast: UdpSplit {
    type MulticastV4<'a>: MulticastV4<Error = Self::Error>
       where Self: 'a;
    type MulticastV6<'a>: MulticastV6<Error = Self::Error>
       where Self: 'a;

    // Required method
    fn split_multicast(
        &mut self,
    ) -> (Self::Receive<'_>, Self::Send<'_>, Self::MulticastV4<'_>, Self::MulticastV6<'_>);
}
Re-export the edge-nal crate This trait is implemented by UDP sockets that can be split into separate receive, send, MulticastV4, and MulticastV6 parts that can operate independently from each other (i.e., a full-duplex connection with multicasting capabilities)

Required Associated Types

type MulticastV4<'a>: MulticastV4<Error = Self::Error> where Self: 'a

type MulticastV6<'a>: MulticastV6<Error = Self::Error> where Self: 'a

Required Methods

fn split_multicast( &mut self, ) -> (Self::Receive<'_>, Self::Send<'_>, Self::MulticastV4<'_>, Self::MulticastV6<'_>)

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> UdpSplitMulticast for &mut T

Implementors