Module network

Module network 

Traits

Embedding
User data that can be embedded in the stack network
Network
A trait modeling a specific network type. MatterStack is parameterized by a network type implementing this trait.