Module rand

Module rand 

A simple adaptor to convert between rand_core V0.6 and rand_core V0.9

A reseeding RNG implementation that wraps an existing RNG and reseeds it after a specified number of generated bytes. Copied over from the rand project which recently retired theirs.

Modules

rand_core
Random number generation traits

Structs

ChaCha8Core
ChaCha with 8 rounds
ChaCha8Rng
A cryptographically secure random number generator that uses the ChaCha algorithm.
ChaCha12Core
ChaCha with 12 rounds
ChaCha12Rng
A cryptographically secure random number generator that uses the ChaCha algorithm.
ChaCha20Core
ChaCha with 20 rounds
ChaCha20Rng
A cryptographically secure random number generator that uses the ChaCha algorithm.
ReseedingRng
A wrapper around any PRNG that implements BlockRngCore, that adds the ability to reseed it.
RngAdaptor
A simple adaptor to convert between rand_core V0.6 and rand_core V0.9

Functions

reseeding_csprng
Create a reseeding CSPRNG using ChaCha12Core as the underlying PRNG. A good default as an argument to the various rs-matter crypto backends, especially in baremetal environments.

Type Aliases

ChaChaCore
ChaCha with 20 rounds, low-level interface
ChaChaRng
ChaCha with 20 rounds