pub struct BlockRng64<R>where
R: BlockRngCore + ?Sized,{
pub core: R,
/* private fields */
}Expand description
A wrapper type implementing RngCore for some type implementing
BlockRngCore with u64 array buffer; i.e. this can be used to implement
a full RNG from just a generate function.
This is similar to BlockRng, but specialized for algorithms that operate
on u64 values.
No whole generated u64 values are thrown away and all values are consumed
in-order. next_u64 simply takes the next available u64 value.
next_u32 is however a bit special: half of a u64 is consumed, leaving
the other half in the buffer. If the next function called is next_u32
then the other half is then consumed, however both next_u64 and
fill_bytes discard the rest of any half-consumed u64s when called.
fill_bytes consumes a whole number of u64 values. If the requested length
is not a multiple of 8, some bytes will be discarded.
Fields
core: RThe core part of the RNG, implementing the generate function.
Implementations
Sourceimpl<R> BlockRng64<R>where
R: BlockRngCore,
impl<R> BlockRng64<R>where
R: BlockRngCore,
Sourcepub fn new(core: R) -> BlockRng64<R>
pub fn new(core: R) -> BlockRng64<R>
Create a new BlockRng from an existing RNG implementing
BlockRngCore. Results will be generated on first use.
Sourcepub fn index(&self) -> usize
pub fn index(&self) -> usize
Get the index into the result buffer.
If this is equal to or larger than the size of the result buffer then
the buffer is “empty” and generate() must be called to produce new
results.
Sourcepub fn reset(&mut self)
pub fn reset(&mut self)
Reset the number of available results. This will force a new set of results to be generated on next use.
Sourcepub fn generate_and_set(&mut self, index: usize)
pub fn generate_and_set(&mut self, index: usize)
Generate a new set of results immediately, setting the index to the given value.