Module wireless

Module wireless 

Structs

PreexistingWireless
A utility type for running a wireless task with a pre-existing wireless interface rather than bringing up / tearing down the wireless interface for the task.
WirelessBle
An implementation of the Network trait for a Matter stack running over BLE during commissioning, and then over either WiFi or Thread when operating.

Enums

WirelessNetCtl
A composite wireless network controller that is the SAME concrete type during both the (BLE) commissioning phase and the operational (Thread/Wifi) phase.

Constants

MAX_WIRELESS_NETWORKS

Traits

Gatt
A trait for running a task within a context where the BLE peripheral is initialized and operable (e.g. the first part of a non-concurrent commissioning workflow)
GattTask
A trait representing a task that needs access to the BLE GATT peripheral to perform its work (e.g. the first part of a non-concurrent commissioning flow)
Thread
A trait for running a task within a context where the wireless interface is initialized and operable
ThreadCoex
A trait for running a task within a context where both the wireless interface (Thread or Wifi) is initialized and operable, as well as the BLE GATT peripheral is also operable.
ThreadCoexTask
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) as well as to the commissioning BTP GATT peripheral.
ThreadTask
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) (network stack, Netif and Wireless controller) to perform its work.
Wifi
A trait for running a task within a context where the wireless interface is initialized and operable
WifiCoex
A trait for running a task within a context where both the wireless interface (Thread or Wifi) is initialized and operable, as well as the BLE GATT peripheral is also operable.
WifiCoexTask
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) as well as to the commissioning BTP GATT peripheral.
WifiTask
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) (Netif, UDP stack and Wireless controller) to perform its work.

Type Aliases

ThreadMatterStack
A type alias for a Matter stack running over Thread (and BLE, during commissioning).
WifiMatterStack
A type alias for a Matter stack running over Wifi (and BLE, during commissioning).
WirelessMatterStack
A type alias for a Matter stack running over either Wifi or Thread (and BLE, during commissioning).