PreexistingWireless

Struct PreexistingWireless 

pub struct PreexistingWireless<S, N, C, M, G> { /* private fields */ }
A utility type for running a wireless task with a pre-existing wireless interface rather than bringing up / tearing down the wireless interface for the task.

This utility can only be used with hardware that implements wireless coexist mode (i.e. the Thread/Wifi interface as well as the BLE GATT peripheral are available at the same time).

Implementations

Source

impl<S, N, C, M, G> PreexistingWireless<S, N, C, M, G>

pub const fn new(net_stack: S, netif: N, net_ctl: C, mdns: M, gatt: G) -> Self

Create a new PreexistingWireless instance with the given network stack, network interface, network controller and GATT peripheral.