WirelessBle

Struct WirelessBle 

pub struct WirelessBle<T, E = ()>
where T: WirelessNetwork,
{ /* private fields */ }
An implementation of the Network trait for a Matter stack running over BLE during commissioning, and then over either WiFi or Thread when operating.

The supported commissioning is either concurrent or non-concurrent (as per the Matter Core spec), where one over the other is decided at runtime with the concrete wireless implementation (WirelessCoex or Wireless + Gatt).

Non-concurrent commissioning means that the device - at any point in time - either runs Bluetooth or Wifi/Thread, but not both.

This is done to save memory and to avoid the usage of BLE+Wifi/Thread co-exist drivers on devices which share a single wireless radio for both BLE and Wifi/Thread.

Implementations

Source

impl<T, E> WirelessBle<T, E>

pub const fn new() -> Self

Creates a new instance of the WirelessBle network type.

pub fn init() -> impl Init<Self>

Return an in-place initializer for the WirelessBle network type.