ThreadCoexTask

Trait ThreadCoexTask 

pub trait ThreadCoexTask {
    // Required method
    async fn run<S, N, C, M, G>(
        &mut self,
        net_stack: S,
        netif: N,
        net_task: C,
        mdns: M,
        gatt: G,
    ) -> Result<(), Error>
       where S: NetStack,
             N: NetifDiag + NetChangeNotif,
             C: NetCtl + ThreadDiag + NetChangeNotif,
             M: Mdns,
             G: GattPeripheral;
}
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) as well as to the commissioning BTP GATT peripheral.

Typically, tasks performing the Matter concurrent commissioning workflow will implement this trait.

Required Methods

async fn run<S, N, C, M, G>( &mut self, net_stack: S, netif: N, net_task: C, mdns: M, gatt: G, ) -> Result<(), Error>

Run the task with the given network stack, network interface, wireless controller and mDNS

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> ThreadCoexTask for &mut T
where T: ThreadCoexTask,

Source

fn run<S, N, C, M, G>( &mut self, net_stack: S, netif: N, net_ctl: C, mdns: M, gatt: G, ) -> impl Future<Output = Result<(), Error>>

Implementors