WifiCoex

Trait WifiCoex 

pub trait WifiCoex {
    // Required method
    async fn run<T>(&mut self, task: T) -> Result<(), Error>
       where T: WifiCoexTask;
}
A trait for running a task within a context where both the wireless interface (Thread or Wifi) is initialized and operable, as well as the BLE GATT peripheral is also operable.

Typically, tasks performing the Matter concurrent commissioning workflow will ran by implementations of this trait.

Required Methods

async fn run<T>(&mut self, task: T) -> Result<(), Error>
where T: WifiCoexTask,

Setup the radio to operate in wireless coexist mode (Wifi or Thread + BLE) and run the given task.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> WifiCoex for &mut T
where T: WifiCoex,

Source

fn run<A>(&mut self, task: A) -> impl Future<Output = Result<(), Error>>
where A: WifiCoexTask,

Implementors

Source

impl<S, N, C, M, P> WifiCoex for PreexistingWireless<S, N, C, M, P>