pub trait WifiCoexTask {
// Required method
async fn run<S, N, C, M, G>(
&mut self,
net_stack: S,
netif: N,
net_ctl: C,
mdns: M,
gatt: G,
) -> Result<(), Error>
where S: NetStack,
N: NetifDiag + NetChangeNotif,
C: NetCtl + WifiDiag + NetChangeNotif,
M: Mdns,
G: GattPeripheral;
}Expand description
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) as well as to the commissioning BTP GATT peripheral.
Typically, tasks performing the Matter concurrent commissioning workflow will implement this trait.
Required Methods
Sourceasync fn run<S, N, C, M, G>(
&mut self,
net_stack: S,
netif: N,
net_ctl: C,
mdns: M,
gatt: G,
) -> Result<(), Error>where
S: NetStack,
N: NetifDiag + NetChangeNotif,
C: NetCtl + WifiDiag + NetChangeNotif,
M: Mdns,
G: GattPeripheral,
async fn run<S, N, C, M, G>(
&mut self,
net_stack: S,
netif: N,
net_ctl: C,
mdns: M,
gatt: G,
) -> Result<(), Error>where
S: NetStack,
N: NetifDiag + NetChangeNotif,
C: NetCtl + WifiDiag + NetChangeNotif,
M: Mdns,
G: GattPeripheral,
Run the task with the given network stack, network interface, wireless controller and mDNS
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".