WifiTask

Trait WifiTask 

pub trait WifiTask {
    // Required method
    async fn run<S, N, C, M>(
        &mut self,
        net_stack: S,
        netif: N,
        net_ctl: C,
        mdns: M,
    ) -> Result<(), Error>
       where S: NetStack,
             N: NetifDiag + NetChangeNotif,
             C: NetCtl + WifiDiag + NetChangeNotif,
             M: Mdns;
}
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread) (Netif, UDP stack and Wireless controller) to perform its work.

Required Methods

async fn run<S, N, C, M>( &mut self, net_stack: S, netif: N, net_ctl: C, mdns: M, ) -> Result<(), Error>

Run the task with the given network stack, network interface, wireless controller and mDNS

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> WifiTask for &mut T
where T: WifiTask,

Source

fn run<S, N, C, M>( &mut self, net_stack: S, netif: N, net_ctl: C, mdns: M, ) -> impl Future<Output = Result<(), Error>>

Implementors