Crate rs_matter_stack

Crate rs_matter_stack 

Modules

ble
bump
A super-simple bump allocator that allocates off from a fixed-size array.
eth
matter
mdns
nal
network
rand
A simple adaptor to convert between rand_core V0.6 and rand_core V0.9
udp
UDP transport implementation for edge-nal
utils
wireless

Macros

alloc
pin_alloc

Structs

MatterStack
The MatterStack struct is the main entry point for the Matter stack.

Traits

UserTask
A trait representing a user task that needs access to the operational network interface (Netif and net stack) to perform its work.

Type Aliases

MatterStackInteractionModel
MatterStackInteractionModelState
The InteractionModelState specialization owned by MatterStack.