A super-simple bump allocator that allocates off from a fixed-size array.
While dropping the BumpBox boxes will call the destructor of the contained object,
the actual memory will be free only when the unsafe reset method is called.
The primary use case of this allocator is reduction of Rust future sizes, due to
rustc not being very intelligent w.r.t. stack usage in async functions.