pub struct Bump<const N: usize, M = MatterRawMutex> { /* private fields */ }Expand description
A bump allocator that uses a provided memory chunk
Implementations
Sourceimpl<const N: usize, M: RawMutex> Bump<N, M>
impl<const N: usize, M: RawMutex> Bump<N, M>
Sourcepub unsafe fn reset(&self)
pub unsafe fn reset(&self)
Reset the allocator, making all previously allocated memory available again.
Safety
This is unsafe because any previously allocated objects that are still in use will get their memory corrupted and overwritten with new objects.
Make sure that NO previously allocated objects are still in use when calling this method.