pub struct Eth<E = ()> { /* private fields */ }Expand description
An implementation of the Network trait for Ethernet.
Note that “Ethernet” - in the context of this crate - means not just the Ethernet transport, but also any other IP-based transport (like Wifi or Thread), where the Matter stack would not be concerned with the management of the network transport (as in re-connecting to the network on lost signal, managing network credentials and so on).
The expectation is nevertheless that for production use-cases
the Eth network would really only be used for Ethernet.