pub trait Ethernet {
// Required method
async fn run<T>(&mut self, task: T) -> Result<(), Error>
where T: EthernetTask;
}Expand description
A trait for running a task within a context where the ethernet interface is initialized and operable
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".