pub struct AccessReq<'a> { /* private fields */ }Expand description
Access Request Object
Implementations
Sourceimpl<'a> AccessReq<'a>
impl<'a> AccessReq<'a>
Sourcepub const fn new(
accessor: &'a Accessor<'a>,
path: GenericPath,
operation: Access,
device_types: &'a [DeviceType],
) -> AccessReq<'a>
pub const fn new( accessor: &'a Accessor<'a>, path: GenericPath, operation: Access, device_types: &'a [DeviceType], ) -> AccessReq<'a>
Create an access request object.
An access request specifies the accessor attempting to access path
with operation. device_types lists the device types declared by
the endpoint that hosts path; pass an empty slice when this is not
applicable (e.g. for unit tests that don’t exercise DeviceType ACL
targets).
Sourcepub fn set_target_perms(&mut self, perms: Access)
pub fn set_target_perms(&mut self, perms: Access)
Add target’s permissions to the request
The permissions that are associated with the target (identified by the path in the AccessReq) are added to the request