pub struct Accessor<'a> { /* private fields */ }Expand description
The Accessor Object
Implementations
Sourceimpl<'a> Accessor<'a>
impl<'a> Accessor<'a>
Sourcepub fn for_session(session: &Session, matter: &'a Matter<'a>) -> Accessor<'a>
pub fn for_session(session: &Session, matter: &'a Matter<'a>) -> Accessor<'a>
Create a new Accessor object for the given session
Sourcepub const fn new(
fab_idx: u8,
subjects: AccessorSubjects,
auth_mode: Option<AuthMode>,
matter: &'a Matter<'a>,
) -> Accessor<'a>
pub const fn new( fab_idx: u8, subjects: AccessorSubjects, auth_mode: Option<AuthMode>, matter: &'a Matter<'a>, ) -> Accessor<'a>
Create a new Accessor object
Arguments
fab_idx: The fabric index of the accessor (0 means no fabric index)subjects: The subjects of the accessorauth_mode: The auth mode of the accessormatter: The Matter instance
pub fn fab_idx(&self) -> Result<NonZero<u8>, Error>
Sourcepub const fn subjects(&self) -> &AccessorSubjects
pub const fn subjects(&self) -> &AccessorSubjects
Return the subjects of the accessor
Sourcepub fn is_endpoint_accessible(&self, endpoint_id: u16) -> bool
pub fn is_endpoint_accessible(&self, endpoint_id: u16) -> bool
Return whether the given endpoint is accessible for this accessor.
For group sessions, only endpoints that are members of the group are accessible. For all other session types, all endpoints are accessible.
Sourcepub fn peer_node_id(&self) -> Option<u64>
pub fn peer_node_id(&self) -> Option<u64>
Return the peer node ID (admin node ID) for CASE sessions, or None for PASE/other sessions.