pub struct AclEntry {
pub fab_idx: Option<NonZero<u8>>,
/* private fields */
}Expand description
The ACL entry object
Fields
fab_idx: Option<NonZero<u8>>Implementations
Sourceimpl AclEntry
impl AclEntry
Sourcepub const fn new(
fab_idx: Option<NonZero<u8>>,
privilege: Privilege,
auth_mode: AuthMode,
) -> AclEntry
pub const fn new( fab_idx: Option<NonZero<u8>>, privilege: Privilege, auth_mode: AuthMode, ) -> AclEntry
Create a new ACL entry object
Sourcepub fn init(
fab_idx: Option<NonZero<u8>>,
privilege: Privilege,
auth_mode: AuthMode,
) -> impl Init<AclEntry>
pub fn init( fab_idx: Option<NonZero<u8>>, privilege: Privilege, auth_mode: AuthMode, ) -> impl Init<AclEntry>
Return an initializer for an ACL entry object using the given fabric index, privilege and auth mode as input
Sourcepub fn init_with<'a>(
fab_idx: NonZero<u8>,
entry: &'a AccessControlEntryStruct<'a>,
) -> impl Init<AclEntry, Error> + 'a
pub fn init_with<'a>( fab_idx: NonZero<u8>, entry: &'a AccessControlEntryStruct<'a>, ) -> impl Init<AclEntry, Error> + 'a
Return an initializer for an ACL entry object using the given fabric index and TLV entry struct as input
Sourcepub fn read_into<P>(
&self,
accessing_fab_idx: u8,
fab_idx: Option<u8>,
builder: AccessControlEntryStructBuilder<P>,
) -> Result<P, Error>where
P: TLVBuilderParent,
pub fn read_into<P>(
&self,
accessing_fab_idx: u8,
fab_idx: Option<u8>,
builder: AccessControlEntryStructBuilder<P>,
) -> Result<P, Error>where
P: TLVBuilderParent,
Return the data of the ACL entry object into the provided TLV builder
Sourcepub fn normalize(&mut self)
pub fn normalize(&mut self)
Normalize the ACL entry by converting non-null but empty subjects/targets to null, as the spec and YAML tests expect
Sourcepub fn subjects(&self) -> Maybe<&[u64], AsNullable>
pub fn subjects(&self) -> Maybe<&[u64], AsNullable>
Return the subjects of the ACL entry
Sourcepub fn targets(&self) -> Maybe<&[Target], AsNullable>
pub fn targets(&self) -> Maybe<&[Target], AsNullable>
Return the targets of the ACL entry
pub fn auxiliary_type(&self) -> Option<AccessControlAuxiliaryTypeEnum>
Sourcepub fn allow(&self, req: &AccessReq<'_>) -> bool
pub fn allow(&self, req: &AccessReq<'_>) -> bool
Check if the ACL entry allows access to the given accessor and object
Sourcepub fn add_subject(&mut self, subject: u64) -> Result<(), Error>
pub fn add_subject(&mut self, subject: u64) -> Result<(), Error>
Add a subject to the ACL entry