Re-export the rs-matter crate
Modules
- der_
utils - DER encoding utilities for ECDSA signatures and certificate operations.
- gen
- Matter TLV-encoded certificate generator (RCAC / ICAC / NOC).
- x509
- X.509 DER certificate parsing utilities for extracting Matter-specific data.
Structs
Enums
Constants
- MAX_
CERT_ ASN1_ LEN - As per “Certificate Sizes” of the Matter spec, DER formatted DAC and NOC chains must not be longer than this size
- MAX_
CERT_ TLV_ AND_ ASN1_ LEN - Must be large enough to hold both TLV encoding and intermediate ASN.1 encoding during building in order to sign over the ASN1-encoded TBS certificate
- MAX_
CERT_ TLV_ LEN - As per “Certificate Sizes” of the Matter spec