pub struct CryptoSensitive<const N: usize> { /* private fields */ }Expand description
A cryptographic material represented in a cross-platform way, as a fixed-length array in a well-defined format.
Thus, it can be imported into any Crypto provider and exported from it without
worrying about endianness or other platform-specific representation issues.
The reason for wrapping the array with a newtype is so that the following protection measures are taken:
- The material is not accidentally printed in logs or debug output.
- The material has a single
access/access_mutmethod and deliberately does not implementDereforAsReftraits to avoid accidental leakage. - The material is zeroed out when dropped; note however that this has a limited use case, in Rust, because of the Rust move semantics.
Regarding sensitivity, rs-matter takes a radical approach and assumes that
all cryptographic material is sensitive. Including, but not limited to:
- Secret keys (obviously)
- Signatures (because they can leak information about the secret key)
- Hashes (because they can be pre-images of sensitive data)
- Public keys (just in case)
Implementations
Sourceimpl<const N: usize> CryptoSensitive<N>
impl<const N: usize> CryptoSensitive<N>
Sourcepub const fn new() -> CryptoSensitive<N>
pub const fn new() -> CryptoSensitive<N>
Create a new zeroed CryptoSensitive instance.
Sourcepub const fn new_from_ref(
other: CryptoSensitiveRef<'_, N>,
) -> CryptoSensitive<N>
pub const fn new_from_ref( other: CryptoSensitiveRef<'_, N>, ) -> CryptoSensitive<N>
Create a new CryptoSensitive instance by loading data from the provided reference.
Sourcepub fn init() -> impl Init<CryptoSensitive<N>>
pub fn init() -> impl Init<CryptoSensitive<N>>
Return an in-place initializer for a zeroed CryptoSensitive instance.
Sourcepub const fn reference(&self) -> CryptoSensitiveRef<'_, N>
pub const fn reference(&self) -> CryptoSensitiveRef<'_, N>
Get a reference to this cryptographic material.
Sourcepub const fn load(&mut self, other: CryptoSensitiveRef<'_, N>)
pub const fn load(&mut self, other: CryptoSensitiveRef<'_, N>)
Load data from another cryptographic material reference.
Sourcepub const fn load_from_array(&mut self, data: &[u8; N])
pub const fn load_from_array(&mut self, data: &[u8; N])
Load data from a byte array.
Sourcepub fn try_load_from_slice(&mut self, data: &[u8]) -> Result<(), Error>
pub fn try_load_from_slice(&mut self, data: &[u8]) -> Result<(), Error>
Try to load data from a byte slice.
Returns an error if the slice length does not match the expected length.
Sourcepub const fn access(&self) -> &[u8; N]
pub const fn access(&self) -> &[u8; N]
Access the underlying data as a byte array reference.
NOTE: care should be taken when using this method, as it exposes the sensitive data.
Sourcepub const fn access_mut(&mut self) -> &mut [u8; N]
pub const fn access_mut(&mut self) -> &mut [u8; N]
Access the underlying data as a mutable byte array reference.
NOTE: care should be taken when using this method, as it exposes the sensitive data.