pub struct CryptoSensitiveRef<'a, const N: usize> { /* private fields */ }Expand description
A reference to cryptographic material.
The non-owned equivalent of CryptoSensitive<N>.
Implementations
Sourceimpl<'a, const N: usize> CryptoSensitiveRef<'a, N>
impl<'a, const N: usize> CryptoSensitiveRef<'a, N>
Sourcepub const fn new(material: &'a [u8; N]) -> CryptoSensitiveRef<'a, N>
pub const fn new(material: &'a [u8; N]) -> CryptoSensitiveRef<'a, N>
Create a new CryptoSensitiveRef instance from a byte array reference.
Sourcepub fn new_from_slice(material: &'a [u8]) -> CryptoSensitiveRef<'a, N>
pub fn new_from_slice(material: &'a [u8]) -> CryptoSensitiveRef<'a, N>
Create a new CryptoSensitiveRef instance from a byte slice.
Panics if the slice length does not match the expected length.
Sourcepub fn try_new(material: &'a [u8]) -> Result<CryptoSensitiveRef<'a, N>, Error>
pub fn try_new(material: &'a [u8]) -> Result<CryptoSensitiveRef<'a, N>, Error>
Try to create a new CryptoSensitiveRef instance from a byte slice.
Returns an error if the slice length does not match the expected length.
Sourcepub fn split<const M1: usize, const M2: usize>(
&self,
) -> (CryptoSensitiveRef<'a, M1>, CryptoSensitiveRef<'a, M2>)
pub fn split<const M1: usize, const M2: usize>( &self, ) -> (CryptoSensitiveRef<'a, M1>, CryptoSensitiveRef<'a, M2>)
Split this reference into two references of the specified lengths.
Panics if the sum of the specified lengths does not match the length of this reference.