pub struct NoOnOff;Expand description
This is a phantom type for when the LevelControl cluster is not coupled with an OnOff cluster. This type should only be used for annotations and not for actual OnOff functionality. All methods will panic.