pub struct CapabilityMinima {
pub case_sessions_per_fabric: u16,
pub subscriptions_per_fabric: u16,
}Expand description
Capability Minima as reported in the Basic Information cluster
Fields
case_sessions_per_fabric: u16Maximum CASE sessions per fabric
subscriptions_per_fabric: u16Maximum subscriptions per fabric
Implementations
Sourceimpl CapabilityMinima
impl CapabilityMinima
Sourcepub const fn new() -> CapabilityMinima
pub const fn new() -> CapabilityMinima
Create a default instance of CapabilityMinima, with CASE sessions per
fabric derived from the session table and the spec-minimum subscriptions
per fabric.