pub struct DoorLockClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the DoorLock cluster’s client operations. Returned by DoorLockClient::door_lock. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> DoorLockClientView<'a>
impl<'a> DoorLockClientView<'a>
pub async fn lock_door<F>(self, endpoint: u16, request: F) -> Result<(), Error>where
F: FnMut(LockDoorRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn unlock_door<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(UnlockDoorRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn unlock_with_timeout<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(UnlockWithTimeoutRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_week_day_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetWeekDayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn get_week_day_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<GetWeekDayScheduleResponseHandle<'a>, Error>where
F: FnMut(GetWeekDayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn clear_week_day_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(ClearWeekDayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_year_day_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetYearDayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn get_year_day_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<GetYearDayScheduleResponseHandle<'a>, Error>where
F: FnMut(GetYearDayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn clear_year_day_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(ClearYearDayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_holiday_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetHolidayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn get_holiday_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<GetHolidayScheduleResponseHandle<'a>, Error>where
F: FnMut(GetHolidayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn clear_holiday_schedule<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(ClearHolidayScheduleRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_user<F>(self, endpoint: u16, request: F) -> Result<(), Error>where
F: FnMut(SetUserRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn get_user<F>(
self,
endpoint: u16,
request: F,
) -> Result<GetUserResponseHandle<'a>, Error>where
F: FnMut(GetUserRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn clear_user<F>(self, endpoint: u16, request: F) -> Result<(), Error>where
F: FnMut(ClearUserRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_credential<F>(
self,
endpoint: u16,
request: F,
) -> Result<SetCredentialResponseHandle<'a>, Error>where
F: FnMut(SetCredentialRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn get_credential_status<F>(
self,
endpoint: u16,
request: F,
) -> Result<GetCredentialStatusResponseHandle<'a>, Error>where
F: FnMut(GetCredentialStatusRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn clear_credential<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(ClearCredentialRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn unbolt_door<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(UnboltDoorRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn set_aliro_reader_config<F>(
self,
endpoint: u16,
request: F,
) -> Result<(), Error>where
F: FnMut(SetAliroReaderConfigRequestBuilder<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>>) -> Result<CmdDataBuilder<CmdDataArrayBuilder<InvReqBuilder<InvokeSender<'a>, 3>>, 2>, Error>,
pub async fn clear_aliro_reader_config(self, endpoint: u16) -> Result<(), Error>
pub async fn lock_state_read( self, endpoint: u16, ) -> Result<Maybe<DlLockState, AsNullable>, Error>
pub async fn lock_type_read(self, endpoint: u16) -> Result<DlLockType, Error>
pub async fn actuator_enabled_read(self, endpoint: u16) -> Result<bool, Error>
pub async fn door_state_read( self, endpoint: u16, ) -> Result<Maybe<DoorStateEnum, AsNullable>, Error>
pub async fn door_open_events_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn door_closed_events_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn open_period_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn number_of_total_users_supported_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn number_of_pin_users_supported_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn number_of_rfid_users_supported_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn number_of_week_day_schedules_supported_per_user_read( self, endpoint: u16, ) -> Result<u8, Error>
pub async fn number_of_year_day_schedules_supported_per_user_read( self, endpoint: u16, ) -> Result<u8, Error>
pub async fn number_of_holiday_schedules_supported_read( self, endpoint: u16, ) -> Result<u8, Error>
pub async fn max_pin_code_length_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn min_pin_code_length_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn max_rfid_code_length_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn min_rfid_code_length_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn credential_rules_support_read( self, endpoint: u16, ) -> Result<DlCredentialRuleMask, Error>
pub async fn number_of_credentials_supported_per_user_read( self, endpoint: u16, ) -> Result<u8, Error>
Sourcepub async fn language_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<&str, Error>) -> R,
) -> Result<R, Error>
pub async fn language_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<&str, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn led_settings_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn auto_relock_time_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn sound_volume_read(self, endpoint: u16) -> Result<u8, Error>
pub async fn operating_mode_read( self, endpoint: u16, ) -> Result<OperatingModeEnum, Error>
pub async fn supported_operating_modes_read( self, endpoint: u16, ) -> Result<DlSupportedOperatingModes, Error>
pub async fn default_configuration_register_read( self, endpoint: u16, ) -> Result<DlDefaultConfigurationRegister, Error>
pub async fn enable_local_programming_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn enable_one_touch_locking_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn enable_inside_status_led_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn local_programming_features_read( self, endpoint: u16, ) -> Result<DlLocalProgrammingFeatures, Error>
pub async fn wrong_code_entry_limit_read( self, endpoint: u16, ) -> Result<u8, Error>
pub async fn user_code_temporary_disable_time_read( self, endpoint: u16, ) -> Result<u8, Error>
pub async fn send_pin_over_the_air_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn require_pi_nfor_remote_operation_read( self, endpoint: u16, ) -> Result<bool, Error>
pub async fn expiring_user_timeout_read( self, endpoint: u16, ) -> Result<u16, Error>
Sourcepub async fn aliro_reader_verification_key_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn aliro_reader_verification_key_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn aliro_reader_group_identifier_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn aliro_reader_group_identifier_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn aliro_reader_group_sub_identifier_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Octets<'_>, Error>) -> R,
) -> Result<R, Error>
pub async fn aliro_reader_group_sub_identifier_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Octets<'_>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn aliro_expedited_transaction_supported_protocol_versions_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, Octets<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn aliro_expedited_transaction_supported_protocol_versions_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, Octets<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn aliro_group_resolving_key_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn aliro_group_resolving_key_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn aliro_supported_bleuwb_protocol_versions_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, Octets<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn aliro_supported_bleuwb_protocol_versions_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, Octets<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn aliro_ble_advertising_version_read( self, endpoint: u16, ) -> Result<u8, Error>
pub async fn number_of_aliro_credential_issuer_keys_supported_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn number_of_aliro_endpoint_keys_supported_read( self, endpoint: u16, ) -> Result<u16, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn door_open_events_write( self, endpoint: u16, value: u32, ) -> Result<(), Error>
pub async fn door_closed_events_write( self, endpoint: u16, value: u32, ) -> Result<(), Error>
pub async fn open_period_write( self, endpoint: u16, value: u16, ) -> Result<(), Error>
pub async fn led_settings_write( self, endpoint: u16, value: u8, ) -> Result<(), Error>
pub async fn auto_relock_time_write( self, endpoint: u16, value: u32, ) -> Result<(), Error>
pub async fn sound_volume_write( self, endpoint: u16, value: u8, ) -> Result<(), Error>
pub async fn operating_mode_write( self, endpoint: u16, value: OperatingModeEnum, ) -> Result<(), Error>
pub async fn enable_local_programming_write( self, endpoint: u16, value: bool, ) -> Result<(), Error>
pub async fn enable_one_touch_locking_write( self, endpoint: u16, value: bool, ) -> Result<(), Error>
pub async fn enable_inside_status_led_write( self, endpoint: u16, value: bool, ) -> Result<(), Error>
pub async fn local_programming_features_write( self, endpoint: u16, value: DlLocalProgrammingFeatures, ) -> Result<(), Error>
pub async fn wrong_code_entry_limit_write( self, endpoint: u16, value: u8, ) -> Result<(), Error>
pub async fn user_code_temporary_disable_time_write( self, endpoint: u16, value: u8, ) -> Result<(), Error>
pub async fn send_pin_over_the_air_write( self, endpoint: u16, value: bool, ) -> Result<(), Error>
pub async fn require_pi_nfor_remote_operation_write( self, endpoint: u16, value: bool, ) -> Result<(), Error>
pub async fn expiring_user_timeout_write( self, endpoint: u16, value: u16, ) -> Result<(), Error>