pub struct ThreadNetworkDiagnosticsClientView<'a> { /* private fields */ }Expand description
Per-exchange view onto the ThreadNetworkDiagnostics cluster’s client operations. Returned by ThreadNetworkDiagnosticsClient::thread_network_diagnostics. Each method consumes the view (and therefore the underlying crate::transport::exchange::Exchange) — one exchange is one IM transaction.
Implementations
Sourceimpl<'a> ThreadNetworkDiagnosticsClientView<'a>
impl<'a> ThreadNetworkDiagnosticsClientView<'a>
pub async fn reset_counts(self, endpoint: u16) -> Result<(), Error>
pub async fn channel_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn routing_role_read( self, endpoint: u16, ) -> Result<Maybe<RoutingRoleEnum, AsNullable>, Error>
Sourcepub async fn network_name_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn network_name_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<&str, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn pan_id_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn extended_pan_id_read( self, endpoint: u16, ) -> Result<Maybe<u64, AsNullable>, Error>
Sourcepub async fn mesh_local_prefix_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn mesh_local_prefix_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn overrun_count_read(self, endpoint: u16) -> Result<u64, Error>
Sourcepub async fn neighbor_table_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, NeighborTableStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn neighbor_table_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, NeighborTableStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn route_table_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, RouteTableStruct<'_>, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn route_table_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, RouteTableStruct<'_>, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn partition_id_read( self, endpoint: u16, ) -> Result<Maybe<u32, AsNullable>, Error>
pub async fn weighting_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn data_version_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn stable_data_version_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
pub async fn leader_router_id_read( self, endpoint: u16, ) -> Result<Maybe<u8, AsNullable>, Error>
pub async fn detached_role_count_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn child_role_count_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn router_role_count_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn leader_role_count_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn attach_attempt_count_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn partition_id_change_count_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn better_partition_attach_attempt_count_read( self, endpoint: u16, ) -> Result<u16, Error>
pub async fn parent_change_count_read(self, endpoint: u16) -> Result<u16, Error>
pub async fn tx_total_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_unicast_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_broadcast_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_ack_requested_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn tx_acked_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_no_ack_requested_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn tx_data_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_data_poll_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_beacon_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_beacon_request_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn tx_other_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_retry_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_direct_max_retry_expiry_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn tx_indirect_max_retry_expiry_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn tx_err_cca_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_err_abort_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn tx_err_busy_channel_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_total_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_unicast_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_broadcast_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_data_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_data_poll_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_beacon_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_beacon_request_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_other_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_address_filtered_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_dest_addr_filtered_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_duplicated_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_err_no_frame_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_err_unknown_neighbor_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_err_invalid_src_addr_count_read( self, endpoint: u16, ) -> Result<u32, Error>
pub async fn rx_err_sec_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_err_fcs_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn rx_err_other_count_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn active_timestamp_read( self, endpoint: u16, ) -> Result<Maybe<u64, AsNullable>, Error>
pub async fn pending_timestamp_read( self, endpoint: u16, ) -> Result<Maybe<u64, AsNullable>, Error>
pub async fn delay_read( self, endpoint: u16, ) -> Result<Maybe<u32, AsNullable>, Error>
Sourcepub async fn security_policy_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<SecurityPolicy<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn security_policy_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<SecurityPolicy<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn channel_page_0_mask_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn channel_page_0_mask_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<Octets<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn operational_dataset_components_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<Maybe<OperationalDatasetComponents<'_>, AsNullable>, Error>) -> R,
) -> Result<R, Error>
pub async fn operational_dataset_components_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<Maybe<OperationalDatasetComponents<'_>, AsNullable>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn active_network_faults_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, NetworkFaultEnum, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn active_network_faults_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, NetworkFaultEnum, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn ext_address_read( self, endpoint: u16, ) -> Result<Maybe<u64, AsNullable>, Error>
pub async fn rloc_16_read( self, endpoint: u16, ) -> Result<Maybe<u16, AsNullable>, Error>
Sourcepub async fn generated_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn generated_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn accepted_command_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn accepted_command_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
Sourcepub async fn attribute_list_read_with<R>(
self,
endpoint: u16,
f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R,
) -> Result<R, Error>
pub async fn attribute_list_read_with<R>( self, endpoint: u16, f: impl FnOnce(Result<TLVContainer<'_, u32, ArrayContainer>, Error>) -> R, ) -> Result<R, Error>
Read a non-scalar attribute (string, octet string, struct or list) whose value borrows the response buffer. Decodes the value and passes Result<Value, Error> to f while the borrow is live, returning the owned R that f produces (copy out what you need, e.g. |v| v.map(|s| s.to_string())). A non-served optional attribute surfaces as Err to f.
pub async fn feature_map_read(self, endpoint: u16) -> Result<u32, Error>
pub async fn cluster_revision_read(self, endpoint: u16) -> Result<u16, Error>