pub struct WirelessNetworks<const N: usize, T> { /* private fields */ }Expand description
A fixed-size storage for wireless networks credentials.
Implementations
Sourceimpl<const N: usize, T> WirelessNetworks<N, T>where
T: WirelessNetwork,
impl<const N: usize, T> WirelessNetworks<N, T>where
T: WirelessNetwork,
pub const fn new() -> WirelessNetworks<N, T>
pub fn init() -> impl Init<WirelessNetworks<N, T>>
Sourcepub async fn reset_persist<S>(
&mut self,
kv: S,
buf: &mut [u8],
) -> Result<(), Error>where
S: KvBlobStore,
pub async fn reset_persist<S>(
&mut self,
kv: S,
buf: &mut [u8],
) -> Result<(), Error>where
S: KvBlobStore,
Remove all networks from the provided BLOB store and from memory
Arguments
store: the BLOB store to remove the networks frombuf: a temporary buffer to use for removing the networks
Sourcepub async fn load_persist<S>(
&mut self,
kv: S,
buf: &mut [u8],
) -> Result<(), Error>where
S: KvBlobStore,
pub async fn load_persist<S>(
&mut self,
kv: S,
buf: &mut [u8],
) -> Result<(), Error>where
S: KvBlobStore,
Load all networks from the provided BLOB store
Arguments
store: the BLOB store to load the networks frombuf: a temporary buffer to use for loading the networks
Sourcepub fn store(&self, buf: &mut [u8]) -> Result<usize, Error>
pub fn store(&self, buf: &mut [u8]) -> Result<usize, Error>
Store the state into a byte slice.
Arguments
buf: The byte slice to store the state into
Returns the number of bytes written into the buffer.
Sourcepub fn networks<F>(&self, f: F) -> Result<(), Error>
pub fn networks<F>(&self, f: F) -> Result<(), Error>
Iterate over the registered network credentials
Arguments
f: A closure that will be called for each network registered in the storage
Sourcepub fn network<F>(&self, network_id: &[u8], f: F) -> Result<u8, NetworksError>
pub fn network<F>(&self, network_id: &[u8], f: F) -> Result<u8, NetworksError>
Get the credentials of a network by its ID
Arguments
network_id: The ID of the network to getf: A closure that will be called with the credentials of the network, if the network exists
Returns the index of the network in the storage if the network exists, NetworkError::NetworkIdNotFound otherwise
Sourcepub fn next_network<F>(
&self,
last_network_id: Option<&[u8]>,
f: F,
) -> Result<bool, Error>
pub fn next_network<F>( &self, last_network_id: Option<&[u8]>, f: F, ) -> Result<bool, Error>
Get the next network credentials after the one with the given ID
Arguments
after_network_id: The ID of the network to get the next one after. If no network with the provided network ID exists, the first network in the storage will be returned.
Sourcepub fn add_or_update<A, U>(
&mut self,
network_id: &[u8],
add: A,
update: U,
) -> Result<u8, NetworksError>
pub fn add_or_update<A, U>( &mut self, network_id: &[u8], add: A, update: U, ) -> Result<u8, NetworksError>
Add or update a network in the storage
Arguments
network_id: The ID of the network to add or updateadd: An in-place initializer for the network to add. The initializer will be used only if a network with the provided network ID does not exist in the storageupdate: A closure that will be called with the network to update. The closure will be called only if a network with the provided network ID exists in the storage
Sourcepub fn reorder(
&mut self,
index: u8,
network_id: &[u8],
) -> Result<u8, NetworksError>
pub fn reorder( &mut self, index: u8, network_id: &[u8], ) -> Result<u8, NetworksError>
Reorder a network in the storage
Arguments
index: The new index of the networknetwork_id: The ID of the network to reorder
Returns the new index of the network in the storage, if a network with the provided ID exists
or NetworkError::NetworkIdNotFound otherwise
Sourcepub fn remove(&mut self, network_id: &[u8]) -> Result<u8, NetworksError>
pub fn remove(&mut self, network_id: &[u8]) -> Result<u8, NetworksError>
Remove a network from the storage
Arguments
network_id: The ID of the network to remove
Returns the index of the network in the storage if the network exists and was removed, NetworkError::NetworkIdNotFound otherwise
pub fn managed(&self) -> bool
pub fn set_managed(&mut self, managed: bool)