pub struct ChainedHandler<M, H, T> {
pub matcher: M,
pub handler: H,
pub next: T,
}Expand description
A handler that chains two handlers together in a composite handler.
Fields
matcher: MThe matcher that determines whether the handler should be invoked for the incoming operation.
handler: HThe handler to be invoked if the matcher returns true.
next: TThe next handler to be invoked if the matcher returns false.
Implementations
Sourceimpl<M, H, T> ChainedHandler<M, H, T>
impl<M, H, T> ChainedHandler<M, H, T>
Sourcepub const fn new(matcher: M, handler: H, next: T) -> ChainedHandler<M, H, T>
pub const fn new(matcher: M, handler: H, next: T) -> ChainedHandler<M, H, T>
Construct a chained handler that works as follows:
- It will call the provided
handlerinstance if the provided matcher returnstruefor theReadContext/WriteContext/InvokeContextof the incoming operation - Otherwise, it will call the
nexthandler
Arguments:
matcher: A matcher that determines whether the handler should be invoked for the incoming operation.handler: The handler to be invoked if the matcher returnstrue.next: The next handler to be invoked if the matcher returnsfalse.
Sourcepub const fn chain<M2, H2>(
self,
matcher: M2,
handler: H2,
) -> ChainedHandler<M2, H2, ChainedHandler<M, H, T>>
pub const fn chain<M2, H2>( self, matcher: M2, handler: H2, ) -> ChainedHandler<M2, H2, ChainedHandler<M, H, T>>
Chain itself with another handler.
The returned chained handler works as follows:
- It will call the provided
handlerinstance if the provided matcher returnstruefor theReadContext/WriteContext/InvokeContextof the incoming operation - Otherwise, it will call the
selfhandler
Arguments:
matcher: A matcher that determines whether the handler should be invoked for the incoming operation.handler: The handler to be invoked if the matcher returnstrue.