Cluster

Struct Cluster 

pub struct Cluster<'a> {
    pub id: u32,
    pub revision: u16,
    pub feature_map: u32,
    pub attributes: &'a [Attribute],
    pub commands: &'a [Command],
    pub events: &'a [Event],
    pub with_attrs: fn(&Attribute, u16, u32) -> bool,
    pub with_cmds: fn(&Command, u16, u32) -> bool,
    pub with_events: fn(&Event, u16, u32) -> bool,
}
A struct modeling the cluster meta-data (i.e. what is the cluster ID, revision, features, attributes and their access, commands and their access) in the Matter data model.

Fields

id: u32

The ID of the cluster

revision: u16

The revision of the cluster

feature_map: u32

The feature map of the cluster

attributes: &'a [Attribute]

The attributes of the cluster.

These could be all attributes as specified in the Matter spec, even if the concrete instantiation of the cluster supports only a subset of these. See with_attrs for more details.

commands: &'a [Command]

The commands of the cluster.

These could be all commands as specified in the Matter spec, even if the concrete instantiation of the cluster supports only a subset of these. See with_cmds for more details.

events: &'a [Event]

The events of the cluster.

These could be all events as specified in the Matter spec, even if the concrete instantiation of the cluster supports only a subset of these. See with_events for more details.

with_attrs: fn(&Attribute, u16, u32) -> bool

A function that takes an attribute and returns a boolean indicating if the attribute is supported by the cluster.

with_cmds: fn(&Command, u16, u32) -> bool

A function that takes a command and returns a boolean indicating if the command is supported by the cluster.

with_events: fn(&Event, u16, u32) -> bool

A function that takes an event and returns a boolean indicating if the event is supported by the cluster.

Implementations

Source

impl<'a> Cluster<'a>

pub const fn new( id: u32, revision: u16, feature_map: u32, attributes: &'a [Attribute], commands: &'a [Command], events: &'a [Event], with_attrs: fn(&Attribute, u16, u32) -> bool, with_cmds: fn(&Command, u16, u32) -> bool, with_events: fn(&Event, u16, u32) -> bool, ) -> Cluster<'a>

Create a new cluster

Arguments
  • id: The ID of the cluster
  • revision: The revision of the cluster
  • feature_map: The feature map of the cluster
  • attributes: The attributes of the cluster
  • commands: The commands of the cluster
  • with_attrs: A function that takes an attribute and returns a boolean indicating if the attribute should be included
  • with_cmds: A function that takes a command and returns a boolean indicating if the command should be included
  • with_events: A function that takes an event and returns a boolean indicating if the event should be included
pub const fn with_revision(self, revision: u16) -> Cluster<'a>

Return a new cluster with a modified revision

pub const fn with_features(self, feature_map: u32) -> Cluster<'a>

Return a new cluster with a modified feature map

pub const fn with_attrs( self, with_attrs: fn(&Attribute, u16, u32) -> bool, ) -> Cluster<'a>

Return a new cluster with a modified attributes’ matcher

pub const fn with_cmds( self, with_cmds: fn(&Command, u16, u32) -> bool, ) -> Cluster<'a>

Return a new cluster with a modified commands’ matcher

pub const fn with_events( self, with_events: fn(&Event, u16, u32) -> bool, ) -> Cluster<'a>

Return a new cluster with a modified events’ matcher

pub fn attribute(&self, id: u32) -> Option<&Attribute>

Return a reference to the attribute with the given ID, if it exists.

pub fn command(&self, id: u32) -> Option<&Command>

Return a reference to the command with the given ID, if it exists.

pub fn event(&self, id: u32) -> Option<&Event>

Return a reference to the event with the given ID, if it exists.

pub fn read<W>(&self, attr: &AttrDetails, writer: W) -> Result<(), Error>
where W: Reply,

Performs an IM attribute read for the given attribute ID.

The provided attribute ID must be a global attribute, or else an error will be returned.