pub trait InvokeContext: OperationContext {
// Required methods
fn cmd(&self) -> &CmdDetails;
fn data(&self) -> &TLVElement<'_>;
}Required Methods
Sourcefn cmd(&self) -> &CmdDetails
fn cmd(&self) -> &CmdDetails
Return the command object that is associated with this invoke operation.
Sourcefn data(&self) -> &TLVElement<'_>
fn data(&self) -> &TLVElement<'_>
Return the command data that is associated with this invoke operation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".