pub trait Matcher {
// Required method
fn matches(&self, ctx: impl MatchContext) -> bool;
}Expand description
A trait that defines a matcher for determining whether a handler - member of a handler-chain (ChainedHandler)
should be invoked for a specific operation.
Required Methods
Sourcefn matches(&self, ctx: impl MatchContext) -> bool
fn matches(&self, ctx: impl MatchContext) -> bool
Return true if the corresponding handler should be invoked for the provided context.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".