pub trait ReadContext: OperationContext {
// Required method
fn attr(&self) -> &AttrDetails;
}Expand description
A context type that is passed to the handler when processing an attribute Read operation.
Required Methods
Sourcefn attr(&self) -> &AttrDetails
fn attr(&self) -> &AttrDetails
Return the attribute object that is associated with this read operation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".