pub trait WriteContext: OperationContext {
// Required methods
fn attr(&self) -> &AttrDetails;
fn data(&self) -> &TLVElement<'_>;
// Provided method
fn notify_changed(&self) { ... }
}Expand description
A context type that is passed to the handler when processing an attribute Write operation.
Required Methods
Sourcefn attr(&self) -> &AttrDetails
fn attr(&self) -> &AttrDetails
Return the attribute object that is associated with this write operation.
Sourcefn data(&self) -> &TLVElement<'_>
fn data(&self) -> &TLVElement<'_>
Return the attribute data that is associated with this write operation.
Provided Methods
Sourcefn notify_changed(&self)
fn notify_changed(&self)
Notify that the state of the attribute whose write operation is processed has changed.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".