pub struct CmdStatus {
pub path: CmdPath,
pub status: Status,
pub command_ref: Option<u16>,
}Expand description
Status of a command invocation.
Returned when a command invocation does not have a specific generated-command response.
Corresponds to the CommandStatusIB block in the Matter Core spec.
Fields
path: CmdPathThe command path associated with this status.
status: StatusThe status of the command invocation.
command_ref: Option<u16>The CommandRef echoed from the corresponding CommandDataIB.
Required when the request was part of a batched (multi-path) invoke.
Implementations