pub struct Events<const N: usize = rs_matter::::im::events::Events::{constant#0}> { /* private fields */ }Expand description
Events queue.
It lets one publish Matter Events into a priority queue, and allows subscribers and remote clients to read the published events.
The queue is implemented as three equally sized ring buffers, the size of the buffers is set by N. Hence the memory use of the buffers will be 3 * N. If a very small N is picked, then clients that poll may miss events as they fall out of the queue; but a large N of course uses more memory.
If the app emits no events, this subsystem can be disabled by using the NoEvents type alias.
Implementations
Sourceimpl<const N: usize> Events<N>
impl<const N: usize> Events<N>
pub const fn new() -> Events<N>
pub fn init() -> impl Init<Events<N>>
pub fn reset(&mut self)
Sourcepub fn push<S, F>(
&self,
endpoint_id: u16,
cluster_id: u32,
event_id: u32,
priority: EventPriority,
kv: S,
f: F,
) -> Result<u64, Error>
pub fn push<S, F>( &self, endpoint_id: u16, cluster_id: u32, event_id: u32, priority: EventPriority, kv: S, f: F, ) -> Result<u64, Error>
Push a new event into the event queue.
Arguments
endpoint_id: The endpoint ID of the event source.cluster_id: The cluster ID of the event source.event_id: The event ID of the event source.priority: The priority of the event.kv: A key-value store access object for persisting event state as needed.f: A closure that takes anEventTLVWriteand writes the event data into it using TLV encoding. The closure should return an error if writing the event data fails for any reason, in which case the event will not be pushed into the queue.
Returns
Ok(EventNumber): The sequence number of the emitted event, if the event was successfully emitted.Err(Error): An error if the event could not be emitted.