pub struct EventStatus {
pub path: EventPath,
pub status: Status,
}Expand description
A status response for an event in the Interaction Model.
Corresponds to the EventStatusIB TLV structure in the Interaction Model.
Fields
path: EventPathThe path to the event.
status: StatusThe status of the event operation.
Implementations
Sourceimpl EventStatus
impl EventStatus
Sourcepub const fn new(
path: EventPath,
status: IMStatusCode,
cluster_status: Option<u16>,
) -> EventStatus
pub const fn new( path: EventPath, status: IMStatusCode, cluster_status: Option<u16>, ) -> EventStatus
Create a new EventStatus with the given path, status code, and optional cluster status.
Sourcepub const fn from_gp(
path: &GenericPath,
status: IMStatusCode,
cluster_status: Option<u16>,
) -> EventStatus
pub const fn from_gp( path: &GenericPath, status: IMStatusCode, cluster_status: Option<u16>, ) -> EventStatus
Create a new EventStatus from a GenericPath, status code, and optional cluster status.
ATTENTION: the actual reply EventPath will be filled with the GenericPath values,
however these are not necessarily expressing the full path of the incoming data as EventPath does.
Hence, this method is primarily useful for unit tests.