Structs
- Report
Context - Per-subscription context for an in-progress report.
- Subscription
- Subscription
Ids - The IDs of a subscription, used to identify it across the system and to route reports to it.
- Subscriptions
- A type for tracking subscriptions accepted by the data model.
- Subscriptions
Buffers - A struct for the RX buffers containing the read requests of the tracked subscriptions.
Constants
- DEFAULT_
MAX_ SUBSCRIPTIONS - The maximum number of subscriptions that can be tracked at the same time by default.
- MAX_
CHANGED_ ATTRS - The maximum number of changed-attribute entries tracked simultaneously.