pub struct ReportContext<'a, 's, B, const N: usize>{ /* private fields */ }Expand description
Per-subscription context for an in-progress report.
Implementations
Sourceimpl<'a, 's, B, const N: usize> ReportContext<'a, 's, B, N>
impl<'a, 's, B, const N: usize> ReportContext<'a, 's, B, N>
Sourcepub fn subscription(&self) -> &Subscription
pub fn subscription(&self) -> &Subscription
Return a reference to the subscription being reported on.
Sourcepub fn rx(&self) -> &[u8] ⓘ
pub fn rx(&self) -> &[u8] ⓘ
Return a reference to the RX buffer associated with the subscription being reported on.
Sourcepub fn should_send_if_empty(&self) -> bool
pub fn should_send_if_empty(&self) -> bool
Return true if the report should be sent even if it turns out to be empty
(i.e. no attributes or events to report), or false if it can be skipped in that case.
Sourcepub fn should_report_attr(
&self,
endpoint_id: u16,
cluster_id: u32,
attr_id: u32,
) -> bool
pub fn should_report_attr( &self, endpoint_id: u16, cluster_id: u32, attr_id: u32, ) -> bool
Return true if the subscription should report the attribute
identified by the given triple, or false if it can skip it.
Sourcepub fn max_seen_event_number(&self) -> u64
pub fn max_seen_event_number(&self) -> u64
Return the maximum event number the subscription has seen so far.
Sourcepub fn next_max_seen_event_number(&self) -> u64
pub fn next_max_seen_event_number(&self) -> u64
Return the next maximum event number to be updated into the subscription upon returning it to the table.