macro_rules! bitflags_tlv {
($enum_name:ident, $type:ident) => { ... };
}Expand description
Re-export the rs-matter crate
Implements to/from TLV for the given enumeration that was
created using bitflags!
NOTE:
- bitflgs are generally unrestricted. The provided implementations do NOT attempt to validate flags for validity and the entire range of flags will be marshalled (including unknown flags)