pub struct DefaultResponder<'d, 'a, C, B, T, K, N, NC = NoopWirelessNetCtl, R = (), const NS: usize = rs_matter::::respond::DefaultResponder::{constant#0}, const NE: usize = rs_matter::::respond::DefaultResponder::{constant#1}>{ /* private fields */ }Expand description
A composition of the Responder::new_default and Responder::new_busy responders.
Implementations
Sourceimpl<'d, 'a, C, B, T, K, N, NC, R, const NS: usize, const NE: usize> DefaultResponder<'d, 'a, C, B, T, K, N, NC, R, NS, NE>where
C: Crypto,
B: Buffers<Vec<u8, rs_matter::::transport::exchange::Buffer::{constant#0}>>,
T: DataModel,
K: KvBlobStoreAccess,
N: Networks,
R: ReportDataHandler,
impl<'d, 'a, C, B, T, K, N, NC, R, const NS: usize, const NE: usize> DefaultResponder<'d, 'a, C, B, T, K, N, NC, R, NS, NE>where
C: Crypto,
B: Buffers<Vec<u8, rs_matter::::transport::exchange::Buffer::{constant#0}>>,
T: DataModel,
K: KvBlobStoreAccess,
N: Networks,
R: ReportDataHandler,
Sourcepub const fn new(
data_model: &'d InteractionModel<'a, C, B, T, K, N, NC, R, NS, NE>,
) -> DefaultResponder<'d, 'a, C, B, T, K, N, NC, R, NS, NE>
pub const fn new( data_model: &'d InteractionModel<'a, C, B, T, K, N, NC, R, NS, NE>, ) -> DefaultResponder<'d, 'a, C, B, T, K, N, NC, R, NS, NE>
Creates the responder composition.
Sourcepub async fn run<const A: usize, const O: usize>(&self) -> Result<(), Error>
pub async fn run<const A: usize, const O: usize>(&self) -> Result<(), Error>
Run the responder.
Sourcepub const fn responder(
&self,
) -> &Responder<'a, ChainedExchangeHandler<&'d InteractionModel<'a, C, B, T, K, N, NC, R, NS, NE>, SecureChannel<'d, &'d C>>>
pub const fn responder( &self, ) -> &Responder<'a, ChainedExchangeHandler<&'d InteractionModel<'a, C, B, T, K, N, NC, R, NS, NE>, SecureChannel<'d, &'d C>>>
Get a reference to the main responder.
Useful when the user would like to organize its own herd of responders rather than using the run method.
Sourcepub const fn busy_responder(
&self,
) -> &Responder<'a, ChainedExchangeHandler<BusyInteractionModel, BusySecureChannel>>
pub const fn busy_responder( &self, ) -> &Responder<'a, ChainedExchangeHandler<BusyInteractionModel, BusySecureChannel>>
Get a reference to the busy responder.
Useful when the user would like to organize its own herd of busy responders rather than using the run method.