pub trait ExchangeHandler {
// Required method
async fn handle(&self, exchange: Exchange<'_>) -> Result<(), Error>;
}Expand description
A trait modeling a generic handler for an exchange.
The handler takes ownership of the exchange: once handling is done, the only thing left to do with the exchange is to drop it (which ends it).
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".