pub struct BusySecureChannel(/* private fields */);Expand description
A Secure Channel implementation that is only capable of sending Busy status codes
Use with e.g.
ⓘ
let matter = Matter::new(...);
// ...
let busy_responder = Responder::new("SC Busy Responder", BusySecureChannel::new(), &matter, 200/*ms*/);
busy_responder.run::<10>().await?;… to respond with “I’m busy, please try later” status code to all incoming Secure Channel messages, which were not accepted in time by the actual Secure Channel responder, due to all its handlers being occupied with work.
Implementations