pub struct CaseInitiator<'a, C>where
C: Crypto + 'a,{ /* private fields */ }Expand description
CASE Initiator for establishing secure sessions with Matter devices using operational certificates.
This implements the controller side of the CASE protocol. The typical flow is:
- Create an exchange to the target device over a plaintext session
- Call
CaseInitiator::initiate()with the fabric index and peer node ID - On success, the exchange’s session is upgraded to a secure CASE session
Implementations
Sourceimpl<'a, C> CaseInitiator<'a, C>where
C: Crypto + 'a,
impl<'a, C> CaseInitiator<'a, C>where
C: Crypto + 'a,
Sourcepub async fn perform(
exchange: Exchange<'_>,
crypto: &'a C,
fab_idx: NonZero<u8>,
peer_node_id: u64,
) -> Result<(), Error>
pub async fn perform( exchange: Exchange<'_>, crypto: &'a C, fab_idx: NonZero<u8>, peer_node_id: u64, ) -> Result<(), Error>
Perform a CASE handshake with a Matter device.
This performs the complete CASE handshake:
- Send Sigma1 (initiator_random, session_id, destination_id, eph_pub_key)
- Receive Sigma2 (responder_random, session_id, eph_pub_key, encrypted TBE2)
- Send Sigma3 (encrypted TBE3)
- Receive StatusReport
On success, a new secure CASE session is established with the target device.
Arguments
exchange- An exchange to the target device over a plaintext sessioncrypto- The crypto implementationfab_idx- The fabric index to use for the handshakepeer_node_id- The node ID of the target device