pub enum TLVValue<'a> {
}Expand description
A high-level representation of a TLV value.
Combined with TLVTag into a TLV struct it is a convenient way
to emit TLV byte sequences.
A TLVValue can be constructed programmatically, or returned from a TLVElement.
Unlike a TLVElement however, a TLVValue does not represent a complete container,
but rather, its beginning or end.
Variants
S8(i8)
S16(i16)
S32(i32)
S64(i64)
U8(u8)
U16(u16)
U32(u32)
U64(u64)
False
True
F32(f32)
F64(f64)
Utf8l(&'a str)
Utf16l(&'a str)
Utf32l(&'a str)
Utf64l(&'a str)
Str8l(&'a [u8])
Str16l(&'a [u8])
Str32l(&'a [u8])
Str64l(&'a [u8])
Null
Struct
Array
List
EndCnt
Implementations
Sourceimpl<'a> TLVValue<'a>
impl<'a> TLVValue<'a>
Sourcepub const fn value_type(&self) -> TLVValueType
pub const fn value_type(&self) -> TLVValueType
Return the value type of the TLV value.
Sourcepub const fn i16(value: i16) -> TLVValue<'a>
pub const fn i16(value: i16) -> TLVValue<'a>
Create a TLV value as an S8 or S16 TLV value, depending on whether the value is small enough to fit in an S8 TLV value.
Sourcepub const fn i32(value: i32) -> TLVValue<'a>
pub const fn i32(value: i32) -> TLVValue<'a>
Create a TLV value as an S8, S16, or S32 TLV value, depending on whether the value is small enough to fit in an S8 or S16 TLV value.
Sourcepub const fn i64(value: i64) -> TLVValue<'a>
pub const fn i64(value: i64) -> TLVValue<'a>
Create a TLV value as an S8, S16, S32, or S64 TLV value, depending on whether the value is small enough to fit in an S8, S16, or S32 TLV value.
Sourcepub const fn u16(value: u16) -> TLVValue<'a>
pub const fn u16(value: u16) -> TLVValue<'a>
Create a TLV value as a U8 or U16 TLV value, depending on whether the value is small enough to fit in a U8 TLV value.
Sourcepub const fn u32(value: u32) -> TLVValue<'a>
pub const fn u32(value: u32) -> TLVValue<'a>
Create a TLV value as a U8, U16, or U32 TLV value, depending on whether the value is small enough to fit in a U8 or U16 TLV value.
Sourcepub const fn u64(value: u64) -> TLVValue<'a>
pub const fn u64(value: u64) -> TLVValue<'a>
Create a TLV value as a U8, U16, U32, or U64 TLV value, depending on whether the value is small enough to fit in a U8, U16, or U32 TLV value.
Sourcepub const fn utf8(value: &'a str) -> TLVValue<'a>
pub const fn utf8(value: &'a str) -> TLVValue<'a>
Create a TLV value as a UTF-8 TLV value. The length of the string is encoded as 1, 2, 4 or 8 octets, depending on the length of the string.
Sourcepub const fn str(value: &'a [u8]) -> TLVValue<'a>
pub const fn str(value: &'a [u8]) -> TLVValue<'a>
Create a TLV value as an octet string TLV value. The length of the string is encoded as 1, 2, 4 or 8 octets, depending on the length of the string.
Sourcepub const fn end_container() -> TLVValue<'a>
pub const fn end_container() -> TLVValue<'a>
Create a TLV value of type EndCnt (container end).
Sourcepub const fn bool(value: bool) -> TLVValue<'a>
pub const fn bool(value: bool) -> TLVValue<'a>
Create a TLV value of type boolean (True or False).
Sourcepub fn iter(&self) -> TLVValueIter<'a, &TLVValue<'a>> ⓘ
pub fn iter(&self) -> TLVValueIter<'a, &TLVValue<'a>> ⓘ
Return an iterator over the bytes of the TLV value.
Sourcepub fn into_iterator(self) -> TLVValueIter<'a, TLVValue<'a>> ⓘ
pub fn into_iterator(self) -> TLVValueIter<'a, TLVValue<'a>> ⓘ
Converts itself into an iterator over the bytes of the TLV value.