pub struct Skippable<T> { /* private fields */ }Expand description
A wrapper for a type T which might not always be present in the TLV stream.
Unlike Option<T> and Optional<T> though, Skippable<T> is NOT initialized
to None when the value is not present in the TLV stream, but to a default T.
Implementations
Sourceimpl<T> Skippable<T>
impl<T> Skippable<T>
Sourceimpl<T> Skippable<T>where
T: Default + InitDefault,
impl<T> Skippable<T>where
T: Default + InitDefault,
Sourcepub fn new_default() -> Skippable<T>
pub fn new_default() -> Skippable<T>
Create a new Skippable with the default value of T.
Sourcepub fn init_default() -> impl Init<Skippable<T>>
pub fn init_default() -> impl Init<Skippable<T>>
Initialize a Skippable with the default value of T.