pub struct NoNetwork;Expand description
A network implementation that does not support any network communication:
- Trying to send a packet always results in a
ErrorCode::NoNetworkInterfaceerror. - Trying to wait/receive a packet pends forever.
- Joining/leaving multicast groups is a no-op that always succeeds.
Useful when chaining multiple network interfaces together to serve as the last network interface in the chain.