pub struct ReservedSession<'a> { /* private fields */ }Expand description
A helper struct for reserving a session slot in the session table when we don’t have all the necessary information to create a full session yet.
Public for testing purposes, but should not be used outside of the transport module.
Implementations
Sourceimpl<'a> ReservedSession<'a>
impl<'a> ReservedSession<'a>
pub fn reserve_now<C>(
matter: &'a Matter<'a>,
crypto: C,
) -> Result<ReservedSession<'a>, Error>where
C: Crypto,
pub async fn reserve<C>(
matter: &'a Matter<'a>,
crypto: C,
) -> Result<ReservedSession<'a>, Error>where
C: Crypto,
pub fn update( &mut self, local_nodeid: u64, peer_nodeid: u64, peer_sessid: u16, local_sessid: u16, peer_addr: Address, mode: SessionMode, dec_key: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonAeadKeyRef::{constant#0}>>, enc_key: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonAeadKeyRef::{constant#0}>>, att_challenge: Option<CryptoSensitiveRef<'_, rs_matter::::transport::session::AttChallengeRef::{constant#0}>>, shared_secret: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonPkcSharedSecretRef::{constant#0}>>, ) -> Result<(), Error>
pub fn update_with_state( &mut self, state: &mut MatterState, local_nodeid: u64, peer_nodeid: u64, peer_sessid: u16, local_sessid: u16, peer_addr: Address, mode: SessionMode, dec_key: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonAeadKeyRef::{constant#0}>>, enc_key: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonAeadKeyRef::{constant#0}>>, att_challenge: Option<CryptoSensitiveRef<'_, rs_matter::::transport::session::AttChallengeRef::{constant#0}>>, shared_secret: Option<CryptoSensitiveRef<'_, rs_matter::::crypto::canon::CanonPkcSharedSecretRef::{constant#0}>>, ) -> Result<(), Error>
pub fn complete(&mut self)