pub struct TransportRunner<'a, C> { /* private fields */ }Expand description
The Matter Transport Runner, responsible for running the network transport by processing incoming and ougoing packets and thus also managing sessions and exchanges.
The transport runner is wrapping the whole Matter Object, because it needs access to various states, like sessions, fabrics and the transport buffers / state itself.
Implementations
Sourceimpl<'a, C> TransportRunner<'a, C>where
C: Crypto,
impl<'a, C> TransportRunner<'a, C>where
C: Crypto,
Sourcepub const fn new(matter: &'a Matter<'a>, crypto: C) -> TransportRunner<'a, C>
pub const fn new(matter: &'a Matter<'a>, crypto: C) -> TransportRunner<'a, C>
Create a new TransportRunner instance with the given Matter instance and Crypto implementation.
Sourcepub async fn run<S, R, M>(
&mut self,
send: S,
recv: R,
multicast: M,
) -> Result<(), Error>
pub async fn run<S, R, M>( &mut self, send: S, recv: R, multicast: M, ) -> Result<(), Error>
Run the transport runner with the given network send, receive and multicast implementations.
The multicast implementation is only used to manage group (multicast)
membership, so without the groups feature it is accepted but never used.