pub struct RefMut<'b, T>where
T: 'b + ?Sized,{ /* private fields */ }Expand description
A wrapper type for a mutably borrowed value from a RefCell<T>.
See the module-level documentation for more.
Implementations
Sourceimpl<'b, T> RefMut<'b, T>where
T: ?Sized,
impl<'b, T> RefMut<'b, T>where
T: ?Sized,
Sourcepub fn map<U, F>(orig: RefMut<'b, T>, f: F) -> RefMut<'b, U>
pub fn map<U, F>(orig: RefMut<'b, T>, f: F) -> RefMut<'b, U>
Makes a new RefMut for a component of the borrowed data, e.g., an enum
variant.
The RefCell is already mutably borrowed, so this cannot fail.
This is an associated function that needs to be used as
RefMut::map(...). A method would interfere with methods of the same
name on the contents of a RefCell used through Deref.
Examples
use std::cell::{RefCell, RefMut};
let c = RefCell::new((5, 'b'));
{
let b1: RefMut<'_, (u32, char)> = c.borrow_mut();
let mut b2: RefMut<'_, u32> = RefMut::map(b1, |t| &mut t.0);
assert_eq!(*b2, 5);
*b2 = 42;
}
assert_eq!(*c.borrow(), (42, 'b'));Sourcepub fn filter_map<U, F>(
orig: RefMut<'b, T>,
f: F,
) -> Result<RefMut<'b, U>, RefMut<'b, T>>
pub fn filter_map<U, F>( orig: RefMut<'b, T>, f: F, ) -> Result<RefMut<'b, U>, RefMut<'b, T>>
Makes a new RefMut for an optional component of the borrowed data. The
original guard is returned as an Err(..) if the closure returns
None.
The RefCell is already mutably borrowed, so this cannot fail.
This is an associated function that needs to be used as
RefMut::filter_map(...). A method would interfere with methods of the
same name on the contents of a RefCell used through Deref.
Examples
use std::cell::{RefCell, RefMut};
let c = RefCell::new(vec![1, 2, 3]);
{
let b1: RefMut<'_, Vec<u32>> = c.borrow_mut();
let mut b2: Result<RefMut<'_, u32>, _> = RefMut::filter_map(b1, |v| v.get_mut(1));
if let Ok(mut b2) = b2 {
*b2 += 2;
}
}
assert_eq!(*c.borrow(), vec![1, 4, 3]);Sourcepub fn map_split<U, V, F>(
orig: RefMut<'b, T>,
f: F,
) -> (RefMut<'b, U>, RefMut<'b, V>)
pub fn map_split<U, V, F>( orig: RefMut<'b, T>, f: F, ) -> (RefMut<'b, U>, RefMut<'b, V>)
Splits a RefMut into multiple RefMuts for different components of the
borrowed data.
The underlying RefCell will remain mutably borrowed until both
returned RefMuts go out of scope.
The RefCell is already mutably borrowed, so this cannot fail.
This is an associated function that needs to be used as
RefMut::map_split(...). A method would interfere with methods of the
same name on the contents of a RefCell used through Deref.
Examples
use std::cell::{RefCell, RefMut};
let cell = RefCell::new([1, 2, 3, 4]);
let borrow = cell.borrow_mut();
let (mut begin, mut end) = RefMut::map_split(borrow, |slice| slice.split_at_mut(2));
assert_eq!(*begin, [1, 2]);
assert_eq!(*end, [3, 4]);
begin.copy_from_slice(&[4, 3]);
end.copy_from_slice(&[2, 1]);Trait Implementations