Skip to main contentModule sync
Source - blocking
- IfMutex
- Async mutex with conditional locking based on the data inside the mutex.
Check
embassy_sync::Mutex for the original unconditional implementation. - IfMutexGuard
- Async mutex guard.
- Notification
- A notification primitive that allows for notifying a single waiter.
- Signal
Signal is an async synchonization primitive that can be viewed as a generalization of the embassy_sync::Signal primitive
that takes callback closures.- TryLockError
- Error returned by [
Mutex::try_lock]
- DynBase
- A trait that all other
rs-matter dyn traits should extend from.