Re-export the edge-nal crate
This trait is implemented by raw socket stacks. The trait allows the underlying driver to
construct multiple connections that implement the raw socket traits
Re-export the edge-nal crate
This trait is implemented by raw sockets that can be split into separate send and receive halves that can operate
independently from each other (i.e., a full-duplex connection)
Re-export the edge-nal crate
This trait is implemented by TCP sockets and models their shutdown functionality,
which is unique to the TCP protocol (UDP sockets do not have a shutdown procedure).
Re-export the edge-nal crate
This trait is implemented by TCP sockets that can be split into separate send and receive halves that can operate
independently from each other (i.e., a full-duplex connection).
Re-export the edge-nal crate
This trait is implemented by UDP sockets that can be split into separate send and receive halves that can operate
independently from each other (i.e., a full-duplex connection)
Re-export the edge-nal crate
This trait is implemented by UDP sockets that can be split into separate
receive, send, MulticastV4, and MulticastV6 parts that can operate independently from each other
(i.e., a full-duplex connection with multicasting capabilities)