pub struct WithTimeout<T>(/* private fields */);Expand description
Re-export the edge-nal crate
A type that wraps an IO stream type and adds a timeout to all operations.
The operations decorated with a timeout are the ones offered via the following traits:
embedded_io_async::Readembedded_io_async::WriteReadableTcpConnectTcpShutdown
Additionally, wrapping with WithTimeout an IO type that implements TcpAccept will result
in a TcpAccept implementation that - while waiting potentially indefinitely for an incoming
connection - will return a connected socket readily wrapped with a timeout.
Implementations
Sourceimpl<T> WithTimeout<T>
impl<T> WithTimeout<T>
Sourcepub const fn new(timeout_ms: u32, io: T) -> WithTimeout<T>
pub const fn new(timeout_ms: u32, io: T) -> WithTimeout<T>
Create a new WithTimeout instance.
Parameters:
timeout_ms: The timeout duration in millisecondsio: The IO type to add a timeout to
Sourcepub fn timeout_ms(&self) -> u32
pub fn timeout_ms(&self) -> u32
Get the timeout duration in milliseconds.