pub trait NetStack {
type UdpBind<'a>: UdpBind
where Self: 'a;
type UdpConnect<'a>: UdpConnect
where Self: 'a;
type TcpBind<'a>: TcpBind
where Self: 'a;
type TcpConnect<'a>: TcpConnect
where Self: 'a;
type Dns<'a>: Dns
where Self: 'a;
// Required methods
fn udp_bind(&self) -> Option<Self::UdpBind<'_>>;
fn udp_connect(&self) -> Option<Self::UdpConnect<'_>>;
fn tcp_bind(&self) -> Option<Self::TcpBind<'_>>;
fn tcp_connect(&self) -> Option<Self::TcpConnect<'_>>;
fn dns(&self) -> Option<Self::Dns<'_>>;
}Expand description
The network stack used by rs-matter-stack
Depending on the platform and features enabled, the stack might or might not support certain protocols.
Required Associated Types
type UdpBind<'a>: UdpBind where Self: 'a
type UdpConnect<'a>: UdpConnect where Self: 'a
type TcpBind<'a>: TcpBind where Self: 'a
type TcpConnect<'a>: TcpConnect where Self: 'a
type Dns<'a>: Dns where Self: 'a
Required Methods
Sourcefn udp_bind(&self) -> Option<Self::UdpBind<'_>>
fn udp_bind(&self) -> Option<Self::UdpBind<'_>>
Return a UDP Bind implementation, if supported by the network stack
Sourcefn udp_connect(&self) -> Option<Self::UdpConnect<'_>>
fn udp_connect(&self) -> Option<Self::UdpConnect<'_>>
Return a UDP Connect implementation, if supported by the network stack
Sourcefn tcp_bind(&self) -> Option<Self::TcpBind<'_>>
fn tcp_bind(&self) -> Option<Self::TcpBind<'_>>
Return a TCP Bind implementation, if supported by the network stack
Sourcefn tcp_connect(&self) -> Option<Self::TcpConnect<'_>>
fn tcp_connect(&self) -> Option<Self::TcpConnect<'_>>
Return a TCP Connect implementation, if supported by the network stack
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".