A simple adaptor to convert between rand_core V0.6 and rand_core V0.9
A reseeding RNG implementation that wraps an existing RNG and reseeds it after a specified number of generated bytes.
Copied over from the rand project which recently retired theirs.
Modules
- rand_
core - Random number generation traits
Structs
- ChaCha8
Core - ChaCha with 8 rounds
- ChaCha8
Rng - A cryptographically secure random number generator that uses the ChaCha algorithm.
- ChaCha12
Core - ChaCha with 12 rounds
- ChaCha12
Rng - A cryptographically secure random number generator that uses the ChaCha algorithm.
- ChaCha20
Core - ChaCha with 20 rounds
- ChaCha20
Rng - A cryptographically secure random number generator that uses the ChaCha algorithm.
- Reseeding
Rng - A wrapper around any PRNG that implements
BlockRngCore, that adds the ability to reseed it. - RngAdaptor
- A simple adaptor to convert between
rand_coreV0.6 andrand_coreV0.9
Functions
- reseeding_
csprng - Create a reseeding CSPRNG using ChaCha12Core as the underlying PRNG.
A good default as an argument to the various
rs-mattercrypto backends, especially in baremetal environments.
Type Aliases
- ChaCha
Core - ChaCha with 20 rounds, low-level interface
- ChaCha
Rng - ChaCha with 20 rounds