pub struct ReseedingRng<R, Rsdr>(/* private fields */)
where
R: BlockRngCore + SeedableRng,
Rsdr: TryRngCore;Expand description
A wrapper around any PRNG that implements BlockRngCore, that adds the
ability to reseed it.
ReseedingRng reseeds the underlying PRNG in the following cases:
- On a manual call to
reseed(). - After
clone(), the clone will be reseeded on first use. - After the PRNG has generated a configurable number of random bytes.
When should reseeding after a fixed number of generated bytes be used?
Reseeding after a fixed number of generated bytes is never strictly necessary. Cryptographic PRNGs don’t have a limited number of bytes they can output, or at least not a limit reachable in any practical way. There is no such thing as ‘running out of entropy’.
Occasionally reseeding can be seen as some form of ‘security in depth’. Even if in the future a cryptographic weakness is found in the CSPRNG being used, or a flaw in the implementation, occasionally reseeding should make exploiting it much more difficult or even impossible.
Use ReseedingRng::new with a threshold of 0 to disable reseeding
after a fixed number of generated bytes.
Error handling
Although unlikely, reseeding the wrapped PRNG can fail. ReseedingRng will
never panic but try to handle the error intelligently through some
combination of retrying and delaying reseeding until later.
If handling the source error fails ReseedingRng will continue generating
data from the wrapped PRNG without reseeding.
Manually calling reseed() will not have this retry or delay logic, but
reports the error.
Example
use rand::prelude::*;
use rand_chacha::ChaCha20Core; // Internal part of ChaChaRng that
// implements BlockRngCore
use rand::rngs::OsRng;
use rand::rngs::ReseedingRng;
let mut reseeding_rng = ReseedingRng::<ChaCha20Core, _>::new(0, OsRng).unwrap();
println!("{}", reseeding_rng.random::<u64>());
let mut cloned_rng = reseeding_rng.clone();
assert!(reseeding_rng.random::<u64>() != cloned_rng.random::<u64>());Implementations
Sourceimpl<R, Rsdr> ReseedingRng<R, Rsdr>
impl<R, Rsdr> ReseedingRng<R, Rsdr>
Sourcepub fn new(threshold: u64, reseeder: Rsdr) -> Result<Self, Rsdr::Error>
pub fn new(threshold: u64, reseeder: Rsdr) -> Result<Self, Rsdr::Error>
Create a new ReseedingRng from an existing PRNG, combined with a RNG
to use as reseeder.
threshold sets the number of generated bytes after which to reseed the
PRNG. Set it to zero to never reseed based on the number of generated
values.