A utility type for running a wireless task with a pre-existing wireless interface
rather than bringing up / tearing down the wireless interface for the task.
A composite wireless network controller that is the SAME concrete type during
both the (BLE) commissioning phase and the operational (Thread/Wifi) phase.
A trait for running a task within a context where the BLE peripheral is initialized and operable
(e.g. the first part of a non-concurrent commissioning workflow)
A trait representing a task that needs access to the BLE GATT peripheral to perform its work
(e.g. the first part of a non-concurrent commissioning flow)
A trait for running a task within a context where both the wireless interface (Thread or Wifi)
is initialized and operable, as well as the BLE GATT peripheral is also operable.
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread)
as well as to the commissioning BTP GATT peripheral.
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread)
(network stack, Netif and Wireless controller) to perform its work.
A trait for running a task within a context where both the wireless interface (Thread or Wifi)
is initialized and operable, as well as the BLE GATT peripheral is also operable.
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread)
as well as to the commissioning BTP GATT peripheral.
A trait representing a task that needs access to the operational wireless interface (Wifi or Thread)
(Netif, UDP stack and Wireless controller) to perform its work.