pub trait WifiCoex {
// Required method
async fn run<T>(&mut self, task: T) -> Result<(), Error>
where T: WifiCoexTask;
}Expand description
A trait for running a task within a context where both the wireless interface (Thread or Wifi) is initialized and operable, as well as the BLE GATT peripheral is also operable.
Typically, tasks performing the Matter concurrent commissioning workflow will ran by implementations of this trait.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".